@@ -1,10 +1,22 @@
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 """
 Wrapper for loading templates from "templates" directories in panel modules.
 """
 
 import os
 
-from django.conf import settings  # noqa
+from django.conf import settings
 from django.template.base import TemplateDoesNotExist  # noqa
 from django.template.loader import BaseLoader  # noqa
 from django.utils._os import safe_join  # noqa
@@ -35,11 +47,8 @@ class TemplateLoader(BaseLoader):
     def load_template_source(self, template_name, template_dirs=None):
         for path in self.get_template_sources(template_name):
             try:
-                file = open(path)
-                try:
+                with open(path) as file:
                     return (file.read().decode(settings.FILE_CHARSET), path)
-                finally:
-                    file.close()
             except IOError:
                 pass
         raise TemplateDoesNotExist(template_name)
