@@ -1,10 +1,22 @@
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 import glob
-from optparse import make_option
+from optparse import make_option  # noqa
 import os
 
-from django.core.management.base import CommandError
-from django.core.management.templates import TemplateCommand
-from django.utils.importlib import import_module
+from django.core.management.base import CommandError  # noqa
+from django.core.management.templates import TemplateCommand  # noqa
+from django.utils.importlib import import_module  # noqa
 
 import horizon
 
@@ -12,23 +24,23 @@ import horizon
 class Command(TemplateCommand):
     args = "[name] [dashboard name] [optional destination directory]"
     option_list = TemplateCommand.option_list + (
-                      make_option('--dashboard', '-d',
-                                  dest='dashboard',
-                                  action='store',
-                                  default=None,
-                                  help='The dotted python path to the '
-                                       'dashboard which this panel will be '
-                                       'registered with.'),
-                      make_option('--target',
-                                  dest='target',
-                                  action='store',
-                                  default=None,
-                                  help='The directory in which the panel '
-                                       'should be created. Defaults to the '
-                                       'current directory. The value "auto" '
-                                       'may also be used to automatically '
-                                       'create the panel inside the specified '
-                                       'dashboard module.'),)
+        make_option('--dashboard', '-d',
+                    dest='dashboard',
+                    action='store',
+                    default=None,
+                    help='The dotted python path to the '
+                         'dashboard which this panel will be '
+                         'registered with.'),
+        make_option('--target',
+                    dest='target',
+                    action='store',
+                    default=None,
+                    help='The directory in which the panel '
+                         'should be created. Defaults to the '
+                         'current directory. The value "auto" '
+                         'may also be used to automatically '
+                         'create the panel inside the specified '
+                         'dashboard module.'),)
     template = os.path.join(horizon.__path__[0], "conf", "panel_template")
     help = ("Creates a Django app directory structure for a new panel "
             "with the given name in the current directory or optionally in "
@@ -65,7 +77,7 @@ class Command(TemplateCommand):
             if not os.path.exists(target):
                 try:
                     os.mkdir(target)
-                except OSError, exc:
+                except OSError as exc:
                     raise CommandError("Unable to create panel directory: %s"
                                        % exc)
 
