@@ -1,17 +1,3 @@
-/**
- * Licensed under the Apache License, Version 2.0 (the "License"); you may
- * not use this file except in compliance with the License. You may obtain
- * a copy of the License at
- *
- *    http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
- * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
- * License for the specific language governing permissions and limitations
- * under the License.
- */
-
 /**
  *
  * HeatTop JS Framework
@@ -36,14 +22,6 @@
 
 var container = "#heat_resource_topology";
 
-/* NOTE: The structure/architecture of this file (lots of global variables
- *       being referenced within stand-alone functions) means that
- *       "no-use-before-define" eslint warnings will be rampant.
- *       I don't believe there's any plan to overhaul this file, so let's not
- *       clutter up our eslint output with this file's singluar-but-repeated issue.
- */
-/* eslint-disable no-use-before-define */
-
 function update(){
   node = node.data(nodes, function(d) { return d.name; });
   link = link.data(links);
@@ -70,8 +48,9 @@ function update(){
   //Setup click action for all nodes
   node.on("mouseover", function(d) {
     $("#info_box").html(d.info_box);
+    current_info = d.name;
   });
-  node.on("mouseout", function() {
+  node.on("mouseout", function(d) {
     $("#info_box").html('');
   });
 
@@ -157,7 +136,8 @@ function build_node_links(node){
     //make sure target node exists
     try {
       target_idx = findNodeIndex(node.required_by[j]);
-    } catch (err) {
+    } catch(err) {
+      console.log(err);
       push_link =false;
     }
     //check for duplicates
@@ -180,11 +160,11 @@ function build_node_links(node){
 
 function build_reverse_links(node){
   for (var i=0;i<nodes.length;i++){
-    if (nodes[i].required_by) {
+    if(nodes[i].required_by){
       for (var j=0;j<nodes[i].required_by.length;j++){
         var dependency = nodes[i].required_by[j];
         //if new node is required by existing node, push new link
-        if (node.name === dependency) {
+        if(node.name === dependency){
           links.push({
             'source':findNodeIndex(nodes[i].name),
             'target':findNodeIndex(node.name),
@@ -212,7 +192,7 @@ function ajax_poll(poll_time){
 
       //Check for updates and new nodes
       json.nodes.forEach(function(d){
-        var current_node = findNode(d.name);
+        current_node = findNode(d.name);
         //Check if node already exists
         if (current_node) {
           //Node already exists, just update it
@@ -256,10 +236,6 @@ function ajax_poll(poll_time){
       if (needs_update === true){
         update();
       }
-    }).fail(function (jqXHR) {
-      if (jqXHR.status === 401 || jqXHR.status === 403) {
-        window.location.replace(logout_url);
-      }
     });
     //if no nodes still in progress, slow AJAX polling
     if (in_progress === false) { poll_time = 30000; }
@@ -268,13 +244,11 @@ function ajax_poll(poll_time){
   }, poll_time);
 }
 
-/* eslint-disable no-use-before-define */
 if ($(container).length){
   var width = $(container).width(),
     height = 500,
     stack_id = $("#stack_id").data("stack_id"),
-    ajax_url = WEBROOT + 'project/stacks/get_d3_data/' + stack_id + '/',
-    logout_url = WEBROOT + 'auth/logout',
+    ajax_url = '/project/stacks/get_d3_data/' + stack_id + '/',
     graph = $("#d3_data").data("d3_data"),
     force = d3.layout.force()
       .nodes(graph.nodes)
