@@ -20,7 +20,7 @@ horizon.membership = {
    * role id.
    **/
   get_role_element: function(step_slug, role_id) {
-      return $('select[id^="id_' + step_slug + '_role_' + role_id + '"]');
+    return $('select[id^="id_' + step_slug + '_role_' + role_id + '"]');
   },
 
   /*
@@ -28,7 +28,7 @@ horizon.membership = {
    * data id. I.e., the member's row.
    **/
   get_member_element: function(step_slug, data_id) {
-      return $('li[data-' + step_slug + '-id$=' + data_id + ']').parent();
+    return $('li[data-' + step_slug + '-id$=' + data_id + ']').parent();
   },
 
   /*
@@ -49,7 +49,7 @@ horizon.membership = {
    **/
   init_data_list: function(step_slug) {
     horizon.membership.data[step_slug] = [];
-    _.each($(this.get_role_element(step_slug, "")).find("option"), function (option) {
+    angular.forEach($(this.get_role_element(step_slug, "")).find("option"), function (option) {
       horizon.membership.data[step_slug][option.value] = option.text;
     });
   },
@@ -59,7 +59,7 @@ horizon.membership = {
    **/
   init_role_list: function(step_slug) {
     horizon.membership.roles[step_slug] = [];
-    _.each($('label[for^="id_' + step_slug + '_role_"]'), function(role) {
+    angular.forEach($('label[for^="id_' + step_slug + '_role_"]'), function(role) {
       var id = horizon.membership.get_field_id($(role).attr('for'));
       horizon.membership.roles[step_slug][id] = $(role).text();
     });
@@ -73,7 +73,7 @@ horizon.membership = {
     horizon.membership.current_membership[step_slug] = [];
     var members_list = [];
     var role_name, role_id, selected_members;
-    _.each(this.get_role_element(step_slug, ''), function(value, key) {
+    angular.forEach(this.get_role_element(step_slug, ''), function(value, key) {
       role_id = horizon.membership.get_field_id($(value).attr('id'));
       role_name = $('label[for="id_' + step_slug + '_role_' + role_id + '"]').text();
 
@@ -82,7 +82,7 @@ horizon.membership = {
       // extract the member names and add them to the dictionary of lists
       members_list = [];
       if (selected_members) {
-        _.each(selected_members, function(member) {
+        angular.forEach(selected_members, function(member) {
           members_list.push(member.value);
         });
       }
@@ -96,7 +96,7 @@ horizon.membership = {
   get_member_roles: function(step_slug, data_id) {
     var roles = [];
     for (var role in horizon.membership.current_membership[step_slug]) {
-      if ($.inArray(data_id, horizon.membership.current_membership[step_slug][role]) >= 0) {
+      if ($.inArray(data_id, horizon.membership.current_membership[step_slug][role]) !== -1) {
         roles.push(role);
       }
     }
@@ -129,16 +129,20 @@ horizon.membership = {
    * from the lists.
    **/
   remove_member_from_role: function(step_slug, data_id, role_id) {
-    var role_list;
+    var role, membership = horizon.membership.current_membership[step_slug];
     if (role_id) {
-      role_list = horizon.membership.current_membership[step_slug][role_id];
-      horizon.membership.remove_member(step_slug, data_id, role_id, role_list);
+      horizon.membership.remove_member(
+        step_slug, data_id, role_id, membership[role_id]
+      );
     }
     else {
       // search for membership in role lists
-      for (var role in horizon.membership.current_membership[step_slug]) {
-        role_list = horizon.membership.current_membership[step_slug][role];
-        horizon.membership.remove_member(step_slug, data_id, role, role_list);
+      for (role in membership) {
+        if (membership.hasOwnProperty(role)) {
+          horizon.membership.remove_member(
+            step_slug, data_id, role,  membership[role]
+          );
+        }
       }
     }
   },
@@ -154,17 +158,17 @@ horizon.membership = {
 
   update_member_role_dropdown: function(step_slug, data_id, role_ids, member_el) {
     if (typeof(role_ids) === 'undefined') {
-        role_ids = horizon.membership.get_member_roles(step_slug, data_id);
+      role_ids = horizon.membership.get_member_roles(step_slug, data_id);
     }
     if (typeof(member_el) === 'undefined') {
-        member_el = horizon.membership.get_member_element(step_slug, data_id);
+      member_el = horizon.membership.get_member_element(step_slug, data_id);
     }
 
     var $dropdown = member_el.find("li.member").siblings('.dropdown');
     var $role_items = $dropdown.children('.role_dropdown').children('li');
 
     $role_items.each(function (idx, el) {
-      if (_.contains(role_ids, $(el).data('role-id'))) {
+      if ($.inArray(($(el).data('role-id')), role_ids) !== -1) {
         $(el).addClass('selected');
       } else {
         $(el).removeClass('selected');
@@ -175,14 +179,16 @@ horizon.membership = {
     var $roles_display = $dropdown.children('.dropdown-toggle').children('.roles_display');
     var roles_to_display = [];
     for (var i = 0; i < role_ids.length; i++) {
-        if (i == 2) {
-            roles_to_display.push('...');
-            break;
-        }
-        roles_to_display.push(horizon.membership.roles[step_slug][role_ids[i]]);
+      if (i === 2) {
+        roles_to_display.push('...');
+        break;
+      }
+      roles_to_display.push(horizon.membership.roles[step_slug][role_ids[i]]);
     }
     text = roles_to_display.join(', ');
-    if (text.length == 0) text = gettext('No roles');
+    if (text.length === 0) {
+      text = gettext('No roles');
+    }
     $roles_display.text(text);
   },
 
@@ -191,42 +197,50 @@ horizon.membership = {
    * as a list item in the member list.
    **/
   generate_member_element: function(step_slug, display_name, data_id, role_ids, text) {
-    var str_id = "id_" + step_slug + "_" + data_id;
+    var roles = [],
+      that = this,
+      membership_roles = that.roles[step_slug],
+      r;
 
-    var roles = [];
-    for (var r in horizon.membership.roles[step_slug]) {
-      var role = {};
-      role['role_id'] = r;
-      role['role_name'] = horizon.membership.roles[step_slug][r];
-      roles.push(role);
+    for (r in membership_roles) {
+      if (membership_roles.hasOwnProperty(r)){
+        roles.push({
+          role_id: r,
+          role_name: membership_roles[r]
+        });
+      }
     }
 
     var template = horizon.templates.compiled_templates["#membership_template"],
-    params = {data_id: str_id,
-              step_slug: step_slug,
-              default_role: horizon.membership.roles[horizon.membership.default_role_id[step_slug]],
-              display_name: display_name,
-              text: text,
-              roles: roles},
-    member_el = $(template.render(params));
-    this.update_member_role_dropdown(step_slug, str_id, role_ids, member_el);
+      params = {
+        data_id: "id_" + step_slug + "_" + data_id,
+        step_slug: step_slug,
+        default_role: that.roles[that.default_role_id[step_slug]],
+        display_name: display_name,
+        text: text,
+        roles: roles,
+        roles_label: gettext("Roles")
+      },
+      member_el = $(template.render(params));
+    this.update_member_role_dropdown(step_slug, params.data_id, role_ids, member_el);
     return $(member_el);
   },
 
   /*
-  * Generates the HTML structure for the membership UI.
-  **/
+   * Generates the HTML structure for the membership UI.
+   **/
   generate_html: function(step_slug) {
-    var data;
-    for (data in horizon.membership.data[step_slug]) {
-      var data_id = data;
-      var display_name = horizon.membership.data[step_slug][data_id];
-      var role_ids = this.get_member_roles(step_slug, data_id);
-      if (role_ids.length > 0) {
-        $("." + step_slug + "_members").append(this.generate_member_element(step_slug, display_name, data_id, role_ids, "-"));
-      }
-      else {
-        $(".available_" + step_slug).append(this.generate_member_element(step_slug, display_name, data_id, role_ids, "+"));
+    var data_id, data = horizon.membership.data[step_slug];
+    for (data_id in data) {
+      if(data.hasOwnProperty(data_id)){
+        var display_name = data[data_id];
+        var role_ids = this.get_member_roles(step_slug, data_id);
+        if (role_ids.length > 0) {
+          $("." + step_slug + "_members").append(this.generate_member_element(step_slug, display_name, data_id, role_ids, "-"));
+        }
+        else {
+          $(".available_" + step_slug).append(this.generate_member_element(step_slug, display_name, data_id, role_ids, "+"));
+        }
       }
     }
     horizon.membership.detect_no_results(step_slug);
@@ -235,39 +249,39 @@ horizon.membership = {
   /*
    * Triggers on click of link to add/remove membership association.
    **/
-   update_membership: function(step_slug) {
-     $(".available_" + step_slug + ", ." + step_slug + "_members").on('click', ".btn-group a[href='#add_remove']", function (evt) {
-       evt.preventDefault();
-       var available = $(".available_" + step_slug).has($(this)).length;
-       var data_id = horizon.membership.get_field_id($(this).parent().siblings().attr('data-' + step_slug +  '-id'));
-       var member_el = $(this).parent().parent();
+  update_membership: function(step_slug) {
+    $(".available_" + step_slug + ", ." + step_slug + "_members").on('click', ".btn-group a[href='#add_remove']", function (evt) {
+      evt.preventDefault();
+      var available = $(".available_" + step_slug).has($(this)).length;
+      var data_id = horizon.membership.get_field_id($(this).parent().siblings().attr('data-' + step_slug +  '-id'));
+      var member_el = $(this).parent().parent();
 
-       if (available) {
-         var default_role = horizon.membership.default_role_id[step_slug];
-         $(this).text("-");
-         $("." + step_slug + "_members").append(member_el);
-         horizon.membership.add_member_to_role(step_slug, data_id, default_role);
+      if (available) {
+        var default_role = horizon.membership.default_role_id[step_slug];
+        $(this).text("-");
+        $("." + step_slug + "_members").append(member_el);
+        horizon.membership.add_member_to_role(step_slug, data_id, default_role);
 
-         if (horizon.membership.has_roles[step_slug]) {
-           $(this).parent().siblings(".role_options").show();
-           horizon.membership.update_member_role_dropdown(step_slug, data_id, [default_role], member_el);
-         }
-       }
-       else {
-         $(this).text("+");
-         $(this).parent().siblings(".role_options").hide();
-         $(".available_" + step_slug).append(member_el);
-         horizon.membership.remove_member_from_role(step_slug, data_id);
-       }
+        if (horizon.membership.has_roles[step_slug]) {
+          $(this).parent().siblings(".role_options").show();
+          horizon.membership.update_member_role_dropdown(step_slug, data_id, [default_role], member_el);
+        }
+      }
+      else {
+        $(this).text("+");
+        $(this).parent().siblings(".role_options").hide();
+        $(".available_" + step_slug).append(member_el);
+        horizon.membership.remove_member_from_role(step_slug, data_id);
+      }
 
-       // update lists
-       horizon.membership.list_filtering(step_slug);
-       horizon.membership.detect_no_results(step_slug);
+      // update lists
+      horizon.membership.list_filtering(step_slug);
+      horizon.membership.detect_no_results(step_slug);
 
-       // remove input filters
-       $("input." + step_slug + "_filter").val("");
-     });
-   },
+      // remove input filters
+      $("input." + step_slug + "_filter").val("");
+    });
+  },
 
   /*
    * Detects whether each list has members and if it does not
@@ -278,7 +292,7 @@ horizon.membership = {
       var css_class = $(this).find('ul').attr('class');
       // Example value: members step_slug_members
       // Pick the class name that contains the step_slug
-      var filter = _.find(css_class.split(' '), function(val){ return val.indexOf(step_slug) != -1; });
+      var filter = $.grep(css_class.split(' '), function(val){ return val.indexOf(step_slug) !== -1; })[0];
 
       if (!$('.' + filter).children('ul').length) {
         $('#no_' + filter).show();
@@ -357,8 +371,8 @@ horizon.membership = {
   },
 
   /*
-  * Fixes the striping of the fake table upon modification of the lists.
-  **/
+   * Fixes the striping of the fake table upon modification of the lists.
+   **/
   fix_stripes: function(step_slug) {
     $('.fake_' + step_slug + '_table').each( function () {
       var filter = "." + $(this).attr('id');
@@ -390,36 +404,36 @@ horizon.membership = {
       var css_class = $(this).children().children('ul').attr('class');
       // Example value: members step_slug_members
       // Pick the class name that contains the step_slug
-      var filter = _.find(css_class.split(' '), function(val){ return val.indexOf(step_slug) != -1; });
+      var filter = $.grep(css_class.split(' '), function(val){ return val.indexOf(step_slug) !== -1; })[0];
 
       var input = $("input[id='" + filter +"']");
       input.quicksearch('ul.' + filter + ' ul li span.display_name', {
-            'delay': 200,
-            'loader': 'span.loading',
-            'show': function () {
-              $(this).parent().parent().show();
-                if (filter == "available_" + step_slug) {
-                  $(this).parent('.dropdown-toggle').hide();
-                }
-              },
-            'hide': function () {
-              $(this).parent().parent().hide();
-            },
-            'noResults': 'ul#no_' + filter,
-            'onAfter': function () {
-                horizon.membership.fix_stripes(step_slug);
-            },
-            'prepareQuery': function (val) {
-              return new RegExp(val, "i");
-            },
-            'testQuery': function (query, txt, span) {
-              if ($(input).attr('id') == filter) {
-                $(input).prev().removeAttr('disabled');
-                return query.test($(span).text());
-              }
-              else
-                return true;
-            }
+        'delay': 200,
+        'loader': 'span.loading',
+        'show': function () {
+          $(this).parent().parent().show();
+          if (filter === "available_" + step_slug) {
+            $(this).parent('.dropdown-toggle').hide();
+          }
+        },
+        'hide': function () {
+          $(this).parent().parent().hide();
+        },
+        'noResults': 'ul#no_' + filter,
+        'onAfter': function () {
+          horizon.membership.fix_stripes(step_slug);
+        },
+        'prepareQuery': function (val) {
+          return new RegExp(val, "i");
+        },
+        'testQuery': function (query, txt, span) {
+          if ($(input).attr('id') === filter) {
+            $(input).prev().removeAttr('disabled');
+            return query.test($(span).text());
+          } else {
+            return true;
+          }
+        }
       });
     });
   },
@@ -432,53 +446,53 @@ horizon.membership = {
     $(".tab-content, .workflow").addClass("dropdown_fix");
 
     $(modal).find('form').each( function () {
-        var $form = $(this);
+      var $form = $(this);
 
-        // Do nothing if this isn't a membership modal
-        if ($form.find('div.' + step_slug + '_membership').length == 0) {
-           return; // continue
+      // Do nothing if this isn't a membership modal
+      if ($form.find('div.' + step_slug + '_membership').length === 0) {
+        return; // continue
+      }
+
+      // call the initialization functions
+      horizon.membership.init_properties(step_slug);
+      horizon.membership.generate_html(step_slug);
+      horizon.membership.update_membership(step_slug);
+      horizon.membership.select_member_role(step_slug);
+      horizon.membership.add_new_member(step_slug);
+
+
+      // initially hide role dropdowns for available member list
+      $form.find(".available_" +  step_slug + " .role_options").hide();
+
+      // hide the dropdown for members too if we don't need to show it
+      if (!horizon.membership.has_roles[step_slug]) {
+        $form.find("." + step_slug + "_members .role_options").hide();
+      }
+
+      // unfocus filter fields
+      if (step_id.indexOf('update') === 0) {
+        $form.find("#" + step_id + " input").blur();
+      }
+
+      // prevent filter inputs from submitting form on 'enter'
+      $form.find('.' + step_slug + '_membership').keydown(function(event){
+        if(event.keyCode === 13) {
+          event.preventDefault();
+          return false;
         }
+      });
 
-        // call the initalization functions
-        horizon.membership.init_properties(step_slug);
-        horizon.membership.generate_html(step_slug);
-        horizon.membership.update_membership(step_slug);
-        horizon.membership.select_member_role(step_slug);
-        horizon.membership.add_new_member(step_slug);
+      // add filtering + styling to the inline obj creation btn
+      horizon.membership.add_new_member_styling(step_slug);
+      horizon.membership.list_filtering(step_slug);
+      horizon.membership.detect_no_results(step_slug);
 
-
-        // initially hide role dropdowns for available member list
-        $form.find(".available_" +  step_slug + " .role_options").hide();
-
-        // hide the dropdown for members too if we don't need to show it
-        if (!horizon.membership.has_roles[step_slug]) {
-            $form.find("." + step_slug + "_members .role_options").hide();
-        }
-
-        // unfocus filter fields
-        if (step_id.indexOf('update') ==0) {
-            $form.find("#" + step_id + " input").blur();
-        }
-
-        // prevent filter inputs from submitting form on 'enter'
-        $form.find('.' + step_slug + '_membership').keydown(function(event){
-            if(event.keyCode == 13) {
-              event.preventDefault();
-              return false;
-            }
-          });
-
-        // add filtering + styling to the inline obj creation btn
-        horizon.membership.add_new_member_styling(step_slug);
-        horizon.membership.list_filtering(step_slug);
-        horizon.membership.detect_no_results(step_slug);
-
-        // fix initial striping of rows
-        $form.find('.fake_' + step_slug + '_table').each( function () {
-          var filter = "." + $(this).attr('id');
-          $(filter + ' .btn-group:even').addClass('dark_stripe');
-          $(filter + ' .btn-group:last').addClass('last_stripe');
-        });
+      // fix initial striping of rows
+      $form.find('.fake_' + step_slug + '_table').each( function () {
+        var filter = "." + $(this).attr('id');
+        $(filter + ' .btn-group:even').addClass('dark_stripe');
+        $(filter + ' .btn-group:last').addClass('last_stripe');
+      });
     });
   }
 };
