@@ -14,16 +14,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from collections import defaultdict  # noqa
+from collections import defaultdict
 import logging
 import new
 
-from django.conf import settings  # noqa
+from django.conf import settings
 from django.core import urlresolvers
 from django import shortcuts
 from django.utils.functional import Promise  # noqa
-from django.utils.translation import pgettext_lazy  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import pgettext_lazy
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import messages
@@ -38,21 +38,64 @@ ACTION_CSS_CLASSES = ("btn", "btn-small")
 STRING_SEPARATOR = "__"
 
 
-class BaseAction(html.HTMLElement):
-    """ Common base class for all ``Action`` classes. """
-    table = None
-    handles_multiple = False
-    requires_input = False
-    preempt = False
-    policy_rules = None
+class BaseActionMetaClass(type):
+    """Metaclass for adding all actions options from inheritance tree
+    to action.
+    This way actions can inherit from each other but still use
+    the class attributes DSL. Meaning, all attributes of Actions are
+    defined as class attributes, but in the background, it will be used as
+    parameters for the initializer of the object. The object is then
+    initialized clean way. Similar principle is used in DataTableMetaclass.
+    """
+    def __new__(mcs, name, bases, attrs):
+        # Options of action are set ass class attributes, loading them.
+        options = {}
+        if attrs:
+            options = attrs
 
-    def __init__(self, datum=None):
+        # Iterate in reverse to preserve final order
+        for base in bases[::-1]:
+            # It actually throws all super classes away except immediate
+            # superclass. But it's fine, immediate super-class base_options
+            # includes everything because superclasses was created also by
+            # this metaclass. Same principle is used in DataTableMetaclass.
+            if hasattr(base, 'base_options') and base.base_options:
+                base_options = {}
+                # Updating options by superclasses.
+                base_options.update(base.base_options)
+                # Updating superclass options by actual class options.
+                base_options.update(options)
+                options = base_options
+        # Saving all options to class attribute, this will be used for
+        # instantiating of the specific Action.
+        attrs['base_options'] = options
+
+        return type.__new__(mcs, name, bases, attrs)
+
+    def __call__(cls, *args, **kwargs):
+        cls.base_options.update(kwargs)
+        # Adding cls.base_options to each init call.
+        klass = super(BaseActionMetaClass, cls).__call__(
+            *args, **cls.base_options)
+        return klass
+
+
+class BaseAction(html.HTMLElement):
+    """Common base class for all ``Action`` classes."""
+    __metaclass__ = BaseActionMetaClass
+
+    def __init__(self, **kwargs):
         super(BaseAction, self).__init__()
-        self.datum = datum
+        self.datum = kwargs.get('datum', None)
+        self.table = kwargs.get('table', None)
+        self.handles_multiple = kwargs.get('handles_multiple', False)
+        self.requires_input = kwargs.get('requires_input', False)
+        self.preempt = kwargs.get('preempt', False)
+        self.policy_rules = kwargs.get('policy_rules', None)
 
     def data_type_matched(self, datum):
-        """ Method to see if the action is allowed for a certain type of data.
-            Only affects mixed data type tables.
+        """Method to see if the action is allowed for a certain type of data.
+        Only affects mixed data type tables.
         """
         if datum:
             action_data_types = getattr(self, "allowed_data_types", [])
@@ -66,7 +109,7 @@ class BaseAction(html.HTMLElement):
         return True
 
     def get_policy_target(self, request, datum):
-        """ Provide the target for a policy request.
+        """Provide the target for a policy request.
 
         This method is meant to be overridden to return target details when
         one of the policy checks requires them.  E.g., {"user_id": datum.id}
@@ -74,7 +117,7 @@ class BaseAction(html.HTMLElement):
         return {}
 
     def allowed(self, request, datum):
-        """ Determine whether this action is allowed for the current request.
+        """Determine whether this action is allowed for the current request.
 
         This method is meant to be overridden with more specific checks.
         """
@@ -90,7 +133,7 @@ class BaseAction(html.HTMLElement):
         return self.allowed(request, datum)
 
     def update(self, request, datum):
-        """ Allows per-action customization based on current conditions.
+        """Allows per-action customization based on current conditions.
 
         This is particularly useful when you wish to create a "toggle"
         action that will be rendered differently based on the value of an
@@ -101,16 +144,14 @@ class BaseAction(html.HTMLElement):
         pass
 
     def get_default_classes(self):
-        """
-        Returns a list of the default classes for the action. Defaults to
+        """Returns a list of the default classes for the action. Defaults to
         ``["btn", "btn-small"]``.
         """
         return getattr(settings, "ACTION_CSS_CLASSES", ACTION_CSS_CLASSES)
 
     def get_default_attrs(self):
-        """
-        Returns a list of the default HTML attributes for the action. Defaults
-        to returning an ``id`` attribute with the value
+        """Returns a list of the default HTML attributes for the action.
+        Defaults to returning an ``id`` attribute with the value
         ``{{ table.name }}__action_{{ action.name }}__{{ creation counter }}``.
         """
         if self.datum is not None:
@@ -126,7 +167,7 @@ class BaseAction(html.HTMLElement):
 
 
 class Action(BaseAction):
-    """ Represents an action which can be taken on this table's data.
+    """Represents an action which can be taken on this table's data.
 
     .. attribute:: name
 
@@ -206,28 +247,17 @@ class Action(BaseAction):
         to ``handle`` with the calls from ``single`` being transformed
         into a list containing only the single object id.
     """
-    method = "POST"
-    requires_input = True
 
-    def __init__(self, verbose_name=None, verbose_name_plural=None,
-                 single_func=None, multiple_func=None, handle_func=None,
-                 handles_multiple=False, attrs=None, requires_input=True,
-                 allowed_data_types=[], datum=None):
-        super(Action, self).__init__(datum=datum)
-        # Priority: constructor, class-defined, fallback
-        self.verbose_name = verbose_name or getattr(self, 'verbose_name',
-                                                    self.name.title())
-        self.verbose_name_plural = verbose_name_plural or \
-                                    getattr(self, 'verbose_name_plural',
-                                           "%ss" % self.verbose_name)
-        self.handles_multiple = getattr(self,
-                                        "handles_multiple",
-                                        handles_multiple)
-        self.requires_input = getattr(self,
-                                      "requires_input",
-                                      requires_input)
-        self.allowed_data_types = getattr(self, "allowed_data_types",
-                                          allowed_data_types)
+    def __init__(self, single_func=None, multiple_func=None, handle_func=None,
+                 attrs=None, **kwargs):
+        super(Action, self).__init__(**kwargs)
+
+        self.method = kwargs.get('method', "POST")
+        self.requires_input = kwargs.get('requires_input', True)
+        self.verbose_name = kwargs.get('verbose_name', self.name.title())
+        self.verbose_name_plural = kwargs.get('verbose_name_plural',
+            "%ss" % self.verbose_name)
+        self.allowed_data_types = kwargs.get('allowed_data_types', [])
 
         if attrs:
             self.attrs.update(attrs)
@@ -265,7 +295,7 @@ class Action(BaseAction):
             self.multiple = new.instancemethod(multiple, self)
 
     def get_param_name(self):
-        """ Returns the full POST parameter name for this action.
+        """Returns the full POST parameter name for this action.
 
         Defaults to
         ``{{ table.name }}__{{ action.name }}``.
@@ -274,7 +304,7 @@ class Action(BaseAction):
 
 
 class LinkAction(BaseAction):
-    """ A table action which is simply a link rather than a form POST.
+    """A table action which is simply a link rather than a form POST.
 
     .. attribute:: name
 
@@ -300,26 +330,26 @@ class LinkAction(BaseAction):
         Defaults to be an empty list (``[]``). When set to empty, the action
         will accept any kind of data.
     """
-    method = "GET"
-    bound_url = None
+    # class attribute name is used for ordering of Actions in table
+    name = "link"
 
-    def __init__(self, verbose_name=None, allowed_data_types=[],
-                 url=None, attrs=None):
-        super(LinkAction, self).__init__()
-        self.verbose_name = verbose_name or getattr(self,
-                                                    "verbose_name",
-                                                    self.name.title())
-        self.url = getattr(self, "url", url)
-        if not self.verbose_name:
+    def __init__(self, attrs=None, **kwargs):
+        super(LinkAction, self).__init__(**kwargs)
+        self.method = kwargs.get('method', "GET")
+        self.bound_url = kwargs.get('bound_url', None)
+        self.name = kwargs.get('name', self.name)
+        self.verbose_name = kwargs.get('verbose_name', self.name.title())
+        self.url = kwargs.get('url', None)
+        self.allowed_data_types = kwargs.get('allowed_data_types', [])
+
+        if not kwargs.get('verbose_name', None):
             raise NotImplementedError('A LinkAction object must have a '
                                       'verbose_name attribute.')
-        self.allowed_data_types = getattr(self, "allowed_data_types",
-                                          allowed_data_types)
         if attrs:
             self.attrs.update(attrs)
 
     def get_link_url(self, datum=None):
-        """ Returns the final URL based on the value of ``url``.
+        """Returns the final URL based on the value of ``url``.
 
         If ``url`` is callable it will call the function.
         If not, it will then try to call ``reverse`` on ``url``.
@@ -346,7 +376,7 @@ class LinkAction(BaseAction):
 
 
 class FilterAction(BaseAction):
-    """ A base class representing a filter action for a table.
+    """A base class representing a filter action for a table.
 
     .. attribute:: name
 
@@ -377,19 +407,21 @@ class FilterAction(BaseAction):
     # but given the form structure of the table that's currently impossible.
     # At some future date this needs to be reworked to get the filter action
     # separated from the table's POST form.
-    method = "POST"
-    name = "filter"
-    verbose_name = _("Filter")
-    filter_type = "query"
-    needs_preloading = False
 
-    def __init__(self, verbose_name=None, param_name=None):
-        super(FilterAction, self).__init__()
-        self.verbose_name = verbose_name or self.name
-        self.param_name = param_name or 'q'
+    # class attribute name is used for ordering of Actions in table
+    name = "filter"
+
+    def __init__(self, **kwargs):
+        super(FilterAction, self).__init__(**kwargs)
+        self.method = kwargs.get('method', "POST")
+        self.name = kwargs.get('name', self.name)
+        self.verbose_name = kwargs.get('verbose_name', _("Filter"))
+        self.filter_type = kwargs.get('filter_type', "query")
+        self.needs_preloading = kwargs.get('needs_preloading', False)
+        self.param_name = kwargs.get('param_name', 'q')
 
     def get_param_name(self):
-        """ Returns the full query parameter name for this action.
+        """Returns the full query parameter name for this action.
 
         Defaults to
         ``{{ table.name }}__{{ action.name }}__{{ action.param_name }}``.
@@ -424,7 +456,7 @@ class FilterAction(BaseAction):
         return filtered_data
 
     def filter(self, table, data, filter_string):
-        """ Provides the actual filtering logic.
+        """Provides the actual filtering logic.
 
         This method must be overridden by subclasses and return
         the filtered data.
@@ -434,13 +466,13 @@ class FilterAction(BaseAction):
 
 
 class FixedFilterAction(FilterAction):
-    """ A filter action with fixed buttons.
-    """
-    filter_type = 'fixed'
-    needs_preloading = True
+    """A filter action with fixed buttons."""
+
+    def __init__(self, **kwargs):
+        super(FixedFilterAction, self).__init__(**kwargs)
+        self.filter_type = kwargs.get('filter_type', "fixed")
+        self.needs_preloading = kwargs.get('needs_preloading', True)
 
-    def __init__(self, *args, **kwargs):
-        super(FixedFilterAction, self).__init__(args, kwargs)
         self.fixed_buttons = self.get_fixed_buttons()
         self.filter_string = ''
 
@@ -480,9 +512,9 @@ class FixedFilterAction(FilterAction):
 
 
 class BatchAction(Action):
-    """ A table action which takes batch action on one or more
-        objects. This action should not require user input on a
-        per-object basis.
+    """A table action which takes batch action on one or more
+    objects. This action should not require user input on a
+    per-object basis.
 
     .. attribute:: name
 
@@ -496,6 +528,13 @@ class BatchAction(Action):
        self.current_present_action = n will set the current active item
        from the list(action_present[n])
 
+       You can pass a complete action name including 'data_type' by specifying
+       '%(data_type)s' substitution in action_present ("Delete %(data_type)s").
+       Otherwise a complete action name is a format of "<action> <data_type>".
+       <data_type> is determined based on the number of items.
+       By passing a complete action name you allow translators to control
+       the order of words as they want.
+
     .. attribute:: action_past
 
        String or tuple/list. The past tense of action_present. ("Deleted",
@@ -506,7 +545,7 @@ class BatchAction(Action):
     .. attribute:: data_type_singular
 
        A display name for the type of data that receives the
-       action. ("Keypair", "Floating IP", etc.)
+       action. ("Key Pair", "Floating IP", etc.)
 
     .. attribute:: data_type_plural
 
@@ -519,21 +558,26 @@ class BatchAction(Action):
        Optional location to redirect after completion of the delete
        action. Defaults to the current page.
     """
-    success_url = None
 
-    def __init__(self):
+    def __init__(self, **kwargs):
+        super(BatchAction, self).__init__(**kwargs)
+        self.success_url = kwargs.get('success_url', None)
+        self.data_type_singular = kwargs.get('data_type_singular', None)
+        self.data_type_plural = kwargs.get('data_type_plural',
+            self.data_type_singular + 's')
+        # If setting a default name, don't initialize it too early
+        self.verbose_name = kwargs.get('verbose_name', self._get_action_name)
+        self.verbose_name_plural = kwargs.get('verbose_name_plural',
+            lambda: self._get_action_name('plural'))
+
+        if not kwargs.get('data_type_singular', None):
+            raise NotImplementedError('A batchAction object must have a '
+                                      'data_type_singular attribute.')
+
         self.current_present_action = 0
         self.current_past_action = 0
-        self.data_type_plural = getattr(self, 'data_type_plural',
-                                        self.data_type_singular + 's')
-        # If setting a default name, don't initialise it too early
-        self.verbose_name = getattr(self, "verbose_name",
-                                    self._conjugate)
-        self.verbose_name_plural = getattr(self, "verbose_name_plural",
-                                           lambda: self._conjugate('plural'))
         # Keep record of successfully handled objects
         self.success_ids = []
-        super(BatchAction, self).__init__()
 
     def _allowed(self, request, datum=None):
         # Override the default internal action method to prevent batch
@@ -542,9 +586,8 @@ class BatchAction(Action):
             return False
         return super(BatchAction, self)._allowed(request, datum)
 
-    def _conjugate(self, items=None, past=False):
-        """
-        Builds combinations like 'Delete Object' and 'Deleted
+    def _get_action_name(self, items=None, past=False):
+        """Builds combinations like 'Delete Object' and 'Deleted
         Objects' based on the number of items and `past` flag.
         """
         action_type = "past" if past else "present"
@@ -558,33 +601,33 @@ class BatchAction(Action):
             data_type = self.data_type_singular
         else:
             data_type = self.data_type_plural
-        if action_type == "past":
-            msgstr = pgettext_lazy("past", "%(action)s %(data_type)s")
+        if '%(data_type)s' in action:
+            # If full action string is specified, use action as format string.
+            msgstr = action
         else:
-            msgstr = pgettext_lazy("present", "%(action)s %(data_type)s")
+            if action_type == "past":
+                msgstr = pgettext_lazy("past", "%(action)s %(data_type)s")
+            else:
+                msgstr = pgettext_lazy("present", "%(action)s %(data_type)s")
         return msgstr % {'action': action, 'data_type': data_type}
 
     def action(self, request, datum_id):
-        """
-        Required. Accepts a single object id and performs the specific action.
+        """Required. Accepts a single object id and performs the specific
+        action.
 
         Return values are discarded, errors raised are caught and logged.
         """
-        raise NotImplementedError('action() must be defined for '
-                                  'BatchAction: %s' % self.data_type_singular)
+        raise NotImplementedError('action() must be defined for %s'
+                                  % self.__class__.__name__)
 
     def update(self, request, datum):
-        """
-        Switches the action verbose name, if needed
-        """
+        """Switches the action verbose name, if needed."""
         if getattr(self, 'action_present', False):
-            self.verbose_name = self._conjugate()
-            self.verbose_name_plural = self._conjugate('plural')
+            self.verbose_name = self._get_action_name()
+            self.verbose_name_plural = self._get_action_name('plural')
 
     def get_success_url(self, request=None):
-        """
-        Returns the URL to redirect to after a successful action.
-        """
+        """Returns the URL to redirect to after a successful action."""
         if self.success_url:
             return self.success_url
         return request.get_full_path()
@@ -599,7 +642,8 @@ class BatchAction(Action):
             if not table._filter_action(self, request, datum):
                 action_not_allowed.append(datum_display)
                 LOG.info('Permission denied to %s: "%s"' %
-                         (self._conjugate(past=True).lower(), datum_display))
+                         (self._get_action_name(past=True).lower(),
+                          datum_display))
                 continue
             try:
                 self.action(request, datum_id)
@@ -608,7 +652,7 @@ class BatchAction(Action):
                 action_success.append(datum_display)
                 self.success_ids.append(datum_id)
                 LOG.info('%s: "%s"' %
-                         (self._conjugate(past=True), datum_display))
+                         (self._get_action_name(past=True), datum_display))
             except Exception as ex:
                 # Handle the exception but silence it since we'll display
                 # an aggregate error message later. Otherwise we'd get
@@ -623,20 +667,22 @@ class BatchAction(Action):
         # Begin with success message class, downgrade to info if problems.
         success_message_level = messages.success
         if action_not_allowed:
-            msg = _('You do not have permission to %(action)s: %(objs)s')
-            params = {"action": self._conjugate(action_not_allowed).lower(),
+            msg = _('You are not allowed to %(action)s: %(objs)s')
+            params = {"action":
+                      self._get_action_name(action_not_allowed).lower(),
                       "objs": functions.lazy_join(", ", action_not_allowed)}
             messages.error(request, msg % params)
             success_message_level = messages.info
         if action_failure:
             msg = _('Unable to %(action)s: %(objs)s')
-            params = {"action": self._conjugate(action_failure).lower(),
+            params = {"action": self._get_action_name(action_failure).lower(),
                       "objs": functions.lazy_join(", ", action_failure)}
             messages.error(request, msg % params)
             success_message_level = messages.info
         if action_success:
             msg = _('%(action)s: %(objs)s')
-            params = {"action": self._conjugate(action_success, True),
+            params = {"action":
+                      self._get_action_name(action_success, past=True),
                       "objs": functions.lazy_join(", ", action_success)}
             success_message_level(request, msg % params)
 
@@ -644,9 +690,14 @@ class BatchAction(Action):
 
 
 class DeleteAction(BatchAction):
+    """Doc missing."""
     name = "delete"
-    action_present = _("Delete")
-    action_past = _("Deleted")
+
+    def __init__(self, **kwargs):
+        super(DeleteAction, self).__init__(**kwargs)
+        self.name = kwargs.get('name', self.name)
+        self.action_present = kwargs.get('action_present', _("Delete"))
+        self.action_past = kwargs.get('action_past', _("Deleted"))
 
     def action(self, request, obj_id):
         return self.delete(request, obj_id)
@@ -658,3 +709,31 @@ class DeleteAction(BatchAction):
         classes = super(DeleteAction, self).get_default_classes()
         classes += ("btn-danger", "btn-delete")
         return classes
+
+
+class UpdateAction(object):
+    """A table action for cell updates by inline editing."""
+    name = "update"
+    action_present = _("Update")
+    action_past = _("Updated")
+    data_type_singular = "update"
+
+    def action(self, request, datum, obj_id, cell_name, new_cell_value):
+        self.update_cell(request, datum, obj_id, cell_name, new_cell_value)
+
+    def update_cell(self, request, datum, obj_id, cell_name, new_cell_value):
+        """Method for saving data of the cell.
+
+        This method must implements saving logic of the inline edited table
+        cell.
+        """
+        raise NotImplementedError(
+            "UpdateAction must define a update_cell method.")
+
+    def allowed(self, request, datum, cell):
+        """Determine whether updating is allowed for the current request.
+
+        This method is meant to be overridden with more specific checks.
+        Data of the row and of the cell are passed to the method.
+        """
+        return True
