@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+#
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -10,12 +12,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import collections
 import itertools
 import logging
+import sys
 
 from django import template
 from django.template import loader
+from django.utils import datastructures
 
 from horizon.tables import base as horizon_tables
 
@@ -35,8 +38,9 @@ class FormsetCell(horizon_tables.Cell):
         else:
             if self.field.errors:
                 self.attrs['class'] = (self.attrs.get('class', '') +
-                                       ' error form-group')
-                self.attrs['title'] = ' '.join(self.field.errors)
+                    ' error control-group')
+                self.attrs['title'] = ' '.join(
+                    unicode(error) for error in self.field.errors)
 
 
 class FormsetRow(horizon_tables.Row):
@@ -47,20 +51,20 @@ class FormsetRow(horizon_tables.Row):
     def __init__(self, column, datum, form):
         self.form = form
         super(FormsetRow, self).__init__(column, datum)
-        if not self.cells:
+        if self.cells == []:
             # We need to be able to handle empty rows, because there may
             # be extra empty forms in a formset. The original DataTable breaks
             # on this, because it sets self.cells to [], but later expects a
-            # OrderedDict. We just fill self.cells with empty Cells.
+            # SortedDict. We just fill self.cells with empty Cells.
             cells = []
-            for col in self.table.columns.values():
-                cell = self.table._meta.cell_class(None, col, self)
-                cells.append((col.name or col.auto, cell))
-            self.cells = collections.OrderedDict(cells)
+            for column in self.table.columns.values():
+                cell = self.table._meta.cell_class(None, column, self)
+                cells.append((column.name or column.auto, cell))
+            self.cells = datastructures.SortedDict(cells)
 
     def render(self):
         return loader.render_to_string(self.template_path,
-                                       {"row": self, "form": self.form})
+            {"row": self, "form": self.form})
 
 
 class FormsetDataTableMixin(object):
@@ -133,18 +137,19 @@ class FormsetDataTableMixin(object):
             else:
                 formset = self.get_formset()
                 formset.is_valid()
-            for datum, form in itertools.zip_longest(self.filtered_data,
-                                                     formset):
+            for datum, form in itertools.izip_longest(self.filtered_data,
+                                                        formset):
                 row = self._meta.row_class(self, datum, form)
                 if self.get_object_id(datum) == self.current_item_id:
                     self.selected = True
                     row.classes.append('current_selected')
                 rows.append(row)
-        except Exception as e:
+        except Exception:
             # Exceptions can be swallowed at the template level here,
             # re-raising as a TemplateSyntaxError makes them visible.
             LOG.exception("Error while rendering table rows.")
-            raise template.TemplateSyntaxError from e
+            exc_info = sys.exc_info()
+            raise template.TemplateSyntaxError, exc_info[1], exc_info[2]
         return rows
 
     def get_object_id(self, datum):
