@@ -18,9 +18,11 @@ from collections import defaultdict
 
 from django.views import generic
 
+from horizon.templatetags.horizon import has_permissions  # noqa
+
 
 class MultiTableMixin(object):
-    """ A generic mixin which provides methods for handling DataTables. """
+    """A generic mixin which provides methods for handling DataTables."""
     data_method_pattern = "get_%s_data"
 
     def __init__(self, *args, **kwargs):
@@ -73,7 +75,7 @@ class MultiTableMixin(object):
         func = getattr(self, func_name, None)
         if not func or not callable(func):
             cls_name = self.__class__.__name__
-            raise NotImplementedError("You must define a %s method"
+            raise NotImplementedError("You must define a %s method "
                                       "in %s." % (func_name, cls_name))
         else:
             return func
@@ -89,6 +91,9 @@ class MultiTableMixin(object):
                                  'on %s.' % self.__class__.__name__)
         if not self._tables:
             for table in self.table_classes:
+                if not has_permissions(self.request.user,
+                                       table._meta):
+                    continue
                 func_name = "get_%s_table" % table._meta.name
                 table_func = getattr(self, func_name, None)
                 if table_func is None:
@@ -118,8 +123,7 @@ class MultiTableMixin(object):
 
 
 class MultiTableView(MultiTableMixin, generic.TemplateView):
-    """
-    A class-based generic view to handle the display and processing of
+    """A class-based generic view to handle the display and processing of
     multiple :class:`~horizon.tables.DataTable` classes in a single view.
 
     Three steps are required to use this view: set the ``table_classes``
@@ -159,7 +163,7 @@ class MultiTableView(MultiTableMixin, generic.TemplateView):
 
 
 class DataTableView(MultiTableView):
-    """ A class-based generic view to handle basic DataTable processing.
+    """A class-based generic view to handle basic DataTable processing.
 
     Three steps are required to use this view: set the ``table_class``
     attribute with the desired :class:`~horizon.tables.DataTable` class;
@@ -183,10 +187,15 @@ class DataTableView(MultiTableView):
 
     def get_tables(self):
         if not self._tables:
-            self._tables = {self.table_class._meta.name: self.get_table()}
+            self._tables = {}
+            if has_permissions(self.request.user,
+                               self.table_class._meta):
+                self._tables[self.table_class._meta.name] = self.get_table()
         return self._tables
 
     def get_table(self):
+        # Note: this method cannot be easily memoized, because get_context_data
+        # uses its cached value directly.
         if not self.table_class:
             raise AttributeError('You must specify a DataTable class for the '
                                  '"table_class" attribute on %s.'
@@ -197,12 +206,13 @@ class DataTableView(MultiTableView):
 
     def get_context_data(self, **kwargs):
         context = super(DataTableView, self).get_context_data(**kwargs)
-        context[self.context_object_name] = self.table
+        if hasattr(self, "table"):
+            context[self.context_object_name] = self.table
         return context
 
 
 class MixedDataTableView(DataTableView):
-    """ A class-based generic view to handle DataTable with mixed data
+    """A class-based generic view to handle DataTable with mixed data
     types.
 
     Basic usage is the same as DataTableView.
@@ -246,7 +256,7 @@ class MixedDataTableView(DataTableView):
         self.table = super(MixedDataTableView, self).get_table()
         if not self.table._meta.mixed_data_type:
             raise AttributeError('You must have at least two elements in '
-                                 'the data_types attibute '
+                                 'the data_types attribute '
                                  'in table %s to use MixedDataTableView.'
                                  % self.table._meta.name)
         return self.table
