@@ -18,9 +18,10 @@ from __future__ import absolute_import
 
 from django import template
 from django.utils.datastructures import SortedDict
-from django.utils.translation import ugettext as _
+from django.utils.encoding import force_unicode
+from django.utils.translation import ugettext_lazy as _
 
-from horizon.base import Horizon
+from horizon.base import Horizon  # noqa
 from horizon import conf
 
 
@@ -29,8 +30,7 @@ register = template.Library()
 
 @register.filter
 def has_permissions(user, component):
-    """
-    Checks if the given user meets the permissions requirements for
+    """Checks if the given user meets the permissions requirements for
     the component.
     """
     return user.has_perms(getattr(component, 'permissions', set()))
@@ -42,9 +42,39 @@ def has_permissions_on_list(components, user):
                 in components if has_permissions(user, component)]
 
 
+@register.inclusion_tag('horizon/_accordion_nav.html', takes_context=True)
+def horizon_nav(context):
+    if 'request' not in context:
+        return {}
+    current_dashboard = context['request'].horizon.get('dashboard', None)
+    current_panel = context['request'].horizon.get('panel', None)
+    dashboards = []
+    for dash in Horizon.get_dashboards():
+        panel_groups = dash.get_panel_groups()
+        non_empty_groups = []
+        for group in panel_groups.values():
+            allowed_panels = []
+            for panel in group:
+                if callable(panel.nav) and panel.nav(context):
+                    allowed_panels.append(panel)
+                elif not callable(panel.nav) and panel.nav:
+                    allowed_panels.append(panel)
+            if allowed_panels:
+                non_empty_groups.append((group.name, allowed_panels))
+        if callable(dash.nav) and dash.nav(context):
+            dashboards.append((dash, SortedDict(non_empty_groups)))
+        elif not callable(dash.nav) and dash.nav:
+            dashboards.append((dash, SortedDict(non_empty_groups)))
+    return {'components': dashboards,
+            'user': context['request'].user,
+            'current': current_dashboard,
+            'current_panel': current_panel.slug if current_panel else '',
+            'request': context['request']}
+
+
 @register.inclusion_tag('horizon/_nav_list.html', takes_context=True)
 def horizon_main_nav(context):
-    """ Generates top-level dashboard navigation entries. """
+    """Generates top-level dashboard navigation entries."""
     if 'request' not in context:
         return {}
     current_dashboard = context['request'].horizon.get('dashboard', None)
@@ -62,7 +92,7 @@ def horizon_main_nav(context):
 
 @register.inclusion_tag('horizon/_subnav_list.html', takes_context=True)
 def horizon_dashboard_nav(context):
-    """ Generates sub-navigation entries for the current dashboard. """
+    """Generates sub-navigation entries for the current dashboard."""
     if 'request' not in context:
         return {}
     dashboard = context['request'].horizon['dashboard']
@@ -85,36 +115,28 @@ def horizon_dashboard_nav(context):
             'request': context['request']}
 
 
-@register.inclusion_tag('horizon/common/_progress_bar.html')
-def horizon_progress_bar(current_val, max_val):
-    """ Renders a progress bar based on parameters passed to the tag. The first
-    parameter is the current value and the second is the max value.
-
-    Example: ``{% progress_bar 25 50 %}``
-
-    This will generate a half-full progress bar.
-
-    The rendered progress bar will fill the area of its container. To constrain
-    the rendered size of the bar provide a container with appropriate width and
-    height styles.
-
-    """
-    return {'current_val': current_val,
-            'max_val': max_val}
-
-
 @register.filter
 def quota(val, units=None):
     if val == float("inf"):
         return _("No Limit")
     elif units is not None:
-        return "%s %s %s" % (val, units, _("Available"))
+        return "%s %s %s" % (val, units, force_unicode(_("Available")))
     else:
-        return "%s %s" % (val, _("Available"))
+        return "%s %s" % (val, force_unicode(_("Available")))
+
+
+@register.filter
+def quotainf(val, units=None):
+    if val == float("inf"):
+        return _("No Limit")
+    elif units is not None:
+        return "%s %s" % (val, units)
+    else:
+        return val
 
 
 class JSTemplateNode(template.Node):
-    """ Helper node for the ``jstemplate`` template tag. """
+    """Helper node for the ``jstemplate`` template tag."""
     def __init__(self, nodelist):
         self.nodelist = nodelist
 
@@ -128,8 +150,7 @@ class JSTemplateNode(template.Node):
 
 @register.tag
 def jstemplate(parser, token):
-    """
-    Replaces ``[[[`` and ``]]]`` with ``{{{`` and ``}}}``,
+    """Replaces ``[[[`` and ``]]]`` with ``{{{`` and ``}}}``,
     ``[[`` and ``]]`` with ``{{`` and ``}}``  and
     ``[%`` and ``%]`` with ``{%`` and ``%}`` to avoid conflicts
     with Django's template engine when using any of the Mustache-based
