@@ -17,7 +17,9 @@
 
 import time
 
-from django.conf import settings  # noqa
+from django.conf import settings
+
+from django.http import HttpResponseRedirect  # noqa
 
 from horizon import exceptions
 from horizon import middleware
@@ -48,3 +50,20 @@ class MiddlewareTests(test.TestCase):
         resp = mw.process_request(request)
         self.assertEqual(resp.status_code, 302)
         self.assertEqual(resp.get('Location'), response_url)
+
+    def test_process_response_redirect_on_ajax_request(self):
+        url = settings.LOGIN_URL
+        mw = middleware.HorizonMiddleware()
+
+        request = self.factory.post(url,
+                                    HTTP_X_REQUESTED_WITH='XMLHttpRequest')
+        request.META['HTTP_X_REQUESTED_WITH'] = 'XMLHttpRequest'
+        request.horizon = {'async_messages':
+                                [('error', 'error_msg', 'extra_tag')]}
+
+        response = HttpResponseRedirect(url)
+        response.client = self.client
+
+        resp = mw.process_response(request, response)
+        self.assertEqual(resp.status_code, 200)
+        self.assertEqual(resp['X-Horizon-Location'], url)
