@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -32,24 +34,34 @@ shouldn't need to understand the finer details of APIs for
 Keystone/Nova/Glance/Swift et. al.
 """
 from openstack_dashboard.api import base
+from openstack_dashboard.api import ceilometer
 from openstack_dashboard.api import cinder
+from openstack_dashboard.api import fwaas
 from openstack_dashboard.api import glance
+from openstack_dashboard.api import heat
 from openstack_dashboard.api import keystone
+from openstack_dashboard.api import lbaas
 from openstack_dashboard.api import network
 from openstack_dashboard.api import neutron
 from openstack_dashboard.api import nova
-from openstack_dashboard.api import placement
 from openstack_dashboard.api import swift
+from openstack_dashboard.api import trove
+from openstack_dashboard.api import vpn
 
 
 __all__ = [
     "base",
     "cinder",
+    "fwaas",
     "glance",
+    "heat",
     "keystone",
+    "lbaas",
     "network",
     "neutron",
     "nova",
-    "placement",
     "swift",
+    "ceilometer",
+    "trove",
+    "vpn",
 ]
