@@ -78,7 +78,7 @@ class BaseCinderAPIResourceWrapper(base.APIResourceWrapper):
 class Volume(BaseCinderAPIResourceWrapper):
 
     _attrs = ['id', 'name', 'description', 'size', 'status', 'created_at',
-              'volume_type', 'availability_zone', 'imageRef', 'bootable'
+              'volume_type', 'availability_zone', 'imageRef', 'bootable',
               'snapshot_id', 'source_volid', 'attachments', 'tenant_name',
               'os-vol-host-attr:host', 'os-vol-tenant-attr:tenant_id',
               'metadata']
@@ -253,9 +253,16 @@ def tenant_absolute_limits(request):
     limits = cinderclient(request).limits.get().absolute
     limits_dict = {}
     for limit in limits:
-        # -1 is used to represent unlimited quotas
-        if limit.value == -1:
-            limits_dict[limit.name] = float("inf")
+        if limit.value < 0:
+            # In some cases, the absolute limits data in Cinder can get
+            # out of sync causing the total.*Used limits to return
+            # negative values instead of 0. For such cases, replace
+            # negative values with 0.
+            if limit.name.startswith('total') and limit.name.endswith('Used'):
+                limits_dict[limit.name] = 0
+            else:
+                # -1 is used to represent unlimited quotas
+                limits_dict[limit.name] = float("inf")
         else:
             limits_dict[limit.name] = limit.value
     return limits_dict
