@@ -46,7 +46,8 @@ DEFAULT_ROLE = None
 class IdentityAPIVersionManager(base.APIVersionManager):
     def upgrade_v2_user(self, user):
         if getattr(user, "project_id", None) is None:
-            user.project_id = getattr(user, "tenantId", None)
+            user.project_id = getattr(user, "default_project_id",
+                                      getattr(user, "tenantId", None))
         return user
 
     def get_project_manager(self, *args, **kwargs):
@@ -113,9 +114,8 @@ def _get_endpoint_url(request, endpoint_type, catalog=None):
 
     # TODO(gabriel): When the Service Catalog no longer contains API versions
     # in the endpoints this can be removed.
-    bits = urlparse.urlparse(url)
-    root = "://".join((bits.scheme, bits.netloc))
-    url = "%s/v%s" % (root, VERSIONS.active)
+    url = url.rstrip('/')
+    url = urlparse.urljoin(url, 'v%s' % VERSIONS.active)
 
     return url
 
