@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013 NEC Corporation
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -21,10 +23,7 @@ methods defined in this module.
 
 import abc
 
-import six
 
-
-@six.add_metaclass(abc.ABCMeta)
 class FloatingIpManager(object):
     """Abstract class to implement Floating IP methods
 
@@ -40,6 +39,8 @@ class FloatingIpManager(object):
     * instance_id: Instance ID of an associated with the Floating IP
     """
 
+    __metaclass__ = abc.ABCMeta
+
     @abc.abstractmethod
     def list_pools(self):
         """Fetches a list of all floating IP pools.
@@ -71,7 +72,7 @@ class FloatingIpManager(object):
         """Allocates a floating IP to the tenant.
 
         You must provide a pool name or id for which you would like to
-        allocate a floating IP.
+        allocate an floating IP.
         """
         pass
 
@@ -84,14 +85,18 @@ class FloatingIpManager(object):
     def associate(self, floating_ip_id, port_id):
         """Associates the floating IP to the port.
 
-        port_id is a fixed IP of an instance (Nova) or
-        a port_id attached to a VNIC of an instance.
+        port_id is a fixed IP of a instance (Nova) or
+        a port_id attached to a VNIC of a instance.
         """
         pass
 
     @abc.abstractmethod
-    def disassociate(self, floating_ip_id):
-        """Disassociates the floating IP specified."""
+    def disassociate(self, floating_ip_id, port_id):
+        """Disassociates the floating IP from the port.
+
+        port_id is a fixed IP of a instance (Nova) or
+        a port_id attached to a VNIC of a instance.
+        """
         pass
 
     @abc.abstractmethod
@@ -107,30 +112,16 @@ class FloatingIpManager(object):
         pass
 
     @abc.abstractmethod
-    def get_target_id_by_instance(self, instance_id, target_list=None):
-        """Returns a target ID of floating IP association.
-
-        Based on a backend implementation.
-
-        :param instance_id: ID of target VM instance
-        :param target_list: (optional) a list returned by list_targets().
-            If specified, looking up is done against the specified list
-            to save extra API calls to a back-end. Otherwise a target
-            information is retrieved from a back-end inside the method.
+    def get_target_id_by_instance(self, instance_id):
+        """Returns a target ID of floating IP association based on
+        a backend implementation.
         """
         pass
 
     @abc.abstractmethod
-    def list_target_id_by_instance(self, instance_id, target_list=None):
-        """Returns a list of instance's target IDs of floating IP association.
-
-        Based on the backend implementation
-
-        :param instance_id: ID of target VM instance
-        :param target_list: (optional) a list returned by list_targets().
-            If specified, looking up is done against the specified list
-            to save extra API calls to a back-end. Otherwise target list
-            is retrieved from a back-end inside the method.
+    def list_target_id_by_instance(self, instance_id):
+        """Returns a list of instance's target IDs of floating IP association
+        based on the backend implementation
         """
         pass
 
@@ -139,13 +130,7 @@ class FloatingIpManager(object):
         """Returns True if the default floating IP pool is enabled."""
         pass
 
-    @abc.abstractmethod
-    def is_supported(self):
-        """Returns True if floating IP feature is supported."""
-        pass
 
-
-@six.add_metaclass(abc.ABCMeta)
 class SecurityGroupManager(object):
     """Abstract class to implement Security Group methods
 
@@ -170,12 +155,14 @@ class SecurityGroupManager(object):
     * from_port: lower limit of allowed port range (inclusive)
     * to_port: upper limit of allowed port range (inclusive)
     * ip_range: remote IP CIDR (source for ingress, dest for egress).
-      The value should be a format of "{'cidr': <cidr>}"
+    The value should be a format of "{'cidr': <cidr>}"
     * group: remote security group. The value should be a format of
-      "{'name': <secgroup_name>}"
+    "{'name': <secgroup_name>}"
 
     """
 
+    __metaclass__ = abc.ABCMeta
+
     @abc.abstractmethod
     def list(self):
         """Fetches a list all security groups.
