@@ -29,6 +29,9 @@ from django.conf import settings
 from django.utils.datastructures import SortedDict
 from django.utils.translation import ugettext_lazy as _
 
+from neutronclient.common import exceptions as neutron_exc
+from neutronclient.v2_0 import client as neutron_client
+
 from horizon import messages
 from horizon.utils.memoized import memoized  # noqa
 
@@ -36,7 +39,6 @@ from openstack_dashboard.api import base
 from openstack_dashboard.api import network_base
 from openstack_dashboard.api import nova
 
-from neutronclient.v2_0 import client as neutron_client
 
 LOG = logging.getLogger(__name__)
 
@@ -442,6 +444,60 @@ def neutronclient(request):
     return c
 
 
+def list_resources_with_long_filters(list_method,
+                                     filter_attr, filter_values, **params):
+    """List neutron resources with handling RequestURITooLong exception.
+
+    If filter parameters are long, list resources API request leads to
+    414 error (URL is too long). For such case, this method split
+    list parameters specified by a list_field argument into chunks
+    and call the specified list_method repeatedly.
+
+    :param list_method: Method used to retrieve resource list.
+    :param filter_attr: attribute name to be filtered. The value corresponding
+        to this attribute is specified by "filter_values".
+        If you want to specify more attributes for a filter condition,
+        pass them as keyword arguments like "attr2=values2".
+    :param filter_values: values of "filter_attr" to be filtered.
+        If filter_values are too long and the total URI lenght exceed the
+        maximum lenght supported by the neutron server, filter_values will
+        be split into sub lists if filter_values is a list.
+    :param params: parameters to pass a specified listing API call
+        without any changes. You can specify more filter conditions
+        in addition to a pair of filter_attr and filter_values.
+    """
+    try:
+        params[filter_attr] = filter_values
+        return list_method(**params)
+    except neutron_exc.RequestURITooLong as uri_len_exc:
+        # The URI is too long because of too many filter values.
+        # Use the excess attribute of the exception to know how many
+        # filter values can be inserted into a single request.
+
+        # We consider only the filter condition from (filter_attr,
+        # filter_values) and do not consider other filter conditions
+        # which may be specified in **params.
+        if type(filter_values) != list:
+            filter_values = [filter_values]
+
+        # Length of each query filter is:
+        # <key>=<value>& (e.g., id=<uuid>)
+        # The length will be key_len + value_maxlen + 2
+        all_filter_len = sum(len(filter_attr) + len(val) + 2
+                             for val in filter_values)
+        allowed_filter_len = all_filter_len - uri_len_exc.excess
+
+        val_maxlen = max(len(val) for val in filter_values)
+        filter_maxlen = len(filter_attr) + val_maxlen + 2
+        chunk_size = allowed_filter_len / filter_maxlen
+
+        resources = []
+        for i in range(0, len(filter_values), chunk_size):
+            params[filter_attr] = filter_values[i:i + chunk_size]
+            resources.extend(list_method(**params))
+        return resources
+
+
 def network_list(request, **params):
     LOG.debug("network_list(): params=%s" % (params))
     networks = neutronclient(request).list_networks(**params).get('networks')
@@ -485,6 +541,7 @@ def network_get(request, network_id, expand_subnet=True, **params):
     if expand_subnet:
         network['subnets'] = [subnet_get(request, sid)
                               for sid in network['subnets']]
+
     return Network(network)
 
 
@@ -745,7 +802,7 @@ def provider_list(request):
     return providers['service_providers']
 
 
-def servers_update_addresses(request, servers):
+def servers_update_addresses(request, servers, all_tenants=False):
     """Retrieve servers networking information from Neutron if enabled.
 
        Should be used when up to date networking information is required,
@@ -754,12 +811,19 @@ def servers_update_addresses(request, servers):
 
     # Get all (filtered for relevant servers) information from Neutron
     try:
-        ports = port_list(request,
-                          device_id=[instance.id for instance in servers])
-        floating_ips = FloatingIpManager(request).list(
-            port_id=[port.id for port in ports])
-        networks = network_list(request,
-                                id=[port.network_id for port in ports])
+        ports = list_resources_with_long_filters(
+            port_list, 'device_id', [instance.id for instance in servers],
+            request=request)
+        fips = FloatingIpManager(request)
+        if fips.is_supported():
+            floating_ips = list_resources_with_long_filters(
+                fips.list, 'port_id', [port.id for port in ports],
+                all_tenants=all_tenants)
+        else:
+            floating_ips = []
+        networks = list_resources_with_long_filters(
+            network_list, 'id', set([port.network_id for port in ports]),
+            request=request)
     except Exception:
         error_message = _('Unable to connect to Neutron.')
         LOG.error(error_message)
