@@ -24,8 +24,9 @@ from __future__ import absolute_import
 
 import logging
 
-from django.conf import settings  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.conf import settings
+from django.utils.functional import cached_property  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from novaclient.v1_1 import client as nova_client
 from novaclient.v1_1.contrib import list_extensions as nova_list_extensions
@@ -34,6 +35,7 @@ from novaclient.v1_1 import security_groups as nova_security_groups
 from novaclient.v1_1 import servers as nova_servers
 
 from horizon import conf
+from horizon.utils import functions as utils
 from horizon.utils.memoized import memoized  # noqa
 
 from openstack_dashboard.api import base
@@ -63,6 +65,13 @@ class SPICEConsole(base.APIDictWrapper):
     _attrs = ['url', 'type']
 
 
+class RDPConsole(base.APIDictWrapper):
+    """Wrapper for the "console" dictionary returned by the
+    novaclient.servers.get_rdp_console method.
+    """
+    _attrs = ['url', 'type']
+
+
 class Server(base.APIResourceWrapper):
     """Simple wrapper around novaclient.server.Server
 
@@ -71,10 +80,11 @@ class Server(base.APIResourceWrapper):
     """
     _attrs = ['addresses', 'attrs', 'id', 'image', 'links',
              'metadata', 'name', 'private_ip', 'public_ip', 'status', 'uuid',
-             'image_name', 'VirtualInterfaces', 'flavor', 'key_name',
-             'tenant_id', 'user_id', 'OS-EXT-STS:power_state',
+             'image_name', 'VirtualInterfaces', 'flavor', 'key_name', 'fault',
+             'tenant_id', 'user_id', 'created', 'OS-EXT-STS:power_state',
              'OS-EXT-STS:task_state', 'OS-EXT-SRV-ATTR:instance_name',
-             'OS-EXT-SRV-ATTR:host', 'created']
+             'OS-EXT-SRV-ATTR:host', 'OS-EXT-AZ:availability_zone',
+             'OS-DCF:diskConfig']
 
     def __init__(self, apiresource, request):
         super(Server, self).__init__(apiresource)
@@ -102,6 +112,10 @@ class Server(base.APIResourceWrapper):
     def internal_name(self):
         return getattr(self, 'OS-EXT-SRV-ATTR:instance_name', "")
 
+    @property
+    def availability_zone(self):
+        return getattr(self, 'OS-EXT-AZ:availability_zone', "")
+
 
 class NovaUsage(base.APIResourceWrapper):
     """Simple wrapper around contrib/simple_usage.py."""
@@ -151,19 +165,17 @@ class SecurityGroup(base.APIResourceWrapper):
     """
     _attrs = ['id', 'name', 'description', 'tenant_id']
 
-    @property
+    @cached_property
     def rules(self):
         """Wraps transmitted rule info in the novaclient rule class."""
-        if "_rules" not in self.__dict__:
-            manager = nova_rules.SecurityGroupRuleManager(None)
-            rule_objs = [nova_rules.SecurityGroupRule(manager, rule)
-                         for rule in self._apiresource.rules]
-            self._rules = [SecurityGroupRule(rule) for rule in rule_objs]
-        return self.__dict__['_rules']
+        manager = nova_rules.SecurityGroupRuleManager(None)
+        rule_objs = [nova_rules.SecurityGroupRule(manager, rule)
+                     for rule in self._apiresource.rules]
+        return [SecurityGroupRule(rule) for rule in rule_objs]
 
 
 class SecurityGroupRule(base.APIResourceWrapper):
-    """ Wrapper for individual rules in a SecurityGroup. """
+    """Wrapper for individual rules in a SecurityGroup."""
     _attrs = ['id', 'ip_protocol', 'from_port', 'to_port', 'ip_range', 'group']
 
     def __unicode__(self):
@@ -350,6 +362,9 @@ class FloatingIpManager(network_base.FloatingIpManager):
     def get_target_id_by_instance(self, instance_id):
         return instance_id
 
+    def list_target_id_by_instance(self, instance_id):
+        return [instance_id, ]
+
     def is_simple_associate_supported(self):
         return conf.HORIZON_CONFIG["simple_ip_management"]
 
@@ -381,6 +396,11 @@ def server_spice_console(request, instance_id, console_type='spice-html5'):
         instance_id, console_type)['console'])
 
 
+def server_rdp_console(request, instance_id, console_type='rdp-html5'):
+    return RDPConsole(novaclient(request).servers.get_rdp_console(
+        instance_id, console_type)['console'])
+
+
 def flavor_create(request, name, memory, vcpu, disk, flavorid='auto',
                   ephemeral=0, swap=0, metadata=None, is_public=True):
     flavor = novaclient(request).flavors.create(name, memory, vcpu, disk,
@@ -471,14 +491,16 @@ def keypair_list(request):
 def server_create(request, name, image, flavor, key_name, user_data,
                   security_groups, block_device_mapping=None,
                   block_device_mapping_v2=None, nics=None,
-                  availability_zone=None, instance_count=1, admin_pass=None):
+                  availability_zone=None, instance_count=1, admin_pass=None,
+                  disk_config=None):
     return Server(novaclient(request).servers.create(
         name, image, flavor, userdata=user_data,
         security_groups=security_groups,
         key_name=key_name, block_device_mapping=block_device_mapping,
         block_device_mapping_v2=block_device_mapping_v2,
         nics=nics, availability_zone=availability_zone,
-        min_count=instance_count, admin_pass=admin_pass), request)
+        min_count=instance_count, admin_pass=admin_pass,
+        disk_config=disk_config), request)
 
 
 def server_delete(request, instance):
@@ -490,9 +512,8 @@ def server_get(request, instance_id):
 
 
 def server_list(request, search_opts=None, all_tenants=False):
-    page_size = request.session.get('horizon_pagesize',
-                                    getattr(settings, 'API_RESULT_PAGE_SIZE',
-                                            20))
+    page_size = utils.get_page_size(request)
+    c = novaclient(request)
     paginate = False
     if search_opts is None:
         search_opts = {}
@@ -506,7 +527,7 @@ def server_list(request, search_opts=None, all_tenants=False):
     else:
         search_opts['project_id'] = request.user.tenant_id
     servers = [Server(s, request)
-                for s in novaclient(request).servers.list(True, search_opts)]
+                for s in c.servers.list(True, search_opts)]
 
     has_more_data = False
     if paginate and len(servers) > page_size:
@@ -547,9 +568,10 @@ def server_reboot(request, instance_id, soft_reboot=False):
     novaclient(request).servers.reboot(instance_id, hardness)
 
 
-def server_rebuild(request, instance_id, image_id, password=None):
+def server_rebuild(request, instance_id, image_id, password=None,
+                   disk_config=None):
     return novaclient(request).servers.rebuild(instance_id, image_id,
-                                               password)
+                                               password, disk_config)
 
 
 def server_update(request, instance_id, name):
@@ -560,8 +582,16 @@ def server_migrate(request, instance_id):
     novaclient(request).servers.migrate(instance_id)
 
 
-def server_resize(request, instance_id, flavor, **kwargs):
-    novaclient(request).servers.resize(instance_id, flavor, **kwargs)
+def server_live_migrate(request, instance_id, host, block_migration=False,
+                        disk_over_commit=False):
+    novaclient(request).servers.live_migrate(instance_id, host,
+                                             block_migration,
+                                             disk_over_commit)
+
+
+def server_resize(request, instance_id, flavor, disk_config=None, **kwargs):
+    novaclient(request).servers.resize(instance_id, flavor,
+                                       disk_config, **kwargs)
 
 
 def server_confirm_resize(request, instance_id):
@@ -592,10 +622,6 @@ def default_quota_get(request, tenant_id):
     return base.QuotaSet(novaclient(request).quotas.defaults(tenant_id))
 
 
-def default_quota_update(request, **kwargs):
-    novaclient(request).quota_classes.update(DEFAULT_QUOTA_NAME, **kwargs)
-
-
 def usage_get(request, tenant_id, start, end):
     return NovaUsage(novaclient(request).usage.get(tenant_id, start, end))
 
@@ -617,6 +643,10 @@ def get_x509_root_certificate(request):
     return novaclient(request).certs.get()
 
 
+def get_password(request, instance_id, private_key=None):
+    return novaclient(request).servers.get_password(instance_id, private_key)
+
+
 def instance_volume_attach(request, volume_id, instance_id, device):
     return novaclient(request).volumes.create_server_volume(instance_id,
                                                               volume_id,
@@ -648,13 +678,23 @@ def hypervisor_stats(request):
     return novaclient(request).hypervisors.statistics()
 
 
+def hypervisor_search(request, query, servers=True):
+    return novaclient(request).hypervisors.search(query, servers)
+
+
 def tenant_absolute_limits(request, reserved=False):
     limits = novaclient(request).limits.get(reserved=reserved).absolute
     limits_dict = {}
     for limit in limits:
-        # -1 is used to represent unlimited quotas
-        if limit.value == -1:
-            limits_dict[limit.name] = float("inf")
+        if limit.value < 0:
+            # Workaround for nova bug 1370867 that absolute_limits
+            # returns negative value for total.*Used instead of 0.
+            # For such case, replace negative values with 0.
+            if limit.name.startswith('total') and limit.name.endswith('Used'):
+                limits_dict[limit.name] = 0
+            else:
+                # -1 is used to represent unlimited quotas
+                limits_dict[limit.name] = float("inf")
         else:
             limits_dict[limit.name] = limit.value
     return limits_dict
@@ -668,15 +708,42 @@ def service_list(request):
     return novaclient(request).services.list()
 
 
-def aggregate_list(request):
+def aggregate_details_list(request):
     result = []
     c = novaclient(request)
     for aggregate in c.aggregates.list():
         result.append(c.aggregates.get_details(aggregate.id))
-
     return result
 
 
+def aggregate_create(request, name, availability_zone=None):
+    return novaclient(request).aggregates.create(name, availability_zone)
+
+
+def aggregate_delete(request, aggregate_id):
+    return novaclient(request).aggregates.delete(aggregate_id)
+
+
+def aggregate_get(request, aggregate_id):
+    return novaclient(request).aggregates.get(aggregate_id)
+
+
+def aggregate_update(request, aggregate_id, values):
+    return novaclient(request).aggregates.update(aggregate_id, values)
+
+
+def host_list(request):
+    return novaclient(request).hosts.list()
+
+
+def add_host_to_aggregate(request, aggregate_id, host):
+    return novaclient(request).aggregates.add_host(aggregate_id, host)
+
+
+def remove_host_from_aggregate(request, aggregate_id, host):
+    return novaclient(request).aggregates.remove_host(aggregate_id, host)
+
+
 @memoized
 def list_extensions(request):
     return nova_list_extensions.ListExtManager(novaclient(request)).show_all()
@@ -684,8 +751,7 @@ def list_extensions(request):
 
 @memoized
 def extension_supported(extension_name, request):
-    """
-    this method will determine if nova supports a given extension name.
+    """this method will determine if nova supports a given extension name.
     example values for the extension_name include AdminActions, ConsoleOutput,
     etc.
     """
@@ -694,3 +760,8 @@ def extension_supported(extension_name, request):
         if extension.name == extension_name:
             return True
     return False
+
+
+def can_set_server_password():
+    features = getattr(settings, 'OPENSTACK_HYPERVISOR_FEATURES', {})
+    return features.get('can_set_password', False)
