@@ -20,26 +20,30 @@
 
 import logging
 
+import six.moves.urllib.parse as urlparse
 import swiftclient
 
 from django.conf import settings
-
-from horizon import exceptions
-from horizon import messages
 from django.utils.translation import ugettext_lazy as _
 
-from openstack_dashboard.api.base import url_for, APIDictWrapper
+from horizon import exceptions
+
+from openstack_dashboard.api import base
+from openstack_dashboard.openstack.common import timeutils
 
 
 LOG = logging.getLogger(__name__)
 FOLDER_DELIMITER = "/"
+# Swift ACL
+GLOBAL_READ_ACL = ".r:*"
+LIST_CONTENTS_ACL = ".rlistings"
 
 
-class Container(APIDictWrapper):
+class Container(base.APIDictWrapper):
     pass
 
 
-class StorageObject(APIDictWrapper):
+class StorageObject(base.APIDictWrapper):
     def __init__(self, apidict, container_name, orig_name=None, data=None):
         super(StorageObject, self).__init__(apidict)
         self.container_name = container_name
@@ -51,7 +55,7 @@ class StorageObject(APIDictWrapper):
         return self.name
 
 
-class PseudoFolder(APIDictWrapper):
+class PseudoFolder(base.APIDictWrapper):
     def __init__(self, apidict, container_name):
         super(PseudoFolder, self).__init__(apidict)
         self.container_name = container_name
@@ -74,7 +78,7 @@ class PseudoFolder(APIDictWrapper):
 
 
 def _objectify(items, container_name):
-    """ Splits a listing of objects into their appropriate wrapper classes. """
+    """Splits a listing of objects into their appropriate wrapper classes."""
     objects = []
 
     # Deal with objects and object pseudo-folders first, save subdirs for later
@@ -89,8 +93,22 @@ def _objectify(items, container_name):
     return objects
 
 
+def _metadata_to_header(metadata):
+    headers = {}
+    public = metadata.get('is_public')
+
+    if public is True:
+        public_container_acls = [GLOBAL_READ_ACL, LIST_CONTENTS_ACL]
+        headers['x-container-read'] = ",".join(public_container_acls)
+    elif public is False:
+        headers['x-container-read'] = ""
+
+    return headers
+
+
 def swift_api(request):
-    endpoint = url_for(request, 'object-store')
+    endpoint = base.url_for(request, 'object-store')
+    cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
     LOG.debug('Swift connection created using token "%s" and url "%s"'
               % (request.user.token.id, endpoint))
     return swiftclient.client.Connection(None,
@@ -98,6 +116,7 @@ def swift_api(request):
                                          None,
                                          preauthtoken=request.user.token.id,
                                          preauthurl=endpoint,
+                                         cacert=cacert,
                                          auth_version="2.0")
 
 
@@ -129,10 +148,49 @@ def swift_get_containers(request, marker=None):
         return (container_objs, False)
 
 
-def swift_create_container(request, name):
+def swift_get_container(request, container_name, with_data=True):
+    if with_data:
+        headers, data = swift_api(request).get_object(container_name, "")
+    else:
+        data = None
+        headers = swift_api(request).head_container(container_name)
+    timestamp = None
+    is_public = False
+    public_url = None
+    try:
+        is_public = GLOBAL_READ_ACL in headers.get('x-container-read', '')
+        if is_public:
+            swift_endpoint = base.url_for(request,
+                                          'object-store',
+                                          endpoint_type='publicURL')
+            public_url = swift_endpoint + '/' + urlparse.quote(container_name)
+        ts_float = float(headers.get('x-timestamp'))
+        timestamp = timeutils.iso8601_from_timestamp(ts_float)
+    except Exception:
+        pass
+    container_info = {
+        'name': container_name,
+        'container_object_count': headers.get('x-container-object-count'),
+        'container_bytes_used': headers.get('x-container-bytes-used'),
+        'timestamp': timestamp,
+        'data': data,
+        'is_public': is_public,
+        'public_url': public_url,
+    }
+    return Container(container_info)
+
+
+def swift_create_container(request, name, metadata=({})):
     if swift_container_exists(request, name):
         raise exceptions.AlreadyExists(name, 'container')
-    swift_api(request).put_container(name)
+    headers = _metadata_to_header(metadata)
+    swift_api(request).put_container(name, headers=headers)
+    return Container({'name': name})
+
+
+def swift_update_container(request, name, metadata=({})):
+    headers = _metadata_to_header(metadata)
+    swift_api(request).post_container(name, headers=headers)
     return Container({'name': name})
 
 
@@ -141,9 +199,11 @@ def swift_delete_container(request, name):
     # be done in swiftclient instead of Horizon.
     objects, more = swift_get_objects(request, name)
     if objects:
-        messages.warning(request,
-            _("The container cannot be deleted since it's not empty."))
-        return False
+        error_msg = unicode(_("The container cannot be deleted "
+                              "since it's not empty."))
+        exc = exceptions.Conflict(error_msg)
+        exc._safe_message = error_msg
+        raise exc
     swift_api(request).delete_container(name)
     return True
 
@@ -214,26 +274,64 @@ def swift_copy_object(request, orig_container_name, orig_object_name,
                                          headers=headers)
 
 
-def swift_upload_object(request, container_name, object_name, object_file):
+def swift_upload_object(request, container_name, object_name,
+                        object_file=None):
     headers = {}
-    headers['X-Object-Meta-Orig-Filename'] = object_file.name
+    size = 0
+    if object_file:
+        headers['X-Object-Meta-Orig-Filename'] = object_file.name
+        size = object_file.size
+
     etag = swift_api(request).put_object(container_name,
                                          object_name,
                                          object_file,
                                          headers=headers)
-    obj_info = {'name': object_name, 'bytes': object_file.size, 'etag': etag}
+
+    obj_info = {'name': object_name, 'bytes': size, 'etag': etag}
     return StorageObject(obj_info, container_name)
 
 
+def swift_create_pseudo_folder(request, container_name, pseudo_folder_name):
+    headers = {}
+    etag = swift_api(request).put_object(container_name,
+                                         pseudo_folder_name,
+                                         None,
+                                         headers=headers)
+    obj_info = {
+        'name': pseudo_folder_name,
+        'etag': etag
+    }
+
+    return PseudoFolder(obj_info, container_name)
+
+
 def swift_delete_object(request, container_name, object_name):
     swift_api(request).delete_object(container_name, object_name)
     return True
 
 
-def swift_get_object(request, container_name, object_name):
-    headers, data = swift_api(request).get_object(container_name, object_name)
+def swift_get_object(request, container_name, object_name, with_data=True):
+    if with_data:
+        headers, data = swift_api(request).get_object(container_name,
+                                                      object_name)
+    else:
+        data = None
+        headers = swift_api(request).head_object(container_name,
+                                                 object_name)
     orig_name = headers.get("x-object-meta-orig-filename")
-    obj_info = {'name': object_name, 'bytes': len(data)}
+    timestamp = None
+    try:
+        ts_float = float(headers.get('x-timestamp'))
+        timestamp = timeutils.iso8601_from_timestamp(ts_float)
+    except Exception:
+        pass
+    obj_info = {
+        'name': object_name,
+        'bytes': headers.get('content-length'),
+        'content_type': headers.get('content-type'),
+        'etag': headers.get('etag'),
+        'timestamp': timestamp,
+    }
     return StorageObject(obj_info,
                          container_name,
                          orig_name=orig_name,
