@@ -21,11 +21,11 @@
 Context processors used by Horizon.
 """
 
-from django.conf import settings  # noqa
+from django.conf import settings
 
 
 def openstack(request):
-    """ Context processor necessary for OpenStack Dashboard functionality.
+    """Context processor necessary for OpenStack Dashboard functionality.
 
     The following variables are added to the request context:
 
@@ -41,9 +41,7 @@ def openstack(request):
 
     # Auth/Keystone context
     context.setdefault('authorized_tenants', [])
-    current_dash = request.horizon['dashboard']
-    needs_tenants = getattr(current_dash, 'supports_tenants', False)
-    if request.user.is_authenticated() and needs_tenants:
+    if request.user.is_authenticated():
         context['authorized_tenants'] = request.user.authorized_tenants
 
     # Region context/support
