@@ -16,10 +16,10 @@
 
 import logging
 
-from django.conf import settings  # noqa
-from django.core.urlresolvers import reverse  # noqa
-from django.utils.http import urlencode  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.conf import settings
+from django.core.urlresolvers import reverse
+from django.utils.http import urlencode
+from django.utils.translation import ugettext_lazy as _
 
 from keystoneclient import exceptions
 
@@ -98,7 +98,7 @@ class DomainFilterAction(tables.FilterAction):
         return multidomain_support
 
     def filter(self, table, domains, filter_string):
-        """ Naive case-insensitive search """
+        """Naive case-insensitive search."""
         q = filter_string.lower()
 
         def comp(domain):
