@@ -14,7 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse  # noqa
+from django.core.urlresolvers import reverse
 from django import http
 from mox import IsA  # noqa
 
@@ -35,3 +35,17 @@ class HypervisorViewTest(test.BaseAdminViewTests):
         res = self.client.get(reverse('horizon:admin:hypervisors:index'))
         self.assertTemplateUsed(res, 'admin/hypervisors/index.html')
         self.assertItemsEqual(res.context['table'].data, hypervisors)
+
+
+class HypervisorDetailViewTest(test.BaseAdminViewTests):
+    @test.create_stubs({api.nova: ('hypervisor_search',)})
+    def test_index(self):
+        hypervisor = self.hypervisors.list().pop().hypervisor_hostname
+        api.nova.hypervisor_search(
+            IsA(http.HttpRequest), hypervisor).AndReturn([])
+        self.mox.ReplayAll()
+
+        url = reverse('horizon:admin:hypervisors:detail', args=[hypervisor])
+        res = self.client.get(url)
+        self.assertTemplateUsed(res, 'admin/hypervisors/detail.html')
+        self.assertItemsEqual(res.context['table'].data, [])
