@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013 B1 Systems GmbH
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,18 +14,16 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import include
-from django.urls import re_path
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from openstack_dashboard.dashboards.admin.hypervisors.compute \
-    import urls as compute_urls
 from openstack_dashboard.dashboards.admin.hypervisors import views
 
 
-urlpatterns = [
-    re_path(r'^(?P<hypervisor>[^/]+)/$',
-            views.AdminDetailView.as_view(),
-            name='detail'),
-    re_path(r'^$', views.AdminIndexView.as_view(), name='index'),
-    re_path(r'', include((compute_urls, 'compute'))),
-]
+urlpatterns = patterns(
+    'openstack_dashboard.dashboards.admin.hypervisors.views',
+    url(r'^(?P<hypervisor>[^/]+)/$',
+        views.AdminDetailView.as_view(),
+        name='detail'),
+    url(r'^$', views.AdminIndexView.as_view(), name='index')
+)
