@@ -18,8 +18,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from openstack_dashboard.dashboards.project.images_and_snapshots \
-    .images import forms
+from openstack_dashboard.dashboards.project.images.images import forms
 
 
 class AdminCreateImageForm(forms.CreateImageForm):
