@@ -18,34 +18,47 @@ from django.utils.translation import ugettext_lazy as _
 
 from horizon import tables
 
-from openstack_dashboard.dashboards.project.images_and_snapshots \
-        .images.tables import (ImagesTable, CreateImage, EditImage,
-                DeleteImage)
+from openstack_dashboard import api
+from openstack_dashboard.dashboards.project.images.images \
+    import tables as project_tables
 
 
-class AdminCreateImage(CreateImage):
+class AdminCreateImage(project_tables.CreateImage):
     url = "horizon:admin:images:create"
 
 
-class AdminDeleteImage(DeleteImage):
+class AdminDeleteImage(project_tables.DeleteImage):
     def allowed(self, request, image=None):
-        return True
+        if image and image.protected:
+            return False
+        else:
+            return True
 
 
-class AdminEditImage(EditImage):
+class AdminEditImage(project_tables.EditImage):
     url = "horizon:admin:images:update"
 
     def allowed(self, request, image=None):
         return True
 
 
-class AdminImagesTable(ImagesTable):
+class UpdateRow(tables.Row):
+    ajax = True
+
+    def get_data(self, request, image_id):
+        image = api.glance.image_get(request, image_id)
+        return image
+
+
+class AdminImagesTable(project_tables.ImagesTable):
     name = tables.Column("name",
                          link="horizon:admin:images:detail",
                          verbose_name=_("Image Name"))
 
     class Meta:
         name = "images"
+        row_class = UpdateRow
+        status_columns = ["status"]
         verbose_name = _("Images")
         table_actions = (AdminCreateImage, AdminDeleteImage)
         row_actions = (AdminEditImage, AdminDeleteImage)
