@@ -14,15 +14,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django import http
 from django.conf import settings
 from django.core.urlresolvers import reverse
+from django import http
 from django.test.utils import override_settings
-from mox import IsA
+
+from mox import IsA  # noqa
 
 from openstack_dashboard import api
 from openstack_dashboard.test import helpers as test
-from .tables import AdminImagesTable
+
+from openstack_dashboard.dashboards.admin.images import tables
 
 
 class ImageCreateViewTest(test.BaseAdminViewTests):
@@ -35,15 +37,17 @@ class ImageCreateViewTest(test.BaseAdminViewTests):
 class ImagesViewTest(test.BaseAdminViewTests):
     @test.create_stubs({api.glance: ('image_list_detailed',)})
     def test_images_list(self):
+        filters = {'is_public': None}
         api.glance.image_list_detailed(IsA(http.HttpRequest),
                                        marker=None,
-                                       paginate=True) \
-                                .AndReturn([self.images.list(),
-                                            False])
+                                       paginate=True,
+                                       filters=filters) \
+            .AndReturn([self.images.list(),
+                        False])
         self.mox.ReplayAll()
 
         res = self.client.get(
-                reverse('horizon:admin:images:index'))
+            reverse('horizon:admin:images:index'))
         self.assertTemplateUsed(res, 'admin/images/index.html')
         self.assertEqual(len(res.context['images_table'].data),
                          len(self.images.list()))
@@ -52,25 +56,29 @@ class ImagesViewTest(test.BaseAdminViewTests):
     @test.create_stubs({api.glance: ('image_list_detailed',)})
     def test_images_list_get_pagination(self):
         images = self.images.list()[:5]
-
+        filters = {'is_public': None}
         api.glance.image_list_detailed(IsA(http.HttpRequest),
                                        marker=None,
-                                       paginate=True) \
+                                       paginate=True,
+                                       filters=filters) \
                                 .AndReturn([images,
                                             True])
         api.glance.image_list_detailed(IsA(http.HttpRequest),
                                        marker=None,
-                                       paginate=True) \
+                                       paginate=True,
+                                       filters=filters) \
                                 .AndReturn([images[:2],
                                             True])
         api.glance.image_list_detailed(IsA(http.HttpRequest),
                                        marker=images[2].id,
-                                       paginate=True) \
+                                       paginate=True,
+                                       filters=filters) \
                                 .AndReturn([images[2:4],
                                             True])
         api.glance.image_list_detailed(IsA(http.HttpRequest),
                                        marker=images[4].id,
-                                       paginate=True) \
+                                       paginate=True,
+                                       filters=filters) \
                                 .AndReturn([images[4:],
                                             True])
         self.mox.ReplayAll()
@@ -88,16 +96,16 @@ class ImagesViewTest(test.BaseAdminViewTests):
                          settings.API_RESULT_PAGE_SIZE)
 
         url = "?".join([reverse('horizon:admin:images:index'),
-                        "=".join([AdminImagesTable._meta.pagination_param,
-                                  images[2].id])])
+                    "=".join([tables.AdminImagesTable._meta.pagination_param,
+                              images[2].id])])
         res = self.client.get(url)
         # get second page (items 2-4)
         self.assertEqual(len(res.context['images_table'].data),
                          settings.API_RESULT_PAGE_SIZE)
 
         url = "?".join([reverse('horizon:admin:images:index'),
-                        "=".join([AdminImagesTable._meta.pagination_param,
-                                  images[4].id])])
+                    "=".join([tables.AdminImagesTable._meta.pagination_param,
+                              images[4].id])])
         res = self.client.get(url)
         # get third page (item 5)
         self.assertEqual(len(res.context['images_table'].data),
