@@ -1,6 +1,18 @@
+# Licensed under the Apache License, Version 2.0 (the "License"); you may
+# not use this file except in compliance with the License. You may obtain
+# a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+# License for the specific language governing permissions and limitations
+# under the License.
+
 from django import template
 from django.template import defaultfilters as filters
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import tables
 from horizon.utils import filters as utils_filters
@@ -34,7 +46,7 @@ def get_enabled(service, reverse=False):
 
 
 class ServicesTable(tables.DataTable):
-    id = tables.Column('id', verbose_name=_('Id'), hidden=True)
+    id = tables.Column('id', hidden=True)
     name = tables.Column("name", verbose_name=_('Name'))
     service_type = tables.Column('__unicode__', verbose_name=_('Service'))
     host = tables.Column('host', verbose_name=_('Host'))
@@ -54,39 +66,6 @@ def get_available(zone):
     return zone.zoneState['available']
 
 
-def get_hosts(zone):
-    hosts = zone.hosts
-    host_details = []
-    if hosts is None:
-        return []
-    for name, services in hosts.items():
-        up = all(s['active'] and s['available'] for s in services.values())
-        up = _("Services Up") if up else _("Services Down")
-        host_details.append("%(host)s (%(up)s)" % {'host': name, 'up': up})
-    return host_details
-
-
-class ZonesTable(tables.DataTable):
-    name = tables.Column('zoneName', verbose_name=_('Name'))
-    hosts = tables.Column(get_hosts,
-                          verbose_name=_('Hosts'),
-                          wrap_list=True,
-                          filters=(filters.unordered_list,))
-    available = tables.Column(get_available,
-                              verbose_name=_('Available'),
-                              status=True,
-                              filters=(filters.yesno, filters.capfirst))
-
-    def get_object_id(self, zone):
-        return zone.zoneName
-
-    class Meta:
-        name = "zones"
-        verbose_name = _("Availability Zones")
-        multi_select = False
-        status_columns = ["available"]
-
-
 class NovaServiceFilterAction(tables.FilterAction):
     def filter(self, table, services, filter_string):
         q = filter_string.lower()
@@ -120,38 +99,6 @@ class NovaServicesTable(tables.DataTable):
         multi_select = False
 
 
-def get_hosts(aggregate):
-    return [host for host in aggregate.hosts]
-
-
-def get_metadata(aggregate):
-    return [' = '.join([key, val]) for key, val
-            in aggregate.metadata.iteritems()]
-
-
-def safe_unordered_list(value):
-    return filters.unordered_list(value, autoescape=True)
-
-
-class AggregatesTable(tables.DataTable):
-    name = tables.Column("name",
-                         verbose_name=_("Name"))
-    availability_zone = tables.Column("availability_zone",
-                                      verbose_name=_("Availability Zone"))
-    hosts = tables.Column(get_hosts,
-                          verbose_name=_("Hosts"),
-                          wrap_list=True,
-                          filters=(safe_unordered_list,))
-    metadata = tables.Column(get_metadata,
-                             verbose_name=_("Metadata"),
-                             wrap_list=True,
-                             filters=(safe_unordered_list,))
-
-    class Meta:
-        name = "aggregates"
-        verbose_name = _("Host Aggregates")
-
-
 class NetworkAgentsFilterAction(tables.FilterAction):
     def filter(self, table, agents, filter_string):
         q = filter_string.lower()
@@ -197,3 +144,55 @@ class NetworkAgentsTable(tables.DataTable):
         verbose_name = _("Network Agents")
         table_actions = (NetworkAgentsFilterAction,)
         multi_select = False
+
+
+class QuotaFilterAction(tables.FilterAction):
+    def filter(self, table, tenants, filter_string):
+        q = filter_string.lower()
+
+        def comp(tenant):
+            if q in tenant.name.lower():
+                return True
+            return False
+
+        return filter(comp, tenants)
+
+
+def get_quota_name(quota):
+    QUOTA_NAMES = {
+        'injected_file_content_bytes': _('Injected File Content Bytes'),
+        'injected_file_path_bytes': _('Injected File Path Bytes'),
+        'metadata_items': _('Metadata Items'),
+        'cores': _('VCPUs'),
+        'instances': _('Instances'),
+        'injected_files': _('Injected Files'),
+        'volumes': _('Volumes'),
+        'snapshots': _('Volume Snapshots'),
+        'gigabytes': _('Total Size of Volumes and Snapshots (GB)'),
+        'ram': _('RAM (MB)'),
+        'floating_ips': _('Floating IPs'),
+        'security_groups': _('Security Groups'),
+        'security_group_rules': _('Security Group Rules'),
+        'key_pairs': _('Key Pairs'),
+        'fixed_ips': _('Fixed IPs'),
+        'volumes_volume_luks': _('LUKS Volumes'),
+        'snapshots_volume_luks': _('LUKS Volume Snapshots'),
+        'gigabytes_volume_luks':
+        _('Total Size of LUKS Volumes and Snapshots (GB)'),
+        'dm-crypt': _('dm-crypt'),
+    }
+    return QUOTA_NAMES.get(quota.name, quota.name.replace("_", " ").title())
+
+
+class QuotasTable(tables.DataTable):
+    name = tables.Column(get_quota_name, verbose_name=_('Quota Name'))
+    limit = tables.Column("limit", verbose_name=_('Limit'))
+
+    def get_object_id(self, obj):
+        return obj.name
+
+    class Meta:
+        name = "quotas"
+        verbose_name = _("Quotas")
+        table_actions = (QuotaFilterAction,)
+        multi_select = False
