@@ -18,10 +18,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from .views import IndexView
+from openstack_dashboard.dashboards.admin.info import views
 
 
 urlpatterns = patterns('openstack_dashboard.dashboards.admin.info.views',
-    url(r'^$', IndexView.as_view(), name='index'))
+    url(r'^$', views.IndexView.as_view(), name='index'))
