@@ -221,14 +221,14 @@ class InstanceViewTest(test.BaseAdminViewTests):
         self.assertContains(res, "instances__revert")
         self.assertNotContains(res, "instances__migrate")
 
-    @test.create_stubs({api.nova: ('hypervisor_list',
+    @test.create_stubs({api.nova: ('host_list',
                                    'server_get',)})
     def test_instance_live_migrate_get(self):
         server = self.servers.first()
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
                 .AndReturn(server)
-        api.nova.hypervisor_list(IsA(http.HttpRequest)) \
-                .AndReturn(self.hypervisors.list())
+        api.nova.host_list(IsA(http.HttpRequest)) \
+                .AndReturn(self.hosts.list())
 
         self.mox.ReplayAll()
 
@@ -252,13 +252,13 @@ class InstanceViewTest(test.BaseAdminViewTests):
 
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({api.nova: ('hypervisor_list',
+    @test.create_stubs({api.nova: ('host_list',
                                    'server_get',)})
     def test_instance_live_migrate_list_hypervisor_get_exception(self):
         server = self.servers.first()
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
                 .AndReturn(server)
-        api.nova.hypervisor_list(IsA(http.HttpRequest)) \
+        api.nova.host_list(IsA(http.HttpRequest)) \
                 .AndRaise(self.exceptions.nova)
 
         self.mox.ReplayAll()
@@ -268,14 +268,14 @@ class InstanceViewTest(test.BaseAdminViewTests):
 
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({api.nova: ('hypervisor_list',
+    @test.create_stubs({api.nova: ('host_list',
                                    'server_get',)})
     def test_instance_live_migrate_list_hypervisor_without_current(self):
         server = self.servers.first()
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
                 .AndReturn(server)
-        api.nova.hypervisor_list(IsA(http.HttpRequest)) \
-                .AndReturn(self.hypervisors.list())
+        api.nova.host_list(IsA(http.HttpRequest)) \
+                .AndReturn(self.hosts.list())
 
         self.mox.ReplayAll()
 
@@ -283,24 +283,25 @@ class InstanceViewTest(test.BaseAdminViewTests):
                       args=[server.id])
         res = self.client.get(url)
         self.assertNotContains(
-            res, "<option value=\"devstack003\">devstack003</option>")
+            res, "<option value=\"instance-host\">devstack004</option>")
         self.assertContains(
             res, "<option value=\"devstack001\">devstack001</option>")
-        self.assertContains(
+        self.assertNotContains(
             res, "<option value=\"devstack002\">devstack002</option>")
+        self.assertContains(
+            res, "<option value=\"devstack003\">devstack003</option>")
 
-    @test.create_stubs({api.nova: ('hypervisor_list',
+    @test.create_stubs({api.nova: ('host_list',
                                    'server_get',
                                    'server_live_migrate',)})
     def test_instance_live_migrate_post(self):
         server = self.servers.first()
-        hypervisor = self.hypervisors.first()
-        host = hypervisor.hypervisor_hostname
+        host = self.hosts.first().host_name
 
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
                 .AndReturn(server)
-        api.nova.hypervisor_list(IsA(http.HttpRequest)) \
-                .AndReturn(self.hypervisors.list())
+        api.nova.host_list(IsA(http.HttpRequest)) \
+                .AndReturn(self.hosts.list())
         api.nova.server_live_migrate(IsA(http.HttpRequest), server.id, host,
                                      block_migration=False,
                                      disk_over_commit=False) \
@@ -314,18 +315,17 @@ class InstanceViewTest(test.BaseAdminViewTests):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({api.nova: ('hypervisor_list',
+    @test.create_stubs({api.nova: ('host_list',
                                    'server_get',
                                    'server_live_migrate',)})
     def test_instance_live_migrate_post_api_exception(self):
         server = self.servers.first()
-        hypervisor = self.hypervisors.first()
-        host = hypervisor.hypervisor_hostname
+        host = self.hosts.first().host_name
 
         api.nova.server_get(IsA(http.HttpRequest), server.id) \
                 .AndReturn(server)
-        api.nova.hypervisor_list(IsA(http.HttpRequest)) \
-                .AndReturn(self.hypervisors.list())
+        api.nova.host_list(IsA(http.HttpRequest)) \
+                .AndReturn(self.hosts.list())
         api.nova.server_live_migrate(IsA(http.HttpRequest), server.id, host,
                                      block_migration=False,
                                      disk_over_commit=False) \
