@@ -18,19 +18,23 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls.defaults import url, patterns
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from .views import DetailView, AdminIndexView, AdminUpdateView
+from openstack_dashboard.dashboards.admin.instances import views
 
 
 INSTANCES = r'^(?P<instance_id>[^/]+)/%s$'
 
 
 urlpatterns = patterns('openstack_dashboard.dashboards.admin.instances.views',
-    url(r'^$', AdminIndexView.as_view(), name='index'),
-    url(INSTANCES % 'update', AdminUpdateView.as_view(), name='update'),
-    url(INSTANCES % 'detail', DetailView.as_view(), name='detail'),
+    url(r'^$', views.AdminIndexView.as_view(), name='index'),
+    url(INSTANCES % 'update', views.AdminUpdateView.as_view(), name='update'),
+    url(INSTANCES % 'detail', views.DetailView.as_view(), name='detail'),
     url(INSTANCES % 'console', 'console', name='console'),
     url(INSTANCES % 'vnc', 'vnc', name='vnc'),
     url(INSTANCES % 'spice', 'spice', name='spice'),
+    url(INSTANCES % 'rdp', 'rdp', name='rdp'),
+    url(INSTANCES % 'live_migrate', views.LiveMigrateView.as_view(),
+        name='live_migrate'),
 )
