@@ -24,7 +24,8 @@ from horizon import exceptions
 from horizon import tables
 
 from openstack_dashboard import api
-from openstack_dashboard.dashboards.project.networks.tables import get_subnets
+from openstack_dashboard.dashboards.project.networks \
+    import tables as project_tables
 
 
 LOG = logging.getLogger(__name__)
@@ -36,8 +37,8 @@ class DeleteNetwork(tables.DeleteAction):
 
     def delete(self, request, obj_id):
         try:
-            api.quantum.network_delete(request, obj_id)
-        except:
+            api.neutron.network_delete(request, obj_id)
+        except Exception:
             msg = _('Failed to delete network %s') % obj_id
             LOG.info(msg)
             redirect = reverse('horizon:admin:networks:index')
@@ -67,7 +68,7 @@ class NetworksTable(tables.DataTable):
     tenant = tables.Column("tenant_name", verbose_name=_("Project"))
     name = tables.Column("name", verbose_name=_("Network Name"),
                          link='horizon:admin:networks:detail')
-    subnets = tables.Column(get_subnets,
+    subnets = tables.Column(project_tables.get_subnets,
                             verbose_name=_("Subnets Associated"),)
     shared = tables.Column("shared", verbose_name=_("Shared"),
                            filters=(filters.yesno, filters.capfirst))
