@@ -19,11 +19,12 @@
 #    under the License.
 
 
-from django.conf.urls.defaults import url, patterns
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from .views import GlobalOverview
+from openstack_dashboard.dashboards.admin.overview import views
 
 
 urlpatterns = patterns('',
-    url(r'^$', GlobalOverview.as_view(), name='index'),
+    url(r'^$', views.GlobalOverview.as_view(), name='index'),
 )
