@@ -19,18 +19,37 @@
 #    under the License.
 
 from django.conf import settings
-from django.utils.translation import ugettext as _
+from django.template.defaultfilters import floatformat  # noqa
+from django.utils import translation
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
+from horizon.utils import csvbase
 
 from openstack_dashboard import api
 from openstack_dashboard import usage
 
 
+class GlobalUsageCsvRenderer(csvbase.BaseCsvResponse):
+
+    columns = [_("Project Name"), _("VCPUs"), _("Ram (MB)"),
+               _("Disk (GB)"), _("Usage (Hours)")]
+
+    def get_row_data(self):
+
+        for u in self.context['usage'].usage_list:
+            yield (u.project_name or u.tenant_id,
+                   u.vcpus,
+                   u.memory_mb,
+                   u.local_gb,
+                   floatformat(u.vcpu_hours, 2))
+
+
 class GlobalOverview(usage.UsageView):
     table_class = usage.GlobalUsageTable
     usage_class = usage.GlobalUsage
     template_name = 'admin/overview/usage.html'
+    csv_response_class = GlobalUsageCsvRenderer
 
     def get_context_data(self, **kwargs):
         context = super(GlobalOverview, self).get_context_data(**kwargs)
@@ -39,17 +58,21 @@ class GlobalOverview(usage.UsageView):
 
     def get_data(self):
         data = super(GlobalOverview, self).get_data()
-        # Pre-fill tenant names
+        # Pre-fill project names
         try:
-            tenants = api.keystone.tenant_list(self.request, admin=True)
-        except:
-            tenants = []
+            projects, has_more = api.keystone.tenant_list(self.request)
+        except Exception:
+            projects = []
             exceptions.handle(self.request,
                               _('Unable to retrieve project list.'))
         for instance in data:
-            tenant = filter(lambda t: t.id == instance.tenant_id, tenants)
-            if tenant:
-                instance.tenant_name = getattr(tenant[0], "name", None)
+            project = filter(lambda t: t.id == instance.tenant_id, projects)
+            # If we could not get the project name, show the tenant_id with
+            # a 'Deleted' identifier instead.
+            if project:
+                instance.project_name = getattr(project[0], "name", None)
             else:
-                instance.tenant_name = None
+                deleted = _("Deleted")
+                instance.project_name = translation.string_concat(
+                    instance.tenant_id, " (", deleted, ")")
         return data
