@@ -18,9 +18,9 @@
 Admin views for managing volumes.
 """
 
-from django.core.urlresolvers import reverse  # noqa
-from django.utils.datastructures import SortedDict  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.core.urlresolvers import reverse
+from django.utils.datastructures import SortedDict
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -34,10 +34,13 @@ from openstack_dashboard.dashboards.admin.volumes \
 from openstack_dashboard.dashboards.admin.volumes \
     import tables as project_tables
 
-from openstack_dashboard.dashboards.project.volumes import views
+from openstack_dashboard.dashboards.project.volumes \
+    import tabs as project_tabs
+from openstack_dashboard.dashboards.project.volumes \
+    .volumes import views as volume_views
 
 
-class IndexView(tables.MultiTableView, views.VolumeTableMixIn):
+class IndexView(tables.MultiTableView, project_tabs.VolumeTableMixIn):
     table_classes = (project_tables.VolumesTable,
                      project_tables.VolumeTypesTable)
     template_name = "admin/volumes/index.html"
@@ -45,7 +48,6 @@ class IndexView(tables.MultiTableView, views.VolumeTableMixIn):
     def get_volumes_data(self):
         volumes = self._get_volumes(search_opts={'all_tenants': True})
         instances = self._get_instances(search_opts={'all_tenants': True})
-        self._set_id_if_nameless(volumes, instances)
         self._set_attachments_string(volumes, instances)
 
         # Gather our tenants to correlate against IDs
@@ -74,7 +76,7 @@ class IndexView(tables.MultiTableView, views.VolumeTableMixIn):
         return volume_types
 
 
-class DetailView(views.DetailView):
+class DetailView(volume_views.DetailView):
     template_name = "admin/volumes/detail.html"
 
 
