@@ -20,11 +20,11 @@
 
 import netaddr
 
-from django.conf import settings  # noqa
-from django.core.urlresolvers import reverse  # noqa
+from django.conf import settings
+from django.core.urlresolvers import reverse
 from django.core import validators
 from django.forms import ValidationError  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import forms
@@ -38,6 +38,7 @@ from openstack_dashboard.utils import filters
 
 class CreateGroup(forms.SelfHandlingForm):
     name = forms.CharField(label=_("Name"),
+                           max_length=255,
                            error_messages={
                                'required': _('This field is required.'),
                                'invalid': _("The string may only contain"
@@ -64,6 +65,7 @@ class CreateGroup(forms.SelfHandlingForm):
 class UpdateGroup(forms.SelfHandlingForm):
     id = forms.CharField(widget=forms.HiddenInput())
     name = forms.CharField(label=_("Name"),
+                           max_length=255,
                            error_messages={
                                'required': _('This field is required.'),
                                'invalid': _("The string may only contain"
@@ -273,6 +275,10 @@ class AddRule(forms.SelfHandlingForm):
     def clean(self):
         cleaned_data = super(AddRule, self).clean()
 
+        def update_cleaned_data(key, value):
+            cleaned_data[key] = value
+            self.errors.pop(key, None)
+
         rule_menu = cleaned_data.get('rule_menu')
         port_or_range = cleaned_data.get("port_or_range")
         remote = cleaned_data.get("remote")
@@ -285,30 +291,34 @@ class AddRule(forms.SelfHandlingForm):
         port = cleaned_data.get("port", None)
 
         if rule_menu == 'icmp':
-            cleaned_data['ip_protocol'] = rule_menu
+            update_cleaned_data('ip_protocol', rule_menu)
             if icmp_type is None:
                 msg = _('The ICMP type is invalid.')
                 raise ValidationError(msg)
             if icmp_code is None:
                 msg = _('The ICMP code is invalid.')
                 raise ValidationError(msg)
-            if icmp_type not in xrange(-1, 256):
+            if icmp_type not in range(-1, 256):
                 msg = _('The ICMP type not in range (-1, 255)')
                 raise ValidationError(msg)
-            if icmp_code not in xrange(-1, 256):
+            if icmp_code not in range(-1, 256):
                 msg = _('The ICMP code not in range (-1, 255)')
                 raise ValidationError(msg)
-            cleaned_data['from_port'] = icmp_type
-            cleaned_data['to_port'] = icmp_code
+            update_cleaned_data('from_port', icmp_type)
+            update_cleaned_data('to_port', icmp_code)
+            update_cleaned_data('port', None)
         elif rule_menu == 'tcp' or rule_menu == 'udp':
-            cleaned_data['ip_protocol'] = rule_menu
+            update_cleaned_data('ip_protocol', rule_menu)
+            update_cleaned_data('icmp_code', None)
+            update_cleaned_data('icmp_type', None)
             if port_or_range == "port":
-                cleaned_data["from_port"] = port
-                cleaned_data["to_port"] = port
+                update_cleaned_data('from_port', port)
+                update_cleaned_data('to_port', port)
                 if port is None:
                     msg = _('The specified port is invalid.')
                     raise ValidationError(msg)
             else:
+                update_cleaned_data('port', None)
                 if from_port is None:
                     msg = _('The "from" port number is invalid.')
                     raise ValidationError(msg)
@@ -325,21 +335,23 @@ class AddRule(forms.SelfHandlingForm):
             cleaned_data['ip_protocol'] = self.rules[rule_menu]['ip_protocol']
             cleaned_data['from_port'] = int(self.rules[rule_menu]['from_port'])
             cleaned_data['to_port'] = int(self.rules[rule_menu]['to_port'])
-            cleaned_data['direction'] = self.rules[rule_menu].get('direction')
+            if rule_menu not in ['all_tcp', 'all_udp', 'all_icmp']:
+                direction = self.rules[rule_menu].get('direction')
+                cleaned_data['direction'] = direction
 
         # NOTE(amotoki): There are two cases where cleaned_data['direction']
         # is empty: (1) Nova Security Group is used. Since "direction" is
         # HiddenInput, direction field exists but its value is ''.
-        # (2) Template is used. In this case, the default value is None.
-        # To make sure 'direction' field has 'ingress' or 'egress',
+        # (2) Template except all_* is used. In this case, the default value
+        # is None. To make sure 'direction' field has 'ingress' or 'egress',
         # fill this field here if it is not specified.
         if not cleaned_data['direction']:
             cleaned_data['direction'] = 'ingress'
 
         if remote == "cidr":
-            cleaned_data['security_group'] = None
+            update_cleaned_data('security_group', None)
         else:
-            cleaned_data['cidr'] = None
+            update_cleaned_data('cidr', None)
 
         # If cleaned_data does not contain cidr, cidr is already marked
         # as invalid, so skip the further validation for cidr.
