@@ -20,7 +20,7 @@
 
 from copy import deepcopy  # noqa
 
-from django.core.urlresolvers import reverse  # noqa
+from django.core.urlresolvers import reverse
 from django import http
 
 from mox import IsA  # noqa
