@@ -15,7 +15,6 @@
 #    under the License.
 import logging
 
-from django.core.urlresolvers import reverse
 from django import shortcuts
 from django import template
 from django.template import defaultfilters as filters
@@ -26,6 +25,7 @@ from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import messages
 from horizon import tables
+from horizon.utils.urlresolvers import reverse  # noqa
 
 from openstack_dashboard import api
 from openstack_dashboard.api import swift
@@ -49,8 +49,7 @@ class ViewContainer(tables.LinkAction):
 
     def get_link_url(self, datum=None):
         obj_id = self.table.get_object_id(datum)
-        args = (http.urlquote(obj_id),)
-        return reverse(self.url, args=args)
+        return reverse(self.url, args=(obj_id,))
 
 
 class MakePublicContainer(tables.Action):
@@ -157,8 +156,7 @@ class CreatePseudoFolder(tables.LinkAction):
         else:
             container_name = self.table.kwargs['container_name']
         subfolders = self.table.kwargs.get('subfolder_path', '')
-        args = (http.urlquote(bit) for bit in
-                (container_name, subfolders) if bit)
+        args = (bit for bit in (container_name, subfolders) if bit)
         return reverse(self.url, args=args)
 
     def allowed(self, request, datum=None):
@@ -182,13 +180,12 @@ class UploadObject(tables.LinkAction):
         # Usable for both the container and object tables
         if getattr(datum, 'container', datum):
             # This is a container
-            container_name = http.urlquote(datum.name)
+            container_name = datum.name
         else:
             # This is a table action, and we already have the container name
             container_name = self.table.kwargs['container_name']
         subfolders = self.table.kwargs.get('subfolder_path', '')
-        args = (http.urlquote(bit) for bit in
-                (container_name, subfolders) if bit)
+        args = (bit for bit in (container_name, subfolders) if bit)
         return reverse(self.url, args=args)
 
     def allowed(self, request, datum=None):
@@ -208,7 +205,7 @@ def get_size_used(container):
 
 def get_container_link(container):
     return reverse("horizon:project:containers:index",
-                   args=(http.urlquote(wrap_delimiter(container.name)),))
+                   args=(wrap_delimiter(container.name),))
 
 
 class ContainerAjaxUpdateRow(tables.Row):
@@ -290,8 +287,7 @@ class ViewObject(tables.LinkAction):
 
     def get_link_url(self, obj):
         container_name = self.table.kwargs['container_name']
-        return reverse(self.url, args=(http.urlquote(container_name),
-                                       http.urlquote(obj.name)))
+        return reverse(self.url, args=(container_name, obj.name))
 
 
 class UpdateObject(tables.LinkAction):
@@ -303,19 +299,21 @@ class UpdateObject(tables.LinkAction):
 
     def get_link_url(self, obj):
         container_name = self.table.kwargs['container_name']
-        return reverse(self.url, args=(http.urlquote(container_name),
-                                       http.urlquote(obj.name)))
+        return reverse(self.url, args=(container_name, obj.name))
 
 
 class DeleteObject(tables.DeleteAction):
     name = "delete_object"
     data_type_singular = _("Object")
     data_type_plural = _("Objects")
-    allowed_data_types = ("objects",)
+    allowed_data_types = ("objects", "subfolders",)
 
     def delete(self, request, obj_id):
         obj = self.table.get_object_by_id(obj_id)
         container_name = obj.container_name
+        datum_type = getattr(obj, self.table._meta.data_type_name, None)
+        if datum_type == 'subfolders':
+            obj_id = obj_id[(len(container_name) + 1):] + "/"
         api.swift.swift_delete_object(request, container_name, obj_id)
 
     def get_success_url(self, request):
@@ -325,9 +323,6 @@ class DeleteObject(tables.DeleteAction):
 
 class DeleteMultipleObjects(DeleteObject):
     name = "delete_multiple_objects"
-    data_type_singular = _("Object")
-    data_type_plural = _("Objects")
-    allowed_data_types = ("objects",)
 
 
 class CopyObject(tables.LinkAction):
@@ -339,8 +334,7 @@ class CopyObject(tables.LinkAction):
 
     def get_link_url(self, obj):
         container_name = self.table.kwargs['container_name']
-        return reverse(self.url, args=(http.urlquote(container_name),
-                                       http.urlquote(obj.name)))
+        return reverse(self.url, args=(container_name, obj.name))
 
 
 class DownloadObject(tables.LinkAction):
@@ -352,8 +346,7 @@ class DownloadObject(tables.LinkAction):
 
     def get_link_url(self, obj):
         container_name = self.table.kwargs['container_name']
-        return reverse(self.url, args=(http.urlquote(container_name),
-                                       http.urlquote(obj.name)))
+        return reverse(self.url, args=(container_name, obj.name))
 
     def allowed(self, request, object):
         return object.bytes and object.bytes > 0
@@ -400,8 +393,8 @@ def get_size(obj):
 def get_link_subfolder(subfolder):
     container_name = subfolder.container_name
     return reverse("horizon:project:containers:index",
-                    args=(http.urlquote(wrap_delimiter(container_name)),
-                          http.urlquote(wrap_delimiter(subfolder.name))))
+                   args=(wrap_delimiter(container_name),
+                         wrap_delimiter(subfolder.name)))
 
 
 class ObjectsTable(tables.DataTable):
