@@ -22,10 +22,10 @@
 Views for managing Swift containers.
 """
 
-from django.core.urlresolvers import reverse
+import os
+
 from django import http
 from django.utils.functional import cached_property  # noqa
-from django.utils import http as utils_http
 from django.utils.translation import ugettext_lazy as _
 from django.views import generic
 
@@ -33,6 +33,7 @@ from horizon import browsers
 from horizon import exceptions
 from horizon import forms
 from horizon.utils import memoized
+from horizon.utils.urlresolvers import reverse  # noqa
 
 from openstack_dashboard import api
 from openstack_dashboard.api import swift
@@ -42,18 +43,6 @@ from openstack_dashboard.dashboards.project.containers \
     import forms as project_forms
 from openstack_dashboard.dashboards.project.containers import tables
 
-import os
-
-
-def for_url(container_name):
-    """Build a URL friendly container name.
-
-    Add Swift delimiter if necessary.
-    The name can contain '%' (bug 1231904).
-    """
-    container_name = tables.wrap_delimiter(container_name)
-    return utils_http.urlquote(container_name)
-
 
 class ContainerView(browsers.ResourceBrowserView):
     browser_class = project_browsers.ContainerBrowser
@@ -145,10 +134,11 @@ class CreateView(forms.ModalFormView):
         if parent:
             container, slash, remainder = parent.partition(
                 swift.FOLDER_DELIMITER)
-            args = (for_url(container), for_url(remainder))
+            args = (tables.wrap_delimiter(container),
+                    tables.wrap_delimiter(remainder))
             return reverse(self.success_url, args=args)
         else:
-            container = for_url(self.request.POST['name'])
+            container = tables.wrap_delimiter(self.request.POST['name'])
             return reverse(self.success_url, args=[container])
 
     def get_initial(self):
@@ -185,9 +175,9 @@ class UploadView(forms.ModalFormView):
     success_url = "horizon:project:containers:index"
 
     def get_success_url(self):
-        container_name = for_url(self.request.POST['container_name'])
-        path = for_url(self.request.POST.get('path', ''))
-        args = (container_name, path)
+        container = tables.wrap_delimiter(self.request.POST['container_name'])
+        path = tables.wrap_delimiter(self.request.POST.get('path', ''))
+        args = (container, path)
         return reverse(self.success_url, args=args)
 
     def get_initial(self):
@@ -196,8 +186,7 @@ class UploadView(forms.ModalFormView):
 
     def get_context_data(self, **kwargs):
         context = super(UploadView, self).get_context_data(**kwargs)
-        container_name = utils_http.urlquote(self.kwargs["container_name"])
-        context['container_name'] = container_name
+        context['container_name'] = self.kwargs["container_name"]
         return context
 
 
@@ -229,9 +218,10 @@ class CopyView(forms.ModalFormView):
     success_url = "horizon:project:containers:index"
 
     def get_success_url(self):
-        new_container_name = for_url(self.request.POST['new_container_name'])
-        path = for_url(self.request.POST.get('path', ''))
-        args = (new_container_name, path)
+        container = tables.wrap_delimiter(
+            self.request.POST['new_container_name'])
+        path = tables.wrap_delimiter(self.request.POST.get('path', ''))
+        args = (container, path)
         return reverse(self.success_url, args=args)
 
     def get_form_kwargs(self):
@@ -257,8 +247,7 @@ class CopyView(forms.ModalFormView):
 
     def get_context_data(self, **kwargs):
         context = super(CopyView, self).get_context_data(**kwargs)
-        container_name = utils_http.urlquote(self.kwargs["container_name"])
-        context['container_name'] = container_name
+        context['container_name'] = self.kwargs["container_name"]
         context['object_name'] = self.kwargs["object_name"]
         return context
 
@@ -314,9 +303,9 @@ class UpdateObjectView(forms.ModalFormView):
     success_url = "horizon:project:containers:index"
 
     def get_success_url(self):
-        container_name = for_url(self.request.POST['container_name'])
-        path = for_url(self.request.POST.get('path', ''))
-        args = (container_name, path)
+        container = tables.wrap_delimiter(self.request.POST['container_name'])
+        path = tables.wrap_delimiter(self.request.POST.get('path', ''))
+        args = (container, path)
         return reverse(self.success_url, args=args)
 
     def get_initial(self):
@@ -326,10 +315,7 @@ class UpdateObjectView(forms.ModalFormView):
 
     def get_context_data(self, **kwargs):
         context = super(UpdateObjectView, self).get_context_data(**kwargs)
-        context['container_name'] = utils_http.urlquote(
-            self.kwargs["container_name"])
-        context['subfolder_path'] = utils_http.urlquote(
-            self.kwargs["subfolder_path"])
-        context['object_name'] = utils_http.urlquote(
-            self.kwargs["object_name"])
+        context['container_name'] = self.kwargs["container_name"]
+        context['subfolder_path'] = self.kwargs["subfolder_path"]
+        context['object_name'] = self.kwargs["object_name"]
         return context
