@@ -14,24 +14,24 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
 
 class BasePanels(horizon.PanelGroup):
     slug = "compute"
-    name = _("Manage Compute")
+    name = _("Compute")
     panels = ('overview',
               'instances',
               'volumes',
-              'images_and_snapshots',
+              'images',
               'access_and_security',)
 
 
 class NetworkPanels(horizon.PanelGroup):
     slug = "network"
-    name = _("Manage Network")
+    name = _("Network")
     panels = ('network_topology',
               'networks',
               'routers',
@@ -53,7 +53,7 @@ class OrchestrationPanels(horizon.PanelGroup):
 
 
 class DatabasePanels(horizon.PanelGroup):
-    name = _("Manage Databases")
+    name = _("Databases")
     slug = "database"
     panels = ('databases',
               'database_backups',)
