@@ -17,8 +17,8 @@
 
 from mox import IsA  # noqa
 
-from django.core.urlresolvers import reverse  # noqa
-from django.core.urlresolvers import reverse_lazy  # noqa
+from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse_lazy
 from django import http
 
 from openstack_dashboard import api
@@ -56,36 +56,36 @@ class FirewallTests(test.TestCase):
         # retrieve rules
         tenant_id = self.tenant.id
 
-        api.fwaas.rules_list(
+        api.fwaas.rule_list(
             IsA(http.HttpRequest),
             tenant_id=tenant_id).AndReturn(self.fw_rules.list())
 
         # retrieves policies
         policies = self.fw_policies.list()
-        api.fwaas.policies_list(
+        api.fwaas.policy_list(
             IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(policies)
 
         # retrieves firewalls
         firewalls = self.firewalls.list()
-        api.fwaas.firewalls_list(
+        api.fwaas.firewall_list(
             IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(firewalls)
 
     def set_up_expect_with_exception(self):
         tenant_id = self.tenant.id
 
-        api.fwaas.rules_list(
+        api.fwaas.rule_list(
             IsA(http.HttpRequest),
             tenant_id=tenant_id).AndRaise(self.exceptions.neutron)
-        api.fwaas.policies_list(
+        api.fwaas.policy_list(
             IsA(http.HttpRequest),
             tenant_id=tenant_id).AndRaise(self.exceptions.neutron)
-        api.fwaas.firewalls_list(
+        api.fwaas.firewall_list(
             IsA(http.HttpRequest),
             tenant_id=tenant_id).AndRaise(self.exceptions.neutron)
 
-    @test.create_stubs({api.fwaas: ('firewalls_list',
-                                    'policies_list',
-                                    'rules_list')}, )
+    @test.create_stubs({api.fwaas: ('firewall_list',
+                                    'policy_list',
+                                    'rule_list')}, )
     def test_index_firewalls(self):
         self.set_up_expect()
 
@@ -101,9 +101,9 @@ class FirewallTests(test.TestCase):
         self.assertEqual(len(res.context['table'].data),
                          len(self.firewalls.list()))
 
-    @test.create_stubs({api.fwaas: ('firewalls_list',
-                                    'policies_list',
-                                    'rules_list')}, )
+    @test.create_stubs({api.fwaas: ('firewall_list',
+                                    'policy_list',
+                                    'rule_list')}, )
     def test_index_policies(self):
         self.set_up_expect()
 
@@ -120,9 +120,9 @@ class FirewallTests(test.TestCase):
         self.assertEqual(len(res.context['policiestable_table'].data),
                          len(self.fw_policies.list()))
 
-    @test.create_stubs({api.fwaas: ('firewalls_list',
-                                    'policies_list',
-                                    'rules_list')}, )
+    @test.create_stubs({api.fwaas: ('firewall_list',
+                                    'policy_list',
+                                    'rule_list')}, )
     def test_index_rules(self):
         self.set_up_expect()
 
@@ -139,9 +139,9 @@ class FirewallTests(test.TestCase):
         self.assertEqual(len(res.context['rulestable_table'].data),
                          len(self.fw_rules.list()))
 
-    @test.create_stubs({api.fwaas: ('firewalls_list',
-                                    'policies_list',
-                                    'rules_list')}, )
+    @test.create_stubs({api.fwaas: ('firewall_list',
+                                    'policy_list',
+                                    'rule_list')}, )
     def test_index_exception_firewalls(self):
         self.set_up_expect_with_exception()
 
@@ -158,9 +158,9 @@ class FirewallTests(test.TestCase):
                                 'horizon/common/_detail_table.html')
         self.assertEqual(len(res.context['table'].data), 0)
 
-    @test.create_stubs({api.fwaas: ('firewalls_list',
-                                    'policies_list',
-                                    'rules_list')}, )
+    @test.create_stubs({api.fwaas: ('firewall_list',
+                                    'policy_list',
+                                    'rule_list')}, )
     def test_index_exception_policies(self):
         self.set_up_expect_with_exception()
 
@@ -178,9 +178,9 @@ class FirewallTests(test.TestCase):
                                 'horizon/common/_detail_table.html')
         self.assertEqual(len(res.context['policiestable_table'].data), 0)
 
-    @test.create_stubs({api.fwaas: ('firewalls_list',
-                                    'policies_list',
-                                    'rules_list')}, )
+    @test.create_stubs({api.fwaas: ('firewall_list',
+                                    'policy_list',
+                                    'rule_list')}, )
     def test_index_exception_rules(self):
         self.set_up_expect_with_exception()
 
@@ -245,7 +245,7 @@ class FirewallTests(test.TestCase):
 
         self.assertFormErrors(res, 2)
 
-    @test.create_stubs({api.fwaas: ('policy_create', 'rules_list'), })
+    @test.create_stubs({api.fwaas: ('policy_create', 'rule_list'), })
     def test_add_policy_post(self):
         policy = self.fw_policies.first()
         rules = self.fw_rules.list()
@@ -271,7 +271,7 @@ class FirewallTests(test.TestCase):
         for rule in rules:
             if rule.id in policy.firewall_rules:
                 rule.firewall_policy_id = rule.policy = None
-        api.fwaas.rules_list(
+        api.fwaas.rule_list(
             IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(rules)
         api.fwaas.policy_create(
             IsA(http.HttpRequest), **form_data).AndReturn(policy)
@@ -283,7 +283,7 @@ class FirewallTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.fwaas: ('policy_create', 'rules_list'), })
+    @test.create_stubs({api.fwaas: ('policy_create', 'rule_list'), })
     def test_add_policy_post_with_error(self):
         policy = self.fw_policies.first()
         rules = self.fw_rules.list()
@@ -293,7 +293,7 @@ class FirewallTests(test.TestCase):
                      'shared': policy.shared,
                      'audited': policy.audited
                      }
-        api.fwaas.rules_list(
+        api.fwaas.rule_list(
             IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(rules)
 
         self.mox.ReplayAll()
@@ -302,7 +302,7 @@ class FirewallTests(test.TestCase):
 
         self.assertFormErrors(res, 1)
 
-    @test.create_stubs({api.fwaas: ('firewall_create', 'policies_list'), })
+    @test.create_stubs({api.fwaas: ('firewall_create', 'policy_list'), })
     def test_add_firewall_post(self):
         firewall = self.firewalls.first()
         policies = self.fw_policies.list()
@@ -313,7 +313,7 @@ class FirewallTests(test.TestCase):
                      'shared': firewall.shared,
                      'admin_state_up': firewall.admin_state_up
                      }
-        api.fwaas.policies_list(
+        api.fwaas.policy_list(
             IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(policies)
         api.fwaas.firewall_create(
             IsA(http.HttpRequest), **form_data).AndReturn(firewall)
@@ -325,7 +325,7 @@ class FirewallTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.fwaas: ('firewall_create', 'policies_list'), })
+    @test.create_stubs({api.fwaas: ('firewall_create', 'policy_list'), })
     def test_add_firewall_post_with_error(self):
         firewall = self.firewalls.first()
         policies = self.fw_policies.list()
@@ -336,7 +336,7 @@ class FirewallTests(test.TestCase):
                      'shared': firewall.shared,
                      'admin_state_up': firewall.admin_state_up
                      }
-        api.fwaas.policies_list(
+        api.fwaas.policy_list(
             IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(policies)
 
         self.mox.ReplayAll()
@@ -345,25 +345,30 @@ class FirewallTests(test.TestCase):
 
         self.assertFormErrors(res, 1)
 
+    @test.create_stubs({api.fwaas: ('rule_get',)})
+    def test_update_rule_get(self):
+        rule = self.fw_rules.first()
+
+        api.fwaas.rule_get(IsA(http.HttpRequest), rule.id).AndReturn(rule)
+
+        self.mox.ReplayAll()
+
+        res = self.client.get(reverse(self.UPDATERULE_PATH, args=(rule.id,)))
+
+        self.assertTemplateUsed(res, 'project/firewalls/updaterule.html')
+
     @test.create_stubs({api.fwaas: ('rule_get', 'rule_update')})
     def test_update_rule_post(self):
         rule = self.fw_rules.first()
 
         api.fwaas.rule_get(IsA(http.HttpRequest), rule.id).AndReturn(rule)
 
-        rule.name = 'new name'
-        rule.description = 'new desc'
-        rule.protocol = 'ICMP'
-        rule.action = 'ALLOW'
-        rule.shared = False
-        rule.enabled = True
-
-        data = {'name': rule.name,
-                'description': rule.description,
-                'protocol': rule.protocol,
-                'action': rule.action,
-                'shared': rule.shared,
-                'enabled': rule.enabled,
+        data = {'name': 'new name',
+                'description': 'new desc',
+                'protocol': 'ICMP',
+                'action': 'ALLOW',
+                'shared': False,
+                'enabled': True,
                 'source_ip_address': rule.source_ip_address,
                 'destination_ip_address': None,
                 'source_port': None,
@@ -375,17 +380,9 @@ class FirewallTests(test.TestCase):
 
         self.mox.ReplayAll()
 
-        form_data = {'name': rule.name,
-                     'description': rule.description,
-                     'protocol': rule.protocol,
-                     'action': rule.action,
-                     'shared': rule.shared,
-                     'enabled': rule.enabled,
-                     'source_ip_address': rule.source_ip_address,
-                     'destination_ip_address': '',
-                     'source_port': '',
-                     'destination_port': rule.destination_port,
-                     }
+        form_data = data.copy()
+        form_data['destination_ip_address'] = ''
+        form_data['source_port'] = ''
 
         res = self.client.post(
             reverse(self.UPDATERULE_PATH, args=(rule.id,)), form_data)
@@ -393,23 +390,32 @@ class FirewallTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
+    @test.create_stubs({api.fwaas: ('policy_get',)})
+    def test_update_policy_get(self):
+        policy = self.fw_policies.first()
+
+        api.fwaas.policy_get(IsA(http.HttpRequest),
+                             policy.id).AndReturn(policy)
+
+        self.mox.ReplayAll()
+
+        res = self.client.get(
+            reverse(self.UPDATEPOLICY_PATH, args=(policy.id,)))
+
+        self.assertTemplateUsed(res, 'project/firewalls/updatepolicy.html')
+
     @test.create_stubs({api.fwaas: ('policy_get', 'policy_update',
-                                    'rules_list')})
+                                    'rule_list')})
     def test_update_policy_post(self):
         policy = self.fw_policies.first()
 
         api.fwaas.policy_get(IsA(http.HttpRequest),
                              policy.id).AndReturn(policy)
 
-        policy.name = 'new name'
-        policy.description = 'new desc'
-        policy.shared = True
-        policy.audited = False
-
-        data = {'name': policy.name,
-                'description': policy.description,
-                'shared': policy.shared,
-                'audited': policy.audited
+        data = {'name': 'new name',
+                'description': 'new desc',
+                'shared': True,
+                'audited': False
                 }
 
         api.fwaas.policy_update(IsA(http.HttpRequest), policy.id, **data)\
@@ -423,7 +429,26 @@ class FirewallTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
-    @test.create_stubs({api.fwaas: ('firewall_get', 'policies_list',
+    @test.create_stubs({api.fwaas: ('firewall_get', 'policy_list')})
+    def test_update_firewall_get(self):
+        firewall = self.firewalls.first()
+        policies = self.fw_policies.list()
+        tenant_id = self.tenant.id
+
+        api.fwaas.policy_list(
+            IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(policies)
+
+        api.fwaas.firewall_get(IsA(http.HttpRequest),
+                               firewall.id).AndReturn(firewall)
+
+        self.mox.ReplayAll()
+
+        res = self.client.get(
+            reverse(self.UPDATEFIREWALL_PATH, args=(firewall.id,)))
+
+        self.assertTemplateUsed(res, 'project/firewalls/updatefirewall.html')
+
+    @test.create_stubs({api.fwaas: ('firewall_get', 'policy_list',
                                     'firewall_update')})
     def test_update_firewall_post(self):
         firewall = self.firewalls.first()
@@ -431,18 +456,14 @@ class FirewallTests(test.TestCase):
         api.fwaas.firewall_get(IsA(http.HttpRequest),
                                firewall.id).AndReturn(firewall)
 
-        firewall.name = 'new name'
-        firewall.description = 'new desc'
-        firewall.admin_state_up = False
-
-        data = {'name': firewall.name,
-                'description': firewall.description,
+        data = {'name': 'new name',
+                'description': 'new desc',
                 'firewall_policy_id': firewall.firewall_policy_id,
-                'admin_state_up': firewall.admin_state_up
+                'admin_state_up': False
                 }
 
         policies = self.fw_policies.list()
-        api.fwaas.policies_list(
+        api.fwaas.policy_list(
             IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(policies)
 
         api.fwaas.firewall_update(IsA(http.HttpRequest), firewall.id, **data)\
@@ -457,7 +478,7 @@ class FirewallTests(test.TestCase):
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
     @test.create_stubs({api.fwaas: ('policy_get', 'policy_insert_rule',
-                                    'rules_list', 'rule_get')})
+                                    'rule_list', 'rule_get')})
     def test_policy_insert_rule(self):
         policy = self.fw_policies.first()
         tenant_id = self.tenant.id
@@ -476,7 +497,7 @@ class FirewallTests(test.TestCase):
                                  new_rule_id,
                                  rules[1].id]
 
-        api.fwaas.rules_list(
+        api.fwaas.rule_list(
             IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(rules)
         api.fwaas.rule_get(
             IsA(http.HttpRequest), new_rule_id).AndReturn(rules[2])
@@ -492,7 +513,7 @@ class FirewallTests(test.TestCase):
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
 
     @test.create_stubs({api.fwaas: ('policy_get', 'policy_remove_rule',
-                                    'rules_list', 'rule_get')})
+                                    'rule_list', 'rule_get')})
     def test_policy_remove_rule(self):
         policy = self.fw_policies.first()
         tenant_id = self.tenant.id
@@ -514,7 +535,7 @@ class FirewallTests(test.TestCase):
 
         api.fwaas.policy_get(IsA(http.HttpRequest),
                              policy.id).AndReturn(policy)
-        api.fwaas.rules_list(
+        api.fwaas.rule_list(
             IsA(http.HttpRequest), tenant_id=tenant_id).AndReturn(rules)
         api.fwaas.rule_get(
             IsA(http.HttpRequest), remove_rule_id).AndReturn(rules[0])
@@ -528,3 +549,48 @@ class FirewallTests(test.TestCase):
 
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, str(self.INDEX_URL))
+
+    @test.create_stubs({api.fwaas: ('firewall_list',
+                                    'policy_list',
+                                    'rule_list',
+                                    'rule_delete')})
+    def test_delete_rule(self):
+        self.set_up_expect()
+        rule = self.fw_rules.first()
+        api.fwaas.rule_delete(IsA(http.HttpRequest), rule.id)
+        self.mox.ReplayAll()
+
+        form_data = {"action": "rulestable__deleterule__%s" % rule.id}
+        res = self.client.post(self.INDEX_URL, form_data)
+
+        self.assertNoFormErrors(res)
+
+    @test.create_stubs({api.fwaas: ('firewall_list',
+                                    'policy_list',
+                                    'rule_list',
+                                    'policy_delete')})
+    def test_delete_policy(self):
+        self.set_up_expect()
+        policy = self.fw_policies.first()
+        api.fwaas.policy_delete(IsA(http.HttpRequest), policy.id)
+        self.mox.ReplayAll()
+
+        form_data = {"action": "policiestable__deletepolicy__%s" % policy.id}
+        res = self.client.post(self.INDEX_URL, form_data)
+
+        self.assertNoFormErrors(res)
+
+    @test.create_stubs({api.fwaas: ('firewall_list',
+                                    'policy_list',
+                                    'rule_list',
+                                    'firewall_delete')})
+    def test_delete_firewall(self):
+        self.set_up_expect()
+        fwl = self.firewalls.first()
+        api.fwaas.firewall_delete(IsA(http.HttpRequest), fwl.id)
+        self.mox.ReplayAll()
+
+        form_data = {"action": "firewallstable__deletefirewall__%s" % fwl.id}
+        res = self.client.post(self.INDEX_URL, form_data)
+
+        self.assertNoFormErrors(res)
