@@ -1,3 +1,4 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
 #    Copyright 2013, Big Switch Networks, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -11,12 +12,14 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+#
+# @author: KC Wang, Big Switch Networks
 
 from django.utils.translation import ugettext_lazy as _
-import netaddr
 
 from horizon import exceptions
 from horizon import forms
+from horizon.utils import fields
 from horizon.utils import validators
 from horizon import workflows
 
@@ -34,24 +37,23 @@ class AddRuleAction(workflows.Action):
         max_length=80,
         label=_("Description"),
         required=False)
-    protocol = forms.ThemableChoiceField(
+    protocol = forms.ChoiceField(
         label=_("Protocol"),
         choices=[('tcp', _('TCP')),
                  ('udp', _('UDP')),
                  ('icmp', _('ICMP')),
                  ('any', _('ANY'))],)
-    action = forms.ThemableChoiceField(
+    action = forms.ChoiceField(
         label=_("Action"),
         choices=[('allow', _('ALLOW')),
-                 ('deny', _('DENY')),
-                 ('reject', _('REJECT'))],)
-    source_ip_address = forms.IPField(
+                 ('deny', _('DENY'))],)
+    source_ip_address = fields.IPField(
         label=_("Source IP Address/Subnet"),
-        version=forms.IPv4 | forms.IPv6,
+        version=fields.IPv4 | fields.IPv6,
         required=False, mask=True)
-    destination_ip_address = forms.IPField(
+    destination_ip_address = fields.IPField(
         label=_("Destination IP Address/Subnet"),
-        version=forms.IPv4 | forms.IPv6,
+        version=fields.IPv4 | fields.IPv6,
         required=False, mask=True)
     source_port = forms.CharField(
         max_length=80,
@@ -63,9 +65,6 @@ class AddRuleAction(workflows.Action):
         label=_("Destination Port/Port Range"),
         required=False,
         validators=[port_validator])
-    ip_version = forms.ThemableChoiceField(
-        label=_("IP Version"), required=False,
-        choices=[('4', '4'), ('6', '6')])
     shared = forms.BooleanField(
         label=_("Shared"), initial=False, required=False)
     enabled = forms.BooleanField(
@@ -74,41 +73,12 @@ class AddRuleAction(workflows.Action):
     def __init__(self, request, *args, **kwargs):
         super(AddRuleAction, self).__init__(request, *args, **kwargs)
 
-    def _check_ip_addr_and_ip_version(self, cleaned_data):
-        ip_version = int(str(cleaned_data.get('ip_version')))
-        src_ip = cleaned_data.get('source_ip_address')
-        dst_ip = cleaned_data.get('destination_ip_address')
-        msg = _('Source/Destination Network Address and IP version '
-                'are inconsistent. Please make them consistent.')
-        if (src_ip and
-                netaddr.IPNetwork(src_ip).version != ip_version):
-                self._errors['ip_version'] = self.error_class([msg])
-
-        elif (dst_ip and
-              netaddr.IPNetwork(dst_ip).version != ip_version):
-            self._errors['ip_version'] = self.error_class([msg])
-
-    def clean(self):
-        cleaned_data = super(AddRuleAction, self).clean()
-        self._check_ip_addr_and_ip_version(cleaned_data)
-
-    class Meta(object):
-        name = _("Rule")
+    class Meta:
+        name = _("AddRule")
         permissions = ('openstack.services.network',)
         help_text = _("Create a firewall rule.\n\n"
-                      "A Firewall rule is an association of the following "
-                      "attributes:\n\n"
-                      "<li>IP Addresses: The addresses from/to which the "
-                      "traffic filtration needs to be applied.</li>"
-                      "<li>IP Version: The type of IP packets (IP V4/V6) "
-                      "that needs to be filtered.</li>"
-                      "<li>Protocol: Type of packets (UDP, ICMP, TCP, Any) "
-                      "that needs to be checked.</li>"
-                      "<li>Action: Action is the type of filtration "
-                      "required, it can be Reject/Deny/Allow data "
-                      "packets.</li>\n"
-                      "The protocol and action fields are required, all "
-                      "others are optional.")
+                      "Protocol and action must be specified. "
+                      "Other fields are optional.")
 
 
 class AddRuleStep(workflows.Step):
@@ -116,7 +86,7 @@ class AddRuleStep(workflows.Step):
     contributes = ("name", "description", "protocol", "action",
                    "source_ip_address", "source_port",
                    "destination_ip_address", "destination_port",
-                   "enabled", "shared", "ip_version")
+                   "enabled", "shared")
 
     def contribute(self, data, context):
         context = super(AddRuleStep, self).contribute(data, context)
@@ -164,10 +134,10 @@ class SelectRulesAction(workflows.Action):
     rule = forms.MultipleChoiceField(
         label=_("Rules"),
         required=False,
-        widget=forms.ThemableCheckboxSelectMultiple(),
+        widget=forms.CheckboxSelectMultiple(),
         help_text=_("Create a policy with selected rules."))
 
-    class Meta(object):
+    class Meta:
         name = _("Rules")
         permissions = ('openstack.services.network',)
         help_text = _("Select rules for your policy.")
@@ -175,10 +145,12 @@ class SelectRulesAction(workflows.Action):
     def populate_rule_choices(self, request, context):
         try:
             tenant_id = self.request.user.tenant_id
-            rules = api.fwaas.rule_list_for_tenant(request, tenant_id)
+            rules = api.fwaas.rule_list(request, tenant_id=tenant_id)
+            for r in rules:
+                r.set_id_as_name_if_empty()
             rules = sorted(rules,
-                           key=lambda rule: rule.name_or_id)
-            rule_list = [(rule.id, rule.name_or_id) for rule in rules
+                           key=lambda rule: rule.name)
+            rule_list = [(rule.id, rule.name) for rule in rules
                          if not rule.firewall_policy_id]
         except Exception as e:
             rule_list = []
@@ -202,54 +174,10 @@ class SelectRulesStep(workflows.Step):
             return context
 
 
-class SelectRoutersAction(workflows.Action):
-    router = forms.MultipleChoiceField(
-        label=_("Routers"),
-        required=False,
-        widget=forms.ThemableCheckboxSelectMultiple(),
-        help_text=_("Create a firewall with selected routers."))
-
-    class Meta(object):
-        name = _("Routers")
-        permissions = ('openstack.services.network',)
-        help_text = _("Select routers for your firewall.")
-
-    def populate_router_choices(self, request, context):
-        try:
-            tenant_id = self.request.user.tenant_id
-            routers_list = api.fwaas.firewall_unassociated_routers_list(
-                request, tenant_id)
-
-        except Exception as e:
-            routers_list = []
-            exceptions.handle(request,
-                              _('Unable to retrieve routers (%(error)s).') % {
-                                  'error': str(e)})
-        routers_list = [(router.id, router.name_or_id)
-                        for router in routers_list]
-        return routers_list
-
-
-class SelectRoutersStep(workflows.Step):
-    action_class = SelectRoutersAction
-    template_name = "project/firewalls/_update_routers.html"
-    contributes = ("router_ids", "all_routers_selected",
-                   "Select No Routers")
-
-    def contribute(self, data, context):
-        if data:
-            routers = self.workflow.request.POST.getlist("router")
-            if routers:
-                routers = [r for r in routers if r != '']
-                context['router_ids'] = routers
-            else:
-                context['router_ids'] = []
-            return context
-
-
 class AddPolicyAction(workflows.Action):
     name = forms.CharField(max_length=80,
-                           label=_("Name"))
+                           label=_("Name"),
+                           required=True)
     description = forms.CharField(max_length=80,
                                   label=_("Description"),
                                   required=False)
@@ -263,28 +191,13 @@ class AddPolicyAction(workflows.Action):
     def __init__(self, request, *args, **kwargs):
         super(AddPolicyAction, self).__init__(request, *args, **kwargs)
 
-    class Meta(object):
-        name = _("Policy")
+    class Meta:
+        name = _("AddPolicy")
         permissions = ('openstack.services.network',)
         help_text = _("Create a firewall policy with an ordered list "
                       "of firewall rules.\n\n"
-                      "A firewall policy is an ordered collection of firewall "
-                      "rules. So if the traffic matches the first rule, the "
-                      "other rules are not executed. If the traffic does not "
-                      "match the current rule, then the next rule is "
-                      "executed. A firewall policy has the following "
-                      "attributes:\n\n"
-                      "<li>Shared: A firewall policy can be shared across "
-                      "tenants. Thus it can also be made part of an audit "
-                      "workflow wherein the firewall policy can be audited "
-                      "by the relevant entity that is authorized.</li>"
-                      "<li>Audited: When audited is set to True, it indicates "
-                      "that the firewall policy has been audited. "
-                      "Each time the firewall policy or the associated "
-                      "firewall rules are changed, this attribute will be "
-                      "set to False and will have to be explicitly set to "
-                      "True through an update operation.</li>\n"
-                      "The name field is required, all others are optional.")
+                      "A name must be given. Firewall rules are "
+                      "added in the order placed under the Rules tab.")
 
 
 class AddPolicyStep(workflows.Step):
@@ -326,8 +239,12 @@ class AddFirewallAction(workflows.Action):
     description = forms.CharField(max_length=80,
                                   label=_("Description"),
                                   required=False)
-    firewall_policy_id = forms.ThemableChoiceField(label=_("Policy"))
-    admin_state_up = forms.BooleanField(label=_("Enable Admin State"),
+    firewall_policy_id = forms.ChoiceField(label=_("Policy"),
+                                           required=True)
+    shared = forms.BooleanField(label=_("Shared"),
+                                initial=False,
+                                required=False)
+    admin_state_up = forms.BooleanField(label=_("Admin State"),
                                         initial=True,
                                         required=False)
 
@@ -337,7 +254,7 @@ class AddFirewallAction(workflows.Action):
         firewall_policy_id_choices = [('', _("Select a Policy"))]
         try:
             tenant_id = self.request.user.tenant_id
-            policies = api.fwaas.policy_list_for_tenant(request, tenant_id)
+            policies = api.fwaas.policy_list(request, tenant_id=tenant_id)
             policies = sorted(policies, key=lambda policy: policy.name)
         except Exception as e:
             exceptions.handle(
@@ -346,23 +263,29 @@ class AddFirewallAction(workflows.Action):
                     'error': str(e)})
             policies = []
         for p in policies:
-            firewall_policy_id_choices.append((p.id, p.name_or_id))
+            p.set_id_as_name_if_empty()
+            firewall_policy_id_choices.append((p.id, p.name))
         self.fields['firewall_policy_id'].choices = firewall_policy_id_choices
+        # only admin can set 'shared' attribute to True
+        if not request.user.is_superuser:
+            self.fields['shared'].widget.attrs['disabled'] = 'disabled'
 
-    class Meta(object):
-        name = _("Firewall")
+    class Meta:
+        name = _("AddFirewall")
         permissions = ('openstack.services.network',)
         help_text = _("Create a firewall based on a policy.\n\n"
-                      "A firewall represents a logical firewall resource that "
-                      "a tenant can instantiate and manage. A firewall must "
-                      "be associated with one policy, all other fields are "
-                      "optional.")
+                      "A policy must be selected. "
+                      "Other fields are optional.")
 
 
 class AddFirewallStep(workflows.Step):
     action_class = AddFirewallAction
     contributes = ("name", "firewall_policy_id", "description",
-                   "admin_state_up")
+                   "shared", "admin_state_up")
+
+    def contribute(self, data, context):
+        context = super(AddFirewallStep, self).contribute(data, context)
+        return context
 
 
 class AddFirewall(workflows.Workflow):
@@ -378,7 +301,7 @@ class AddFirewall(workflows.Workflow):
     # involve more complex configuration over time. Hence,
     # a workflow instead of a single form is used for
     # firewall_rule add to be ready for future extension.
-    default_steps = (AddFirewallStep, )
+    default_steps = (AddFirewallStep,)
 
     def format_status_message(self, message):
         return message % self.context.get('name')
