@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 Nebula, Inc.
 # Copyright 2012 OpenStack Foundation
 #
@@ -17,8 +19,12 @@ from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
+from openstack_dashboard.dashboards.project import dashboard
+
 
 class Images(horizon.Panel):
     name = _("Images")
     slug = 'images'
-    permissions = ('openstack.services.image',)
+
+
+dashboard.Project.register(Images)
