@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -16,13 +18,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import url
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
 from openstack_dashboard.dashboards.project.images.snapshots import views
 
 
-urlpatterns = [
-    url(r'^(?P<instance_id>[^/]+)/create/$',
+urlpatterns = patterns('',
+    url(r'^(?P<instance_id>[^/]+)/create',
         views.CreateView.as_view(),
         name='create')
-]
+)
