@@ -18,13 +18,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls.defaults import patterns  # noqa
-from django.conf.urls.defaults import url  # noqa
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
 from openstack_dashboard.dashboards.project.instances import views
 
 
 INSTANCES = r'^(?P<instance_id>[^/]+)/%s$'
+INSTANCES_KEYPAIR = r'^(?P<instance_id>[^/]+)/(?P<keypair_name>[^/]+)/%s$'
 VIEW_MOD = 'openstack_dashboard.dashboards.project.instances.views'
 
 
@@ -38,5 +39,8 @@ urlpatterns = patterns(VIEW_MOD,
     url(INSTANCES % 'console', 'console', name='console'),
     url(INSTANCES % 'vnc', 'vnc', name='vnc'),
     url(INSTANCES % 'spice', 'spice', name='spice'),
+    url(INSTANCES % 'rdp', 'rdp', name='rdp'),
     url(INSTANCES % 'resize', views.ResizeView.as_view(), name='resize'),
+    url(INSTANCES_KEYPAIR % 'decryptpassword',
+        views.DecryptPasswordView.as_view(), name='decryptpassword'),
 )
