@@ -15,7 +15,7 @@
 #    under the License.
 
 
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import tabs
@@ -34,15 +34,15 @@ class PoolsTab(tabs.TableTab):
     def get_poolstable_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            pools = api.lbaas.pools_get(self.tab_group.request,
+            pools = api.lbaas.pool_list(self.tab_group.request,
                                         tenant_id=tenant_id)
-            poolsFormatted = [p.readable(self.tab_group.request) for
-                              p in pools]
         except Exception:
-            poolsFormatted = []
+            pools = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve pools list.'))
-        return poolsFormatted
+        for p in pools:
+            p.set_id_as_name_if_empty()
+        return pools
 
 
 class MembersTab(tabs.TableTab):
@@ -54,15 +54,15 @@ class MembersTab(tabs.TableTab):
     def get_memberstable_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            members = api.lbaas.members_get(self.tab_group.request,
+            members = api.lbaas.member_list(self.tab_group.request,
                                             tenant_id=tenant_id)
-            membersFormatted = [m.readable(self.tab_group.request) for
-                                m in members]
         except Exception:
-            membersFormatted = []
+            members = []
             exceptions.handle(self.tab_group.request,
                               _('Unable to retrieve member list.'))
-        return membersFormatted
+        for m in members:
+            m.set_id_as_name_if_empty()
+        return members
 
 
 class MonitorsTab(tabs.TableTab):
@@ -74,7 +74,7 @@ class MonitorsTab(tabs.TableTab):
     def get_monitorstable_data(self):
         try:
             tenant_id = self.request.user.tenant_id
-            monitors = api.lbaas.pool_health_monitors_get(
+            monitors = api.lbaas.pool_health_monitor_list(
                 self.tab_group.request, tenant_id=tenant_id)
         except Exception:
             monitors = []
