@@ -14,6 +14,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import logging
+
 from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
@@ -29,6 +31,9 @@ AVAILABLE_PROTOCOLS = ('HTTP', 'HTTPS', 'TCP')
 AVAILABLE_METHODS = ('ROUND_ROBIN', 'LEAST_CONNECTIONS', 'SOURCE_IP')
 
 
+LOG = logging.getLogger(__name__)
+
+
 class AddPoolAction(workflows.Action):
     name = forms.CharField(max_length=80, label=_("Name"))
     description = forms.CharField(
@@ -387,19 +392,44 @@ class AddMember(workflows.Workflow):
     default_steps = (AddMemberStep,)
 
     def handle(self, request, context):
+        try:
+            pool = api.lbaas.pool_get(request, context['pool_id'])
+            subnet_id = pool['subnet_id']
+        except Exception:
+            self.failure_message = _('Unable to retrieve '
+                                     'the specified pool.')
+            return False
         for m in context['members']:
             params = {'device_id': m}
             try:
                 plist = api.neutron.port_list(request, **params)
             except Exception:
                 return False
-            if plist:
-                context['address'] = plist[0].fixed_ips[0]['ip_address']
-            try:
-                context['member_id'] = api.lbaas.member_create(
-                    request, **context).id
-            except Exception:
-                return False
+
+            # Sort port list for each member. This is needed to avoid
+            # attachment of random ports in case of creation of several
+            # members attached to several networks.
+            plist = sorted(plist, key=lambda port: port.network_id)
+            psubnet = [p for p in plist for ips in p.fixed_ips
+                       if ips['subnet_id'] == subnet_id]
+
+            # If possible, select a port on pool subnet.
+            if psubnet:
+                selected_port = psubnet[0]
+            elif plist:
+                selected_port = plist[0]
+            else:
+                selected_port = None
+
+            if selected_port:
+                context['address'] = \
+                    selected_port.fixed_ips[0]['ip_address']
+                try:
+                    api.lbaas.member_create(request, **context).id
+                except Exception as e:
+                    msg = self.failure_message
+                    LOG.info('%s: %s' % (msg, e))
+                    return False
         return True
 
 
