@@ -14,12 +14,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 from openstack_dashboard.dashboards.project.instances import tables as i_tables
 
 
 class InstancesTable(i_tables.InstancesTable):
     class Meta:
         name = "instances"
-        verbose_name = _("NT_Instances")
+        verbose_name = _("Instances")
         row_actions = (i_tables.TerminateInstance,)
