@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2012 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -16,12 +18,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import gettext_lazy as _
+from django.utils.translation import ugettext_lazy as _
 
 import horizon
 
+from openstack_dashboard.dashboards.project import dashboard
+
 
 class NetworkTopology(horizon.Panel):
     name = _("Network Topology")
     slug = 'network_topology'
     permissions = ('openstack.services.network', )
+
+
+dashboard.Project.register(NetworkTopology)
