@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013 NTT Innovation Institute Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,17 +14,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import gettext_lazy as _
-
-from openstack_dashboard.dashboards.project.routers import tables
+from django.utils.translation import ugettext_lazy as _
+from openstack_dashboard.dashboards.project.routers import\
+    tables as r_tables
 
 
-class DeleteRouter(tables.DeleteRouter):
+class DeleteRouter(r_tables.DeleteRouter):
     redirect_url = "horizon:project:network_topology:router"
 
 
-class RoutersTable(tables.RoutersTable):
-    class Meta(object):
+class RoutersTable(r_tables.RoutersTable):
+    class Meta:
         name = "Routers"
         verbose_name = _("Routers")
         status_columns = ["status"]
