@@ -14,9 +14,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse  # noqa
+from django.core.urlresolvers import reverse
 from django import http
-from django.utils.html import escape  # noqa
+from django.test.utils import override_settings
+from django.utils.html import escape
 
 from horizon.workflows import views
 
@@ -220,11 +221,9 @@ class NetworkTests(test.TestCase):
         self.assertEqual(len(ports), 0)
 
     @test.create_stubs({api.neutron: ('profile_list',)})
-    def test_network_create_get(self):
-        # TODO(absubram): Remove if clause and create separate
-        # test stubs for when profile_support is being used.
-        # Additionally ensure those are always run even in default setting
-        if api.neutron.is_port_profiles_supported():
+    def test_network_create_get(self,
+                                test_with_profile=False):
+        if test_with_profile:
             net_profiles = self.net_profiles.list()
             api.neutron.profile_list(IsA(http.HttpRequest),
                                      'network').AndReturn(net_profiles)
@@ -241,16 +240,18 @@ class NetworkTests(test.TestCase):
                          '<CreateSubnetDetail: createsubnetdetailaction>']
         self.assertQuerysetEqual(workflow.steps, expected_objs)
 
+    @override_settings(OPENSTACK_NEUTRON_NETWORK={'profile_support': 'cisco'})
+    def test_network_create_get_with_profile(self):
+        self.test_network_create_get(test_with_profile=True)
+
     @test.create_stubs({api.neutron: ('network_create',
                                       'profile_list',)})
-    def test_network_create_post(self):
+    def test_network_create_post(self,
+                                 test_with_profile=False):
         network = self.networks.first()
         params = {'name': network.name,
                   'admin_state_up': network.admin_state_up}
-        # TODO(absubram): Remove if clause and create separate
-        # test stubs for when profile_support is being used.
-        # Additionally ensure those are always run even in default setting
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             net_profiles = self.net_profiles.list()
             net_profile_id = self.net_profiles.first().id
             api.neutron.profile_list(IsA(http.HttpRequest),
@@ -264,7 +265,7 @@ class NetworkTests(test.TestCase):
                      'admin_state': network.admin_state_up,
                      # subnet
                      'with_subnet': False}
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             form_data['net_profile_id'] = net_profile_id
         form_data.update(form_data_no_subnet())
         url = reverse('horizon:project:networks:create')
@@ -273,18 +274,20 @@ class NetworkTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
+    @override_settings(OPENSTACK_NEUTRON_NETWORK={'profile_support': 'cisco'})
+    def test_network_create_post_with_profile(self):
+        self.test_network_create_post(test_with_profile=True)
+
     @test.create_stubs({api.neutron: ('network_create',
                                       'subnet_create',
                                       'profile_list',)})
-    def test_network_create_post_with_subnet(self):
+    def test_network_create_post_with_subnet(self,
+                                             test_with_profile=False):
         network = self.networks.first()
         subnet = self.subnets.first()
         params = {'name': network.name,
                   'admin_state_up': network.admin_state_up}
-        # TODO(absubram): Remove if clause and create separate
-        # test stubs for when profile_support is being used.
-        # Additionally ensure those are always run even in default setting
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             net_profiles = self.net_profiles.list()
             net_profile_id = self.net_profiles.first().id
             api.neutron.profile_list(IsA(http.HttpRequest),
@@ -305,7 +308,7 @@ class NetworkTests(test.TestCase):
         form_data = {'net_name': network.name,
                      'admin_state': network.admin_state_up,
                      'with_subnet': True}
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             form_data['net_profile_id'] = net_profile_id
         form_data.update(form_data_subnet(subnet, allocation_pools=[]))
         url = reverse('horizon:project:networks:create')
@@ -314,16 +317,18 @@ class NetworkTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
+    @override_settings(OPENSTACK_NEUTRON_NETWORK={'profile_support': 'cisco'})
+    def test_network_create_post_with_subnet_w_profile(self):
+        self.test_network_create_post_with_subnet(test_with_profile=True)
+
     @test.create_stubs({api.neutron: ('network_create',
                                       'profile_list',)})
-    def test_network_create_post_network_exception(self):
+    def test_network_create_post_network_exception(self,
+                                                   test_with_profile=False):
         network = self.networks.first()
         params = {'name': network.name,
                   'admin_state_up': network.admin_state_up}
-        # TODO(absubram): Remove if clause and create separate
-        # test stubs for when profile_support is being used.
-        # Additionally ensure those are always run even in default setting
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             net_profiles = self.net_profiles.list()
             net_profile_id = self.net_profiles.first().id
             api.neutron.profile_list(IsA(http.HttpRequest),
@@ -337,7 +342,7 @@ class NetworkTests(test.TestCase):
                      'admin_state': network.admin_state_up,
                      # subnet
                      'with_subnet': False}
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             form_data['net_profile_id'] = net_profile_id
         form_data.update(form_data_no_subnet())
         url = reverse('horizon:project:networks:create')
@@ -346,17 +351,22 @@ class NetworkTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
+    @override_settings(OPENSTACK_NEUTRON_NETWORK={'profile_support': 'cisco'})
+    def test_network_create_post_nw_exception_w_profile(self):
+        self.test_network_create_post_network_exception(
+            test_with_profile=True)
+
     @test.create_stubs({api.neutron: ('network_create',
                                       'profile_list')})
-    def test_network_create_post_with_subnet_network_exception(self):
+    def test_network_create_post_with_subnet_network_exception(
+        self,
+        test_with_profile=False
+    ):
         network = self.networks.first()
         subnet = self.subnets.first()
         params = {'name': network.name,
                   'admin_state_up': network.admin_state_up}
-        # TODO(absubram): Remove if clause and create separate
-        # test stubs for when profile_support is being used.
-        # Additionally ensure those are always run even in default setting
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             net_profiles = self.net_profiles.list()
             net_profile_id = self.net_profiles.first().id
             api.neutron.profile_list(IsA(http.HttpRequest),
@@ -369,7 +379,7 @@ class NetworkTests(test.TestCase):
         form_data = {'net_name': network.name,
                      'admin_state': network.admin_state_up,
                      'with_subnet': True}
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             form_data['net_profile_id'] = net_profile_id
         form_data.update(form_data_subnet(subnet, allocation_pools=[]))
         url = reverse('horizon:project:networks:create')
@@ -378,19 +388,24 @@ class NetworkTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
+    @override_settings(OPENSTACK_NEUTRON_NETWORK={'profile_support': 'cisco'})
+    def test_nw_create_post_w_subnet_nw_exception_w_profile(self):
+        self.test_network_create_post_with_subnet_network_exception(
+            test_with_profile=True)
+
     @test.create_stubs({api.neutron: ('network_create',
                                       'network_delete',
                                       'subnet_create',
                                       'profile_list')})
-    def test_network_create_post_with_subnet_subnet_exception(self):
+    def test_network_create_post_with_subnet_subnet_exception(
+        self,
+        test_with_profile=False
+    ):
         network = self.networks.first()
         subnet = self.subnets.first()
         params = {'name': network.name,
                   'admin_state_up': network.admin_state_up}
-        # TODO(absubram): Remove if clause and create separate
-        # test stubs for when profile_support is being used.
-        # Additionally ensure those are always run even in default setting
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             net_profiles = self.net_profiles.list()
             net_profile_id = self.net_profiles.first().id
             api.neutron.profile_list(IsA(http.HttpRequest),
@@ -413,7 +428,7 @@ class NetworkTests(test.TestCase):
         form_data = {'net_name': network.name,
                      'admin_state': network.admin_state_up,
                      'with_subnet': True}
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             form_data['net_profile_id'] = net_profile_id
         form_data.update(form_data_subnet(subnet, allocation_pools=[]))
         url = reverse('horizon:project:networks:create')
@@ -422,14 +437,17 @@ class NetworkTests(test.TestCase):
         self.assertNoFormErrors(res)
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
+    @override_settings(OPENSTACK_NEUTRON_NETWORK={'profile_support': 'cisco'})
+    def test_nw_create_post_w_subnet_subnet_exception_w_profile(self):
+        self.test_network_create_post_with_subnet_subnet_exception(
+            test_with_profile=True)
+
     @test.create_stubs({api.neutron: ('profile_list',)})
-    def test_network_create_post_with_subnet_nocidr(self):
+    def test_network_create_post_with_subnet_nocidr(self,
+                                                    test_with_profile=False):
         network = self.networks.first()
         subnet = self.subnets.first()
-        # TODO(absubram): Remove if clause and create separate
-        # test stubs for when profile_support is being used.
-        # Additionally ensure those are always run even in default setting
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             net_profiles = self.net_profiles.list()
             net_profile_id = self.net_profiles.first().id
             api.neutron.profile_list(IsA(http.HttpRequest),
@@ -439,7 +457,7 @@ class NetworkTests(test.TestCase):
         form_data = {'net_name': network.name,
                      'admin_state': network.admin_state_up,
                      'with_subnet': True}
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             form_data['net_profile_id'] = net_profile_id
         form_data.update(form_data_subnet(subnet, cidr='',
                                           allocation_pools=[]))
@@ -449,14 +467,19 @@ class NetworkTests(test.TestCase):
         self.assertContains(res, escape('Specify "Network Address" or '
                                         'clear "Create Subnet" checkbox.'))
 
+    @override_settings(OPENSTACK_NEUTRON_NETWORK={'profile_support': 'cisco'})
+    def test_nw_create_post_w_subnet_no_cidr_w_profile(self):
+        self.test_network_create_post_with_subnet_nocidr(
+            test_with_profile=True)
+
     @test.create_stubs({api.neutron: ('profile_list',)})
-    def test_network_create_post_with_subnet_cidr_without_mask(self):
+    def test_network_create_post_with_subnet_cidr_without_mask(
+        self,
+        test_with_profile=False
+    ):
         network = self.networks.first()
         subnet = self.subnets.first()
-        # TODO(absubram): Remove if clause and create separate
-        # test stubs for when profile_support is being used.
-        # Additionally ensure those are always run even in default setting
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             net_profiles = self.net_profiles.list()
             net_profile_id = self.net_profiles.first().id
             api.neutron.profile_list(IsA(http.HttpRequest),
@@ -466,7 +489,7 @@ class NetworkTests(test.TestCase):
         form_data = {'net_name': network.name,
                      'admin_state': network.admin_state_up,
                      'with_subnet': True}
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             form_data['net_profile_id'] = net_profile_id
         form_data.update(form_data_subnet(subnet, cidr='10.0.0.0',
                                           allocation_pools=[]))
@@ -476,14 +499,19 @@ class NetworkTests(test.TestCase):
         expected_msg = "The subnet in the Network Address is too small (/32)."
         self.assertContains(res, expected_msg)
 
+    @override_settings(OPENSTACK_NEUTRON_NETWORK={'profile_support': 'cisco'})
+    def test_nw_create_post_w_subnet_cidr_without_mask_w_profile(self):
+        self.test_network_create_post_with_subnet_cidr_without_mask(
+            test_with_profile=True)
+
     @test.create_stubs({api.neutron: ('profile_list',)})
-    def test_network_create_post_with_subnet_cidr_inconsistent(self):
+    def test_network_create_post_with_subnet_cidr_inconsistent(
+        self,
+        test_with_profile=False
+    ):
         network = self.networks.first()
         subnet = self.subnets.first()
-        # TODO(absubram): Remove if clause and create separate
-        # test stubs for when profile_support is being used.
-        # Additionally ensure those are always run even in default setting
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             net_profiles = self.net_profiles.list()
             net_profile_id = self.net_profiles.first().id
             api.neutron.profile_list(IsA(http.HttpRequest),
@@ -495,7 +523,7 @@ class NetworkTests(test.TestCase):
         form_data = {'net_name': network.name,
                      'admin_state': network.admin_state_up,
                      'with_subnet': True}
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             form_data['net_profile_id'] = net_profile_id
         form_data.update(form_data_subnet(subnet, cidr=cidr,
                                           allocation_pools=[]))
@@ -505,14 +533,19 @@ class NetworkTests(test.TestCase):
         expected_msg = 'Network Address and IP version are inconsistent.'
         self.assertContains(res, expected_msg)
 
+    @override_settings(OPENSTACK_NEUTRON_NETWORK={'profile_support': 'cisco'})
+    def test_network_create_post_with_subnet_cidr_inconsistent_w_profile(self):
+        self.test_network_create_post_with_subnet_cidr_inconsistent(
+            test_with_profile=True)
+
     @test.create_stubs({api.neutron: ('profile_list',)})
-    def test_network_create_post_with_subnet_gw_inconsistent(self):
+    def test_network_create_post_with_subnet_gw_inconsistent(
+        self,
+        test_with_profile=False
+    ):
         network = self.networks.first()
         subnet = self.subnets.first()
-        # TODO(absubram): Remove if clause and create separate
-        # test stubs for when profile_support is being used.
-        # Additionally ensure those are always run even in default setting
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             net_profiles = self.net_profiles.list()
             net_profile_id = self.net_profiles.first().id
             api.neutron.profile_list(IsA(http.HttpRequest),
@@ -524,7 +557,7 @@ class NetworkTests(test.TestCase):
         form_data = {'net_name': network.name,
                      'admin_state': network.admin_state_up,
                      'with_subnet': True}
-        if api.neutron.is_port_profiles_supported():
+        if test_with_profile:
             form_data['net_profile_id'] = net_profile_id
         form_data.update(form_data_subnet(subnet, gateway_ip=gateway_ip,
                                           allocation_pools=[]))
@@ -533,6 +566,11 @@ class NetworkTests(test.TestCase):
 
         self.assertContains(res, 'Gateway IP and IP version are inconsistent.')
 
+    @override_settings(OPENSTACK_NEUTRON_NETWORK={'profile_support': 'cisco'})
+    def test_network_create_post_with_subnet_gw_inconsistent_w_profile(self):
+        self.test_network_create_post_with_subnet_gw_inconsistent(
+            test_with_profile=True)
+
     @test.create_stubs({api.neutron: ('network_get',)})
     def test_network_update_get(self):
         network = self.networks.first()
@@ -560,11 +598,11 @@ class NetworkTests(test.TestCase):
         redir_url = INDEX_URL
         self.assertRedirectsNoFollow(res, redir_url)
 
-    @test.create_stubs({api.neutron: ('network_modify',
+    @test.create_stubs({api.neutron: ('network_update',
                                       'network_get',)})
     def test_network_update_post(self):
         network = self.networks.first()
-        api.neutron.network_modify(IsA(http.HttpRequest), network.id,
+        api.neutron.network_update(IsA(http.HttpRequest), network.id,
                                    name=network.name,
                                    admin_state_up=network.admin_state_up)\
             .AndReturn(network)
@@ -581,11 +619,11 @@ class NetworkTests(test.TestCase):
 
         self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({api.neutron: ('network_modify',
+    @test.create_stubs({api.neutron: ('network_update',
                                       'network_get',)})
     def test_network_update_post_exception(self):
         network = self.networks.first()
-        api.neutron.network_modify(IsA(http.HttpRequest), network.id,
+        api.neutron.network_update(IsA(http.HttpRequest), network.id,
                                    name=network.name,
                                    admin_state_up=network.admin_state_up)\
             .AndRaise(self.exceptions.neutron)
@@ -1105,7 +1143,7 @@ class NetworkSubnetTests(test.TestCase):
                             'host_routes: Invalid IP address '
                             '(value=%s)' % host_routes.split(',')[1])
 
-    @test.create_stubs({api.neutron: ('subnet_modify',
+    @test.create_stubs({api.neutron: ('subnet_update',
                                       'subnet_get',)})
     def test_subnet_update_post(self):
         subnet = self.subnets.first()
@@ -1113,7 +1151,7 @@ class NetworkSubnetTests(test.TestCase):
             .AndReturn(subnet)
         api.neutron.subnet_get(IsA(http.HttpRequest), subnet.id)\
             .AndReturn(subnet)
-        api.neutron.subnet_modify(IsA(http.HttpRequest), subnet.id,
+        api.neutron.subnet_update(IsA(http.HttpRequest), subnet.id,
                                   name=subnet.name,
                                   enable_dhcp=subnet.enable_dhcp,
                                   dns_nameservers=[],
@@ -1131,7 +1169,7 @@ class NetworkSubnetTests(test.TestCase):
                             args=[subnet.network_id])
         self.assertRedirectsNoFollow(res, redir_url)
 
-    @test.create_stubs({api.neutron: ('subnet_modify',
+    @test.create_stubs({api.neutron: ('subnet_update',
                                       'subnet_get',)})
     def test_subnet_update_post_with_gateway_ip(self):
         subnet = self.subnets.first()
@@ -1140,7 +1178,7 @@ class NetworkSubnetTests(test.TestCase):
         api.neutron.subnet_get(IsA(http.HttpRequest), subnet.id)\
             .AndReturn(subnet)
         gateway_ip = '10.0.0.100'
-        api.neutron.subnet_modify(IsA(http.HttpRequest), subnet.id,
+        api.neutron.subnet_update(IsA(http.HttpRequest), subnet.id,
                                   name=subnet.name,
                                   gateway_ip=gateway_ip,
                                   enable_dhcp=subnet.enable_dhcp,
@@ -1160,7 +1198,7 @@ class NetworkSubnetTests(test.TestCase):
                             args=[subnet.network_id])
         self.assertRedirectsNoFollow(res, redir_url)
 
-    @test.create_stubs({api.neutron: ('subnet_modify',
+    @test.create_stubs({api.neutron: ('subnet_update',
                                       'subnet_get',)})
     def test_subnet_update_post_no_gateway(self):
         subnet = self.subnets.first()
@@ -1168,7 +1206,7 @@ class NetworkSubnetTests(test.TestCase):
             .AndReturn(subnet)
         api.neutron.subnet_get(IsA(http.HttpRequest), subnet.id)\
             .AndReturn(subnet)
-        api.neutron.subnet_modify(IsA(http.HttpRequest), subnet.id,
+        api.neutron.subnet_update(IsA(http.HttpRequest), subnet.id,
                                   name=subnet.name,
                                   gateway_ip=None,
                                   enable_dhcp=subnet.enable_dhcp,
@@ -1188,7 +1226,7 @@ class NetworkSubnetTests(test.TestCase):
                             args=[subnet.network_id])
         self.assertRedirectsNoFollow(res, redir_url)
 
-    @test.create_stubs({api.neutron: ('subnet_modify',
+    @test.create_stubs({api.neutron: ('subnet_update',
                                       'subnet_get',)})
     def test_subnet_update_post_with_additional_attributes(self):
         subnet = self.subnets.list()[1]
@@ -1196,7 +1234,7 @@ class NetworkSubnetTests(test.TestCase):
             .AndReturn(subnet)
         api.neutron.subnet_get(IsA(http.HttpRequest), subnet.id)\
             .AndReturn(subnet)
-        api.neutron.subnet_modify(IsA(http.HttpRequest), subnet.id,
+        api.neutron.subnet_update(IsA(http.HttpRequest), subnet.id,
                                   name=subnet.name,
                                   enable_dhcp=False,
                                   dns_nameservers=subnet.dns_nameservers,
@@ -1214,7 +1252,7 @@ class NetworkSubnetTests(test.TestCase):
                             args=[subnet.network_id])
         self.assertRedirectsNoFollow(res, redir_url)
 
-    @test.create_stubs({api.neutron: ('subnet_modify',
+    @test.create_stubs({api.neutron: ('subnet_update',
                                       'subnet_get',)})
     def test_subnet_update_post_gw_inconsistent(self):
         subnet = self.subnets.first()
@@ -1232,7 +1270,7 @@ class NetworkSubnetTests(test.TestCase):
 
         self.assertContains(res, 'Gateway IP and IP version are inconsistent.')
 
-    @test.create_stubs({api.neutron: ('subnet_modify',
+    @test.create_stubs({api.neutron: ('subnet_update',
                                       'subnet_get',)})
     def test_subnet_update_post_invalid_nameservers(self):
         subnet = self.subnets.first()
@@ -1252,7 +1290,7 @@ class NetworkSubnetTests(test.TestCase):
                             'dns_nameservers: Invalid IP address '
                             '(value=%s)' % dns_nameservers[1])
 
-    @test.create_stubs({api.neutron: ('subnet_modify',
+    @test.create_stubs({api.neutron: ('subnet_update',
                                       'subnet_get',)})
     def test_subnet_update_post_invalid_routes_destination_only(self):
         subnet = self.subnets.first()
@@ -1274,7 +1312,7 @@ class NetworkSubnetTests(test.TestCase):
                             'Destination CIDR and nexthop must be specified '
                             '(value=%s)' % host_routes)
 
-    @test.create_stubs({api.neutron: ('subnet_modify',
+    @test.create_stubs({api.neutron: ('subnet_update',
                                       'subnet_get',)})
     def test_subnet_update_post_invalid_routes_three_entries(self):
         subnet = self.subnets.first()
@@ -1296,7 +1334,7 @@ class NetworkSubnetTests(test.TestCase):
                             'Destination CIDR and nexthop must be specified '
                             '(value=%s)' % host_routes)
 
-    @test.create_stubs({api.neutron: ('subnet_modify',
+    @test.create_stubs({api.neutron: ('subnet_update',
                                       'subnet_get',)})
     def test_subnet_update_post_invalid_routes_invalid_destination(self):
         subnet = self.subnets.first()
@@ -1317,7 +1355,7 @@ class NetworkSubnetTests(test.TestCase):
                             'host_routes: Invalid IP address '
                             '(value=%s)' % host_routes.split(',')[0])
 
-    @test.create_stubs({api.neutron: ('subnet_modify',
+    @test.create_stubs({api.neutron: ('subnet_update',
                                       'subnet_get',)})
     def test_subnet_update_post_invalid_routes_nexthop_ip_network(self):
         subnet = self.subnets.first()
@@ -1436,12 +1474,12 @@ class NetworkPortTests(test.TestCase):
         self.assertTemplateUsed(res, 'project/networks/ports/update.html')
 
     @test.create_stubs({api.neutron: ('port_get',
-                                      'port_modify')})
+                                      'port_update')})
     def test_port_update_post(self):
         port = self.ports.first()
         api.neutron.port_get(IsA(http.HttpRequest), port.id)\
             .AndReturn(port)
-        api.neutron.port_modify(IsA(http.HttpRequest), port.id,
+        api.neutron.port_update(IsA(http.HttpRequest), port.id,
                                 name=port.name,
                                 admin_state_up=port.admin_state_up)\
             .AndReturn(port)
@@ -1460,12 +1498,12 @@ class NetworkPortTests(test.TestCase):
         self.assertRedirectsNoFollow(res, redir_url)
 
     @test.create_stubs({api.neutron: ('port_get',
-                                      'port_modify')})
+                                      'port_update')})
     def test_port_update_post_exception(self):
         port = self.ports.first()
         api.neutron.port_get(IsA(http.HttpRequest), port.id)\
             .AndReturn(port)
-        api.neutron.port_modify(IsA(http.HttpRequest), port.id,
+        api.neutron.port_update(IsA(http.HttpRequest), port.id,
                                 name=port.name,
                                 admin_state_up=port.admin_state_up)\
             .AndRaise(self.exceptions.neutron)
