@@ -38,31 +38,36 @@ class CreateNetworkInfoAction(workflows.Action):
                                label=_("Network Name"),
                                required=False)
     if api.neutron.is_port_profiles_supported():
-        net_profile_id = forms.ChoiceField(label=_("Network Profile"))
+        widget = None
+    else:
+        widget = forms.HiddenInput()
+    net_profile_id = forms.ChoiceField(label=_("Network Profile"),
+                                       required=False,
+                                       widget=widget)
     admin_state = forms.BooleanField(label=_("Admin State"),
                                      initial=True, required=False)
 
-    if api.neutron.is_port_profiles_supported():
-        def __init__(self, request, *args, **kwargs):
-            super(CreateNetworkInfoAction, self).__init__(request,
-                                                          *args, **kwargs)
+    def __init__(self, request, *args, **kwargs):
+        super(CreateNetworkInfoAction, self).__init__(request,
+                                                      *args, **kwargs)
+        if api.neutron.is_port_profiles_supported():
             self.fields['net_profile_id'].choices = (
                 self.get_network_profile_choices(request))
 
-        def get_network_profile_choices(self, request):
-            profile_choices = [('', _("Select a profile"))]
-            for profile in self._get_profiles(request, 'network'):
-                profile_choices.append((profile.id, profile.name))
-            return profile_choices
+    def get_network_profile_choices(self, request):
+        profile_choices = [('', _("Select a profile"))]
+        for profile in self._get_profiles(request, 'network'):
+            profile_choices.append((profile.id, profile.name))
+        return profile_choices
 
-        def _get_profiles(self, request, type_p):
-            try:
-                profiles = api.neutron.profile_list(request, type_p)
-            except Exception:
-                profiles = []
-                msg = _('Network Profiles could not be retrieved.')
-                exceptions.handle(request, msg)
-            return profiles
+    def _get_profiles(self, request, type_p):
+        profiles = []
+        try:
+            profiles = api.neutron.profile_list(request, type_p)
+        except Exception:
+            msg = _('Network Profiles could not be retrieved.')
+            exceptions.handle(request, msg)
+        return profiles
     # TODO(absubram): Add ability to view network profile information
     # in the network detail if a profile is used.
 
@@ -75,10 +80,7 @@ class CreateNetworkInfoAction(workflows.Action):
 
 class CreateNetworkInfo(workflows.Step):
     action_class = CreateNetworkInfoAction
-    if api.neutron.is_port_profiles_supported():
-        contributes = ("net_name", "admin_state", "net_profile_id")
-    else:
-        contributes = ("net_name", "admin_state")
+    contributes = ("net_name", "admin_state", "net_profile_id")
 
 
 class CreateSubnetInfoAction(workflows.Action):
@@ -168,8 +170,8 @@ class CreateSubnetDetailAction(workflows.Action):
     allocation_pools = forms.CharField(
         widget=forms.Textarea(),
         label=_("Allocation Pools"),
-        help_text=_("IP address allocation pools. Each entry is "
-                    "&lt;start_ip_address&gt;,&lt;end_ip_address&gt; "
+        help_text=_("IP address allocation pools. Each entry is: "
+                    "start_ip_address,end_ip_address "
                     "(e.g., 192.168.1.100,192.168.1.120) "
                     "and one entry per line."),
         required=False)
@@ -183,7 +185,7 @@ class CreateSubnetDetailAction(workflows.Action):
         widget=forms.widgets.Textarea(),
         label=_("Host Routes"),
         help_text=_("Additional routes announced to the hosts. "
-                    "Each entry is &lt;destination_cidr&gt;,&lt;nexthop&gt; "
+                    "Each entry is: destination_cidr,nexthop "
                     "(e.g., 192.168.200.0/24,10.56.1.254) "
                     "and one entry per line."),
         required=False)
