@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013,  Big Switch Networks, Inc
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -12,49 +14,34 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import logging
+
 from django.core.urlresolvers import reverse
 from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ungettext_lazy
 
 from openstack_dashboard.dashboards.project.routers.extensions.routerrules\
     import rulemanager
-from openstack_dashboard import policy
 
 from horizon import tables
 
+LOG = logging.getLogger(__name__)
 
-class AddRouterRule(policy.PolicyTargetMixin, tables.LinkAction):
+
+class AddRouterRule(tables.LinkAction):
     name = "create"
     verbose_name = _("Add Router Rule")
     url = "horizon:project:routers:addrouterrule"
-    classes = ("ajax-modal",)
-    icon = "plus"
-    policy_rules = (("network", "update_router"),)
+    classes = ("ajax-modal", "btn-create")
 
     def get_link_url(self, datum=None):
         router_id = self.table.kwargs['router_id']
         return reverse(self.url, args=(router_id,))
 
 
-class RemoveRouterRule(policy.PolicyTargetMixin, tables.DeleteAction):
-    @staticmethod
-    def action_present(count):
-        return ungettext_lazy(
-            u"Delete Router Rule",
-            u"Delete Router Rules",
-            count
-        )
-
-    @staticmethod
-    def action_past(count):
-        return ungettext_lazy(
-            u"Deleted Router Rule",
-            u"Deleted Router Rules",
-            count
-        )
-
+class RemoveRouterRule(tables.DeleteAction):
+    data_type_singular = _("Router Rule")
+    data_type_plural = _("Router Rules")
     failure_url = 'horizon:project:routers:detail'
-    policy_rules = (("network", "update_router"),)
 
     def delete(self, request, obj_id):
         router_id = self.table.kwargs['router_id']
@@ -72,7 +59,7 @@ class RouterRulesTable(tables.DataTable):
     def get_object_display(self, rule):
         return "(%(action)s) %(source)s -> %(destination)s" % rule
 
-    class Meta(object):
+    class Meta:
         name = "routerrules"
         verbose_name = _("Router Rules")
         table_actions = (AddRouterRule, RemoveRouterRule)
