@@ -19,11 +19,12 @@ from horizon import exceptions
 from horizon import forms
 from horizon import tables
 from horizon import tabs
+from horizon.utils import memoized
 
-from django.core.urlresolvers import reverse  # noqa
-from django.core.urlresolvers import reverse_lazy  # noqa
+from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse_lazy
 from django.http import HttpResponse  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 from django.views import generic
 
 from openstack_dashboard import api
@@ -66,21 +67,59 @@ class SelectTemplateView(forms.ModalFormView):
         return kwargs
 
 
+class ChangeTemplateView(forms.ModalFormView):
+    form_class = project_forms.ChangeTemplateForm
+    template_name = 'project/stacks/change_template.html'
+    success_url = reverse_lazy('horizon:project:stacks:edit_stack')
+
+    def get_context_data(self, **kwargs):
+        context = super(ChangeTemplateView, self).get_context_data(**kwargs)
+        context['stack'] = self.get_object()
+        return context
+
+    @memoized.memoized_method
+    def get_object(self):
+        stack_id = self.kwargs['stack_id']
+        try:
+            self._stack = api.heat.stack_get(self.request, stack_id)
+        except Exception:
+            msg = _("Unable to retrieve stack.")
+            redirect = reverse('horizon:project:stacks:index')
+            exceptions.handle(self.request, msg, redirect=redirect)
+        return self._stack
+
+    def get_initial(self):
+        stack = self.get_object()
+        return {'stack_id': stack.id,
+                'stack_name': stack.stack_name
+                }
+
+    def get_form_kwargs(self):
+        kwargs = super(ChangeTemplateView, self).get_form_kwargs()
+        kwargs['next_view'] = EditStackView
+        return kwargs
+
+
 class CreateStackView(forms.ModalFormView):
-    form_class = project_forms.StackCreateForm
+    form_class = project_forms.CreateStackForm
     template_name = 'project/stacks/create.html'
     success_url = reverse_lazy('horizon:project:stacks:index')
 
     def get_initial(self):
         initial = {}
-        if 'template_data' in self.kwargs:
-            initial['template_data'] = self.kwargs['template_data']
-        if 'template_url' in self.kwargs:
-            initial['template_url'] = self.kwargs['template_url']
+        self.load_kwargs(initial)
         if 'parameters' in self.kwargs:
             initial['parameters'] = json.dumps(self.kwargs['parameters'])
         return initial
 
+    def load_kwargs(self, initial):
+        # load the "passed through" data from template form
+        for prefix in ('template', 'environment'):
+            for suffix in ('_data', '_url'):
+                key = prefix + suffix
+                if key in self.kwargs:
+                    initial[key] = self.kwargs[key]
+
     def get_form_kwargs(self):
         kwargs = super(CreateStackView, self).get_form_kwargs()
         if 'parameters' in self.kwargs:
@@ -91,28 +130,63 @@ class CreateStackView(forms.ModalFormView):
         return kwargs
 
 
+# edit stack parameters, coming from template selector
+class EditStackView(CreateStackView):
+    form_class = project_forms.EditStackForm
+    template_name = 'project/stacks/update.html'
+    success_url = reverse_lazy('horizon:project:stacks:index')
+
+    def get_initial(self):
+        initial = super(EditStackView, self).get_initial()
+
+        initial['stack'] = self.get_object()['stack']
+        if initial['stack']:
+            initial['stack_id'] = initial['stack'].id
+            initial['stack_name'] = initial['stack'].stack_name
+
+        return initial
+
+    def get_context_data(self, **kwargs):
+        context = super(EditStackView, self).get_context_data(**kwargs)
+        context['stack'] = self.get_object()['stack']
+        return context
+
+    @memoized.memoized_method
+    def get_object(self):
+        stack_id = self.kwargs['stack_id']
+        try:
+            stack = {}
+            stack['stack'] = api.heat.stack_get(self.request, stack_id)
+            stack['template'] = api.heat.template_get(self.request, stack_id)
+            self._stack = stack
+        except Exception:
+            msg = _("Unable to retrieve stack.")
+            redirect = reverse('horizon:project:stacks:index')
+            exceptions.handle(self.request, msg, redirect=redirect)
+        return self._stack
+
+
 class DetailView(tabs.TabView):
     tab_group_class = project_tabs.StackDetailTabs
     template_name = 'project/stacks/detail.html'
 
     def get_context_data(self, **kwargs):
         context = super(DetailView, self).get_context_data(**kwargs)
-        context["stack"] = self.get_data(self.request)
+        context["stack"] = self.get_data(self.request, **kwargs)
         return context
 
+    @memoized.memoized_method
     def get_data(self, request, **kwargs):
-        if not hasattr(self, "_stack"):
-            stack_id = kwargs['stack_id']
-            try:
-                stack = api.heat.stack_get(request, stack_id)
-                self._stack = stack
-                request.session['stack_id'] = stack.id
-                request.session['stack_name'] = stack.stack_name
-            except Exception:
-                msg = _("Unable to retrieve stack.")
-                redirect = reverse('horizon:project:stacks:index')
-                exceptions.handle(request, msg, redirect=redirect)
-        return self._stack
+        stack_id = kwargs['stack_id']
+        try:
+            stack = api.heat.stack_get(request, stack_id)
+            request.session['stack_id'] = stack.id
+            request.session['stack_name'] = stack.stack_name
+            return stack
+        except Exception:
+            msg = _("Unable to retrieve stack.")
+            redirect = reverse('horizon:project:stacks:index')
+            exceptions.handle(request, msg, redirect=redirect)
 
     def get_tabs(self, request, **kwargs):
         stack = self.get_data(request, **kwargs)
@@ -129,33 +203,31 @@ class ResourceView(tabs.TabView):
         context["metadata"] = self.get_metadata(self.request, **kwargs)
         return context
 
+    @memoized.memoized_method
     def get_data(self, request, **kwargs):
-        if not hasattr(self, "_resource"):
-            try:
-                resource = api.heat.resource_get(
-                    request,
-                    kwargs['stack_id'],
-                    kwargs['resource_name'])
-                self._resource = resource
-            except Exception:
-                msg = _("Unable to retrieve resource.")
-                redirect = reverse('horizon:project:stacks:index')
-                exceptions.handle(request, msg, redirect=redirect)
-        return self._resource
+        try:
+            resource = api.heat.resource_get(
+                request,
+                kwargs['stack_id'],
+                kwargs['resource_name'])
+            return resource
+        except Exception:
+            msg = _("Unable to retrieve resource.")
+            redirect = reverse('horizon:project:stacks:index')
+            exceptions.handle(request, msg, redirect=redirect)
 
+    @memoized.memoized_method
     def get_metadata(self, request, **kwargs):
-        if not hasattr(self, "_metadata"):
-            try:
-                metadata = api.heat.resource_metadata_get(
-                    request,
-                    kwargs['stack_id'],
-                    kwargs['resource_name'])
-                self._metadata = json.dumps(metadata, indent=2)
-            except Exception:
-                msg = _("Unable to retrieve metadata.")
-                redirect = reverse('horizon:project:stacks:index')
-                exceptions.handle(request, msg, redirect=redirect)
-        return self._metadata
+        try:
+            metadata = api.heat.resource_metadata_get(
+                request,
+                kwargs['stack_id'],
+                kwargs['resource_name'])
+            return json.dumps(metadata, indent=2)
+        except Exception:
+            msg = _("Unable to retrieve metadata.")
+            redirect = reverse('horizon:project:stacks:index')
+            exceptions.handle(request, msg, redirect=redirect)
 
     def get_tabs(self, request, **kwargs):
         resource = self.get_data(request, **kwargs)
