@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2011 United States Government as represented by the
 # Administrator of the National Aeronautics and Space Administration.
 # All Rights Reserved.
@@ -18,7 +20,7 @@
 
 from django.core.urlresolvers import reverse
 from django import http
-from mox3.mox import IsA  # noqa
+from mox import IsA  # noqa
 
 from openstack_dashboard import api
 from openstack_dashboard.api import cinder
@@ -27,7 +29,6 @@ from openstack_dashboard.usage import quotas
 
 
 INDEX_URL = reverse('horizon:project:volumes:index')
-VOLUME_SNAPSHOTS_TAB_URL = reverse('horizon:project:volumes:snapshots_tab')
 
 
 class VolumeSnapshotsViewTests(test.TestCase):
@@ -37,11 +38,10 @@ class VolumeSnapshotsViewTests(test.TestCase):
         volume = self.cinder_volumes.first()
         cinder.volume_get(IsA(http.HttpRequest), volume.id) \
             .AndReturn(volume)
-        snapshot_used = len(self.cinder_volume_snapshots.list())
         usage_limit = {'maxTotalVolumeGigabytes': 250,
                        'gigabytesUsed': 20,
-                       'snapshotsUsed': snapshot_used,
-                       'maxTotalSnapshots': 6}
+                       'volumesUsed': len(self.cinder_volumes.list()),
+                       'maxTotalVolumes': 6}
         quotas.tenant_limit_usages(IsA(http.HttpRequest)).\
             AndReturn(usage_limit)
         self.mox.ReplayAll()
@@ -77,7 +77,7 @@ class VolumeSnapshotsViewTests(test.TestCase):
         url = reverse('horizon:project:volumes:volumes:create_snapshot',
                       args=[volume.id])
         res = self.client.post(url, formData)
-        self.assertRedirectsNoFollow(res, VOLUME_SNAPSHOTS_TAB_URL)
+        self.assertRedirectsNoFollow(res, INDEX_URL)
 
     @test.create_stubs({cinder: ('volume_get',
                                  'volume_snapshot_create',)})
@@ -103,36 +103,39 @@ class VolumeSnapshotsViewTests(test.TestCase):
         url = reverse('horizon:project:volumes:volumes:create_snapshot',
                       args=[volume.id])
         res = self.client.post(url, formData)
-        self.assertRedirectsNoFollow(res, VOLUME_SNAPSHOTS_TAB_URL)
+        self.assertRedirectsNoFollow(res, INDEX_URL)
 
-    @test.create_stubs({api.cinder: ('volume_snapshot_list_paged',
+    @test.create_stubs({api.nova: ('server_list',),
+                        api.cinder: ('volume_snapshot_list',
                                      'volume_list',
-                                     'volume_backup_supported',
-                                     'volume_snapshot_delete')})
+                                     'volume_snapshot_delete'),
+                        quotas: ('tenant_quota_usages',)})
     def test_delete_volume_snapshot(self):
         vol_snapshots = self.cinder_volume_snapshots.list()
         volumes = self.cinder_volumes.list()
         snapshot = self.cinder_volume_snapshots.first()
 
-        api.cinder.volume_backup_supported(IsA(http.HttpRequest)). \
-            MultipleTimes().AndReturn(True)
-        api.cinder.volume_snapshot_list_paged(
-            IsA(http.HttpRequest), paginate=True, marker=None,
-            sort_dir='desc').AndReturn([vol_snapshots, False, False])
+        api.cinder.volume_snapshot_list(IsA(http.HttpRequest)). \
+            AndReturn(vol_snapshots)
         api.cinder.volume_list(IsA(http.HttpRequest)). \
             AndReturn(volumes)
 
         api.cinder.volume_snapshot_delete(IsA(http.HttpRequest), snapshot.id)
-        api.cinder.volume_snapshot_list_paged(
-            IsA(http.HttpRequest), paginate=True, marker=None,
-            sort_dir='desc').AndReturn([[], False, False])
+        api.cinder.volume_list(IsA(http.HttpRequest), search_opts=None). \
+            AndReturn(volumes)
+        api.nova.server_list(IsA(http.HttpRequest), search_opts=None). \
+            AndReturn([self.servers.list(), False])
+        api.cinder.volume_snapshot_list(IsA(http.HttpRequest)). \
+            AndReturn([])
         api.cinder.volume_list(IsA(http.HttpRequest)). \
             AndReturn(volumes)
+        quotas.tenant_quota_usages(IsA(http.HttpRequest)).MultipleTimes(). \
+            AndReturn(self.quota_usages.first())
         self.mox.ReplayAll()
 
         formData = {'action':
                     'volume_snapshots__delete__%s' % snapshot.id}
-        res = self.client.post(VOLUME_SNAPSHOTS_TAB_URL, formData, follow=True)
+        res = self.client.post(INDEX_URL, formData, follow=True)
 
         self.assertIn("Scheduled deletion of Volume Snapshot: test snapshot",
                       [m.message for m in res.context['messages']])
@@ -149,12 +152,17 @@ class VolumeSnapshotsViewTests(test.TestCase):
 
         self.mox.ReplayAll()
 
-        url = reverse('horizon:project:volumes:snapshots:detail',
+        url = reverse('horizon:project:volumes:detail',
                       args=[snapshot.id])
         res = self.client.get(url)
 
-        self.assertTemplateUsed(res, 'horizon/common/_detail.html')
-        self.assertEqual(res.context['snapshot'].id, snapshot.id)
+        self.assertContains(res,
+                            "<h2>Volume Snapshot Details: %s</h2>" %
+                            snapshot.name,
+                            1, 200)
+        self.assertContains(res, "<dd>test snapshot</dd>", 1, 200)
+        self.assertContains(res, "<dd>%s</dd>" % snapshot.id, 1, 200)
+        self.assertContains(res, "<dd>Available</dd>", 1, 200)
 
     @test.create_stubs({api.cinder: ('volume_snapshot_get',)})
     def test_volume_snapshot_detail_get_with_exception(self):
@@ -165,7 +173,7 @@ class VolumeSnapshotsViewTests(test.TestCase):
             AndRaise(self.exceptions.cinder)
         self.mox.ReplayAll()
 
-        url = reverse('horizon:project:volumes:snapshots:detail',
+        url = reverse('horizon:project:volumes:detail',
                       args=[snapshot.id])
         res = self.client.get(url)
 
@@ -184,30 +192,8 @@ class VolumeSnapshotsViewTests(test.TestCase):
 
         self.mox.ReplayAll()
 
-        url = reverse('horizon:project:volumes:snapshots:detail',
+        url = reverse('horizon:project:volumes:detail',
                       args=[snapshot.id])
         res = self.client.get(url)
 
         self.assertRedirectsNoFollow(res, INDEX_URL)
-
-    @test.create_stubs({cinder: ('volume_snapshot_update',
-                                 'volume_snapshot_get')})
-    def test_update_snapshot(self):
-        snapshot = self.cinder_volume_snapshots.first()
-
-        cinder.volume_snapshot_get(IsA(http.HttpRequest), snapshot.id) \
-            .AndReturn(snapshot)
-        cinder.volume_snapshot_update(IsA(http.HttpRequest),
-                                      snapshot.id,
-                                      snapshot.name,
-                                      snapshot.description) \
-            .AndReturn(snapshot)
-        self.mox.ReplayAll()
-
-        formData = {'method': 'UpdateSnapshotForm',
-                    'name': snapshot.name,
-                    'description': snapshot.description}
-        url = reverse(('horizon:project:volumes:snapshots:update'),
-                      args=[snapshot.id])
-        res = self.client.post(url, formData)
-        self.assertRedirectsNoFollow(res, INDEX_URL)
