@@ -14,22 +14,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import include  # noqa
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
-from .views import (IndexView, CreateView, EditAttachmentsView, DetailView,
-                    CreateSnapshotView)
+from openstack_dashboard.dashboards.project.volumes import views
+from openstack_dashboard.dashboards.project.volumes.volumes \
+    import urls as volume_urls
 
 
-urlpatterns = patterns('openstack_dashboard.dashboards.project.volumes.views',
-    url(r'^$', IndexView.as_view(), name='index'),
-    url(r'^create/$', CreateView.as_view(), name='create'),
-    url(r'^(?P<volume_id>[^/]+)/attach/$',
-        EditAttachmentsView.as_view(),
-        name='attach'),
-    url(r'^(?P<volume_id>[^/]+)/create_snapshot/$',
-        CreateSnapshotView.as_view(),
-        name='create_snapshot'),
-    url(r'^(?P<volume_id>[^/]+)/$',
-        DetailView.as_view(),
+urlpatterns = patterns('',
+    url(r'^$', views.IndexView.as_view(), name='index'),
+    url(r'', include(volume_urls, namespace='volumes')),
+    url(r'^snapshots/(?P<snapshot_id>[^/]+)/$',
+        views.DetailView.as_view(),
         name='detail'),
 )
