@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 # Copyright 2013, Mirantis Inc
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -11,12 +13,15 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+#
+# @author: Tatiana Mazur
 
-from django.conf.urls import url
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
 from openstack_dashboard.dashboards.project.vpn import views
 
-urlpatterns = [
+urlpatterns = patterns('openstack_dashboard.dashboards.project.vpn.views',
     url(r'^$', views.IndexView.as_view(), name='index'),
     url(r'^addikepolicy$',
         views.AddIKEPolicyView.as_view(), name='addikepolicy'),
@@ -44,5 +49,4 @@ urlpatterns = [
         views.VPNServiceDetailsView.as_view(), name='vpnservicedetails'),
     url(r'^ipsecsiteconnection/(?P<ipsecsiteconnection_id>[^/]+)/$',
         views.IPSecSiteConnectionDetailsView.as_view(),
-        name='ipsecsiteconnectiondetails'),
-]
+        name='ipsecsiteconnectiondetails'))
