@@ -18,7 +18,6 @@
 from django.utils.translation import ugettext_lazy as _
 
 import horizon
-from openstack_dashboard.api import neutron as neutron
 from openstack_dashboard.dashboards.router import dashboard
 
 
@@ -27,5 +26,4 @@ class Nexus1000v(horizon.Panel):
     slug = 'nexus1000v'
     permissions = ('openstack.services.network',)
 
-if neutron.is_port_profiles_supported():
-    dashboard.Router.register(Nexus1000v)
+dashboard.Router.register(Nexus1000v)
