@@ -17,8 +17,8 @@
 
 import logging
 
-from django.core.urlresolvers import reverse  # noqa
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.core.urlresolvers import reverse
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import exceptions
 from horizon import tables
@@ -57,11 +57,13 @@ class EditNetworkProfile(tables.LinkAction):
 
 
 class NetworkProfile(tables.DataTable):
-    id = tables.Column("profile_id", verbose_name=_("Profile ID"), hidden=True)
+    id = tables.Column("id", hidden=True)
     name = tables.Column("name", verbose_name=_("Network Profile"), )
     project = tables.Column("project_name", verbose_name=_("Project"))
     segment_type = tables.Column("segment_type",
                                  verbose_name=_("Segment Type"))
+    sub_type = tables.Column("sub_type",
+                             verbose_name=_("Sub Type"))
     segment_range = tables.Column("segment_range",
                                   verbose_name=_("Segment Range"))
     multicast_ip_range = tables.Column("multicast_ip_range",
@@ -76,17 +78,10 @@ class NetworkProfile(tables.DataTable):
         row_actions = (EditNetworkProfile, DeleteNetworkProfile,)
 
 
-class EditPolicyProfile(tables.LinkAction):
-    name = "edit"
-    verbose_name = _("Edit Policy Profile")
-    url = "horizon:project:images_and_snapshots:images:update"
-    classes = ("ajax-modal", "btn-edit")
-
-
 class PolicyProfile(tables.DataTable):
-    id = tables.Column("profile_id", verbose_name=_("Profile ID"), hidden=True)
+    id = tables.Column("id", hidden=True)
     name = tables.Column("name", verbose_name=_("Policy Profile"), )
-    project_id = tables.Column("project_name", verbose_name=_("Project"))
+    project = tables.Column("project_name", verbose_name=_("Project"))
 
     class Meta:
         name = "policy_profile"
