@@ -1,6 +1,6 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-# Copyright 2012 Openstack, LLC
+# Copyright 2012 OpenStack Foundation
 # Copyright 2012 Nebula, Inc.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -23,9 +23,14 @@ import horizon
 class Settings(horizon.Dashboard):
     name = _("Settings")
     slug = "settings"
-    panels = ('user',)
+    panels = ('user', 'password', )
     default_panel = 'user'
-    nav = False
+
+    def nav(self, context):
+        dash = context['request'].horizon.get('dashboard', None)
+        if dash and dash.slug == self.slug:
+            return True
+        return False
 
 
 horizon.register(Settings)
