@@ -17,11 +17,11 @@
 from datetime import datetime  # noqa
 import pytz
 
-from django.conf import settings  # noqa
+from django.conf import settings
 from django import shortcuts
 from django.utils import encoding
 from django.utils import translation
-from django.utils.translation import ugettext_lazy as _  # noqa
+from django.utils.translation import ugettext_lazy as _
 
 from horizon import forms
 from horizon import messages
