@@ -22,12 +22,12 @@ from __future__ import absolute_import
 
 from horizon import exceptions
 
-from openstack_dashboard.test import helpers as test
 from openstack_dashboard.api import base as api_base
+from openstack_dashboard.test import helpers as test
 
 
 class APIResource(api_base.APIResourceWrapper):
-    """ Simple APIResource for testing """
+    """Simple APIResource for testing."""
     _attrs = ['foo', 'bar', 'baz']
 
     @staticmethod
@@ -44,7 +44,7 @@ class APIResource(api_base.APIResourceWrapper):
 
 
 class APIDict(api_base.APIDictWrapper):
-    """ Simple APIDict for testing """
+    """Simple APIDict for testing."""
     _attrs = ['foo', 'bar', 'baz']
 
     @staticmethod
@@ -73,6 +73,13 @@ class APIResourceWrapperTests(test.TestCase):
         with self.assertRaises(AttributeError):
             resource.baz
 
+    def test_repr(self):
+        resource = APIResource.get_instance()
+        resource_str = resource.__repr__()
+        self.assertIn('foo', resource_str)
+        self.assertIn('bar', resource_str)
+        self.assertNotIn('baz', resource_str)
+
 
 class APIDictWrapperTests(test.TestCase):
     # APIDict allows for both attribute access and dictionary style [element]
@@ -109,25 +116,20 @@ class APIDictWrapperTests(test.TestCase):
 
 
 class ApiHelperTests(test.TestCase):
-    """ Tests for functions that don't use one of the api objects """
+    """Tests for functions that don't use one of the api objects."""
 
     def test_url_for(self):
         url = api_base.url_for(self.request, 'image')
         self.assertEqual(url, 'http://public.glance.example.com:9292/v1')
 
-        url = api_base.url_for(self.request, 'image', admin=False)
-        self.assertEqual(url, 'http://public.glance.example.com:9292/v1')
-
-        url = api_base.url_for(self.request, 'image', admin=True)
+        url = api_base.url_for(self.request, 'image', endpoint_type='adminURL')
         self.assertEqual(url, 'http://admin.glance.example.com:9292/v1')
 
         url = api_base.url_for(self.request, 'compute')
         self.assertEqual(url, 'http://public.nova.example.com:8774/v2')
 
-        url = api_base.url_for(self.request, 'compute', admin=False)
-        self.assertEqual(url, 'http://public.nova.example.com:8774/v2')
-
-        url = api_base.url_for(self.request, 'compute', admin=True)
+        url = api_base.url_for(self.request, 'compute',
+                               endpoint_type='adminURL')
         self.assertEqual(url, 'http://admin.nova.example.com:8774/v2')
 
         url = api_base.url_for(self.request, 'volume')
@@ -137,13 +139,77 @@ class ApiHelperTests(test.TestCase):
                                endpoint_type="internalURL")
         self.assertEqual(url, 'http://int.nova.example.com:8776/v1')
 
-        url = api_base.url_for(self.request, 'volume', admin=False)
-        self.assertEqual(url, 'http://public.nova.example.com:8776/v1')
-
-        url = api_base.url_for(self.request, 'volume', admin=True)
+        url = api_base.url_for(self.request, 'volume',
+                               endpoint_type='adminURL')
         self.assertEqual(url, 'http://admin.nova.example.com:8776/v1')
 
         self.assertNotIn('notAnApi', self.request.user.service_catalog,
                          'Select a new nonexistent service catalog key')
         with self.assertRaises(exceptions.ServiceCatalogException):
             url = api_base.url_for(self.request, 'notAnApi')
+
+        self.request.user.services_region = "RegionTwo"
+        url = api_base.url_for(self.request, 'compute')
+        self.assertEqual(url, 'http://public.nova2.example.com:8774/v2')
+
+        self.request.user.services_region = "RegionTwo"
+        url = api_base.url_for(self.request, 'compute',
+                               endpoint_type='adminURL')
+        self.assertEqual(url, 'http://admin.nova2.example.com:8774/v2')
+
+        self.request.user.services_region = "RegionTwo"
+        with self.assertRaises(exceptions.ServiceCatalogException):
+            url = api_base.url_for(self.request, 'image')
+
+        self.request.user.services_region = "bogus_value"
+        url = api_base.url_for(self.request, 'identity',
+                               endpoint_type='adminURL')
+        self.assertEqual(url, 'http://admin.keystone.example.com:35357/v2.0')
+
+        self.request.user.services_region = "bogus_value"
+        with self.assertRaises(exceptions.ServiceCatalogException):
+            url = api_base.url_for(self.request, 'image')
+
+
+class QuotaSetTests(test.TestCase):
+
+    def test_quotaset_add_with_plus(self):
+        quota_dict = {'foo': 1, 'bar': 10}
+        other_quota_dict = {'my_test': 12}
+        quota_set = api_base.QuotaSet(quota_dict)
+        other_quota_set = api_base.QuotaSet(other_quota_dict)
+
+        quota_set += other_quota_set
+        self.assertEqual(len(quota_set), 3)
+
+        quota_dict.update(other_quota_dict)
+        for q in quota_set:
+            self.assertEqual(q.limit, quota_dict[q.name])
+
+    def test_quotaset_add_doesnt_override_existing_quota(self):
+        quota_dict = {'foo': 1, 'bar': 10}
+        quota_set = api_base.QuotaSet(quota_dict)
+        other_quota_set = api_base.QuotaSet({'foo': 12})
+
+        quota_set += other_quota_set
+        self.assertEqual(len(quota_set), 2)
+
+        for q in quota_set:
+            self.assertEqual(q.limit, quota_dict[q.name])
+
+    def test_quotaset_add_method(self):
+        quota_dict = {'foo': 1, 'bar': 10}
+        other_quota_dict = {'my_test': 12}
+        quota_set = api_base.QuotaSet(quota_dict)
+        other_quota_set = api_base.QuotaSet(other_quota_dict)
+
+        quota_set.add(other_quota_set)
+        self.assertEqual(len(quota_set), 3)
+
+        quota_dict.update(other_quota_dict)
+        for q in quota_set:
+            self.assertEqual(q.limit, quota_dict[q.name])
+
+    def test_quotaset_add_with_wrong_type(self):
+        quota_set = api_base.QuotaSet({'foo': 1, 'bar': 10})
+        self.assertRaises(ValueError, quota_set.add, {'test': 7})
