@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -10,10 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.urls import re_path
+from django.conf.urls import patterns  # noqa
+from django.conf.urls import url  # noqa
 
 from openstack_dashboard.test.test_panels.plugin_panel import views
 
-urlpatterns = [
-    re_path(r'^$', views.IndexView.as_view(), name='index'),
-]
+urlpatterns = patterns('',
+    url(r'^$', views.IndexView.as_view(), name='index'),
+)
