@@ -1,3 +1,5 @@
+# vim: tabstop=4 shiftwidth=4 softtabstop=4
+
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -10,19 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from horizon import views
+from django.views.generic import TemplateView  # noqa
 
 
-class IndexView(views.HorizonTemplateView):
+class IndexView(TemplateView):
     template_name = 'admin/plugin_panel/index.html'
-    page_title = 'Plugin-based Panel'
-
-
-class TestBannerView(views.HorizonTemplateView):
-    template_name = 'admin/plugin_panel/header.html'
-
-    def get_context_data(self, **kwargs):
-        context = super().get_context_data(**kwargs)
-
-        context['message'] = "sample context"
-        return context
